// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

#include <sbkpython.h>
#include <shiboken.h>
#include <algorithm>
#include <signature.h>
#include <sbkcontainer.h>
#include <sbkstaticstrings.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysidecleanup.h>
#include <pysideqenum.h>
#include <feature_select.h>
#include <pysidestaticstrings.h>
#include "pyside6_qt3drender_python.h"

#include <QList>
#include <QMap>
#include <QString>
#include <Qt3DCore/qcomponent.h>
#include <Qt3DCore/qentity.h>
#include <Qt3DCore/qnode.h>
#include <Qt3DRender/qabstracttextureimage.h>
#include <Qt3DRender/qfilterkey.h>
#include <Qt3DRender/qlayer.h>
#include <Qt3DRender/qparameter.h>
#include <Qt3DRender/qraycasterhit.h>
#include <Qt3DRender/qrenderpass.h>
#include <Qt3DRender/qrenderstate.h>
#include <Qt3DRender/qrendertargetoutput.h>
#include <Qt3DRender/qshaderdata.h>
#include <Qt3DRender/qsortpolicy.h>
#include <Qt3DRender/qtechnique.h>
#include <Qt3DRender/qtextureimagedata.h>
#include <Qt3DRender/qtextureimagedatagenerator.h>
#include <qbytearray.h>
#include <qobject.h>
#include <qsharedpointer.h>
#include <qvariant.h>
#include <vector>


// Current module's type array.
PyTypeObject **SbkPySide6_Qt3DRenderTypes = nullptr;
// Current module's PyObject pointer.
PyObject *SbkPySide6_Qt3DRenderModuleObject = nullptr;
// Current module's converter array.
SbkConverter **SbkPySide6_Qt3DRenderTypeConverters = nullptr;
void cleanTypesAttributes() {
    static PyObject *attrName = Shiboken::PyName::qtStaticMetaObject();
    for (int i = 0, imax = SBK_Qt3DRender_IDX_COUNT; i < imax; i++) {
        PyObject *pyType = reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[i]);
        if (pyType && PyObject_HasAttr(pyType, attrName))
            PyObject_SetAttr(pyType, attrName, Py_None);
    }
}
// Global functions ------------------------------------------------------------

static PyMethodDef Qt3DRender_methods[] = {
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Classes initialization functions ------------------------------------------------------------
void init_Qt3DRenderQt3DRender(PyObject *module);
void init_Qt3DRender_QTextureWrapMode(PyObject *enclosingClass);
void init_Qt3DRender_QTextureImageData(PyObject *enclosingClass);
void init_Qt3DRender_QTextureDataUpdate(PyObject *enclosingClass);
void init_Qt3DRender_QTextureData(PyObject *enclosingClass);
void init_Qt3DRender_QStencilTestArguments(PyObject *enclosingClass);
void init_Qt3DRender_QStencilOperationArguments(PyObject *enclosingClass);
void init_Qt3DRender_QRenderCaptureReply(PyObject *enclosingClass);
void init_Qt3DRender_QRenderCapabilities(PyObject *enclosingClass);
void init_Qt3DRender_QRayCasterHit(PyObject *enclosingClass);
void init_Qt3DRender_QPickEvent(PyObject *enclosingClass);
void init_Qt3DRender_QPickTriangleEvent(PyObject *enclosingClass);
void init_Qt3DRender_QPickPointEvent(PyObject *enclosingClass);
void init_Qt3DRender_QPickLineEvent(PyObject *enclosingClass);
void init_Qt3DRender_QLevelOfDetailBoundingSphere(PyObject *enclosingClass);
void init_Qt3DRender_QGraphicsApiFilter(PyObject *enclosingClass);
void init_Qt3DRender_PropertyReaderInterface(PyObject *enclosingClass);
void init_Qt3DRender_QTechnique(PyObject *enclosingClass);
void init_Qt3DRender_QShaderProgramBuilder(PyObject *enclosingClass);
void init_Qt3DRender_QShaderProgram(PyObject *enclosingClass);
void init_Qt3DRender_QShaderImage(PyObject *enclosingClass);
void init_Qt3DRender_QRenderTargetOutput(PyObject *enclosingClass);
void init_Qt3DRender_QRenderState(PyObject *enclosingClass);
void init_Qt3DRender_QStencilTest(PyObject *enclosingClass);
void init_Qt3DRender_QStencilOperation(PyObject *enclosingClass);
void init_Qt3DRender_QStencilMask(PyObject *enclosingClass);
void init_Qt3DRender_QSeamlessCubemap(PyObject *enclosingClass);
void init_Qt3DRender_QScissorTest(PyObject *enclosingClass);
void init_Qt3DRender_QRasterMode(PyObject *enclosingClass);
void init_Qt3DRender_QPolygonOffset(PyObject *enclosingClass);
void init_Qt3DRender_QPointSize(PyObject *enclosingClass);
void init_Qt3DRender_QNoDepthMask(PyObject *enclosingClass);
void init_Qt3DRender_QMultiSampleAntiAliasing(PyObject *enclosingClass);
void init_Qt3DRender_QLineWidth(PyObject *enclosingClass);
void init_Qt3DRender_QFrontFace(PyObject *enclosingClass);
void init_Qt3DRender_QDithering(PyObject *enclosingClass);
void init_Qt3DRender_QDepthTest(PyObject *enclosingClass);
void init_Qt3DRender_QDepthRange(PyObject *enclosingClass);
void init_Qt3DRender_QCullFace(PyObject *enclosingClass);
void init_Qt3DRender_QColorMask(PyObject *enclosingClass);
void init_Qt3DRender_QClipPlane(PyObject *enclosingClass);
void init_Qt3DRender_QBlendEquationArguments(PyObject *enclosingClass);
void init_Qt3DRender_QBlendEquation(PyObject *enclosingClass);
void init_Qt3DRender_QAlphaTest(PyObject *enclosingClass);
void init_Qt3DRender_QAlphaCoverage(PyObject *enclosingClass);
void init_Qt3DRender_QRenderPass(PyObject *enclosingClass);
void init_Qt3DRender_QPickingSettings(PyObject *enclosingClass);
void init_Qt3DRender_QParameter(PyObject *enclosingClass);
void init_Qt3DRender_QFrameGraphNode(PyObject *enclosingClass);
void init_Qt3DRender_QWaitFence(PyObject *enclosingClass);
void init_Qt3DRender_QViewport(PyObject *enclosingClass);
void init_Qt3DRender_QTechniqueFilter(PyObject *enclosingClass);
void init_Qt3DRender_QSubtreeEnabler(PyObject *enclosingClass);
void init_Qt3DRender_QSortPolicy(PyObject *enclosingClass);
void init_Qt3DRender_QSetFence(PyObject *enclosingClass);
void init_Qt3DRender_QRenderTargetSelector(PyObject *enclosingClass);
void init_Qt3DRender_QRenderSurfaceSelector(PyObject *enclosingClass);
void init_Qt3DRender_QRenderStateSet(PyObject *enclosingClass);
void init_Qt3DRender_QRenderPassFilter(PyObject *enclosingClass);
void init_Qt3DRender_QRenderCapture(PyObject *enclosingClass);
void init_Qt3DRender_QProximityFilter(PyObject *enclosingClass);
void init_Qt3DRender_QNoPicking(PyObject *enclosingClass);
void init_Qt3DRender_QNoDraw(PyObject *enclosingClass);
void init_Qt3DRender_QMemoryBarrier(PyObject *enclosingClass);
void init_Qt3DRender_QLayerFilter(PyObject *enclosingClass);
void init_Qt3DRender_QFrustumCulling(PyObject *enclosingClass);
void init_Qt3DRender_QDispatchCompute(PyObject *enclosingClass);
void init_Qt3DRender_QClearBuffers(PyObject *enclosingClass);
void init_Qt3DRender_QCameraSelector(PyObject *enclosingClass);
void init_Qt3DRender_QBufferCapture(PyObject *enclosingClass);
void init_Qt3DRender_QBlitFramebuffer(PyObject *enclosingClass);
void init_Qt3DRender_QFilterKey(PyObject *enclosingClass);
void init_Qt3DRender_QEffect(PyObject *enclosingClass);
void init_Qt3DRender_QAbstractTextureImage(PyObject *enclosingClass);
void init_Qt3DRender_QTextureImage(PyObject *enclosingClass);
void init_Qt3DRender_QPaintedTextureImage(PyObject *enclosingClass);
void init_Qt3DRender_QAbstractTexture(PyObject *enclosingClass);
void init_Qt3DRender_QTextureRectangle(PyObject *enclosingClass);
void init_Qt3DRender_QTextureLoader(PyObject *enclosingClass);
void init_Qt3DRender_QTextureCubeMapArray(PyObject *enclosingClass);
void init_Qt3DRender_QTextureCubeMap(PyObject *enclosingClass);
void init_Qt3DRender_QTextureBuffer(PyObject *enclosingClass);
void init_Qt3DRender_QTexture3D(PyObject *enclosingClass);
void init_Qt3DRender_QTexture2DMultisampleArray(PyObject *enclosingClass);
void init_Qt3DRender_QTexture2DMultisample(PyObject *enclosingClass);
void init_Qt3DRender_QTexture2DArray(PyObject *enclosingClass);
void init_Qt3DRender_QTexture2D(PyObject *enclosingClass);
void init_Qt3DRender_QTexture1DArray(PyObject *enclosingClass);
void init_Qt3DRender_QTexture1D(PyObject *enclosingClass);
void init_Qt3DRender_QSharedGLTexture(PyObject *enclosingClass);
void init_Qt3DRender_QCamera(PyObject *enclosingClass);
void init_Qt3DRender_QShaderData(PyObject *enclosingClass);
void init_Qt3DRender_QSceneLoader(PyObject *enclosingClass);
void init_Qt3DRender_QRenderTarget(PyObject *enclosingClass);
void init_Qt3DRender_QRenderSettings(PyObject *enclosingClass);
void init_Qt3DRender_QObjectPicker(PyObject *enclosingClass);
void init_Qt3DRender_QMaterial(PyObject *enclosingClass);
void init_Qt3DRender_QLevelOfDetail(PyObject *enclosingClass);
void init_Qt3DRender_QLevelOfDetailSwitch(PyObject *enclosingClass);
void init_Qt3DRender_QLayer(PyObject *enclosingClass);
void init_Qt3DRender_QEnvironmentLight(PyObject *enclosingClass);
void init_Qt3DRender_QComputeCommand(PyObject *enclosingClass);
void init_Qt3DRender_QCameraLens(PyObject *enclosingClass);
void init_Qt3DRender_QAbstractRayCaster(PyObject *enclosingClass);
void init_Qt3DRender_QScreenRayCaster(PyObject *enclosingClass);
void init_Qt3DRender_QRayCaster(PyObject *enclosingClass);
void init_Qt3DRender_QAbstractLight(PyObject *enclosingClass);
void init_Qt3DRender_QSpotLight(PyObject *enclosingClass);
void init_Qt3DRender_QPointLight(PyObject *enclosingClass);
void init_Qt3DRender_QDirectionalLight(PyObject *enclosingClass);
void init_Qt3DRender_QPickingProxy(PyObject *enclosingClass);
void init_Qt3DRender_QGeometryRenderer(PyObject *enclosingClass);
void init_Qt3DRender_QMesh(PyObject *enclosingClass);
void init_Qt3DRender_QTextureImageDataGenerator(PyObject *enclosingClass);
void init_Qt3DRender_QRenderAspect(PyObject *enclosingClass);
void init_Qt3DRender_QTextureImageDataPtr(PyObject *enclosingClass);
void init_Qt3DRender_QTextureImageDataGeneratorPtr(PyObject *enclosingClass);
void init_Qt3DRender_PropertyReaderInterfacePtr(PyObject *enclosingClass);

// Required modules' type and converter arrays.
PyTypeObject **SbkPySide6_Qt3DCoreTypes;
SbkConverter **SbkPySide6_Qt3DCoreTypeConverters;
PyTypeObject **SbkPySide6_QtGuiTypes;
SbkConverter **SbkPySide6_QtGuiTypeConverters;
PyTypeObject **SbkPySide6_QtCoreTypes;
SbkConverter **SbkPySide6_QtCoreTypeConverters;

// Module initialization ------------------------------------------------------------
// Container Type converters.

// C++ to Python conversion for container type 'QList<int>'.
static PyObject *_QList_int__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<int> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_int_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<int> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        int cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_int__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyIn))
        return PySequence_PythonToCpp__QList_int_;
    return {};
}


// Binding for QList<int>

template <>
struct ShibokenContainerValueConverter<int>
{
    static bool checkValue(PyObject *pyArg)
    {
        return PyLong_Check(pyArg);
    }

    static PyObject *convertValueToPython(int cppArg)
    {
        return Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppArg);
    }

    static std::optional<int> convertValueToCpp(PyObject *pyArg)
    {
        Shiboken::Conversions::PythonToCppConversion pythonToCpp;
        if (!(PyLong_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg))))) {
            Shiboken::Errors::setWrongContainerType();
            return {};
        }
        int cppArg;
        pythonToCpp(pyArg, &cppArg);
        return cppArg;
    }
};

static PyMethodDef QIntList_methods[] = {
    {"push_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::push_back), METH_O, "push_back"},
    {"append", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::push_back), METH_O, "append"},
    {"clear", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::clear), METH_NOARGS, "clear"},
    {"pop_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::pop_back), METH_NOARGS, "pop_back"},
    {"removeLast", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::pop_back), METH_NOARGS, "removeLast"},
    {"push_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::push_front), METH_O, "push_front"},
    {"prepend", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::push_front), METH_O, "prepend"},
    {"pop_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::pop_front), METH_NOARGS, "pop_front"},
    {"removeFirst", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::pop_front), METH_O, "removeFirst"},
    {"reserve", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::reserve), METH_O, "reserve"},
    {"capacity", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::capacity), METH_NOARGS, "capacity"},
    {"data", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::data), METH_NOARGS, "data"},
    {"constData", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::constData), METH_NOARGS, "constData"},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyType_Slot QIntList_slots[] = {
    {Py_tp_init, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::tpInit)},
    {Py_tp_new, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::tpNew)},
    {Py_tp_free, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::tpFree)},
    {Py_tp_dealloc, reinterpret_cast<void *>(Sbk_object_dealloc)},
    {Py_tp_methods, reinterpret_cast<void *>(QIntList_methods)},
    {Py_sq_ass_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::sqSetItem)},
    {Py_sq_length, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::sqLen)},
    {Py_sq_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::sqGetItem)},
    {0, nullptr}
};

static PyType_Spec QIntList_spec = {
    "2:PySide6.Qt3DRender.QIntList",
    sizeof(ShibokenContainer),
    0,
    Py_TPFLAGS_DEFAULT,
    QIntList_slots
};

static inline PyTypeObject *createQIntListType()
{
    auto *result = reinterpret_cast<PyTypeObject *>(SbkType_FromSpec(&QIntList_spec));
    Py_INCREF(Py_True);
    Shiboken::AutoDecRef tpDict(PepType_GetDict(result));
    PyDict_SetItem(tpDict.object(), Shiboken::PyMagicName::opaque_container(), Py_True);
    return result;
}

static PyTypeObject *QIntList_TypeF()
{
    static PyTypeObject *type = createQIntListType();
    return type;
}

extern "C" PyObject *createQIntList(QList<int>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QIntList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<int>>();
    d->m_list = ct;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" PyObject *createConstQIntList(const QList<int>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QIntList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<int>>();
    d->m_list = const_cast<QList<int> *>(ct);
    d->m_const = true;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" int QIntList_Check(PyObject *pyArg)
{
    return pyArg != nullptr && pyArg != Py_None && pyArg->ob_type == QIntList_TypeF();
}

extern "C" void PythonToCppQIntList(PyObject *pyArg, void *cppOut)
{
    auto *d = ShibokenSequenceContainerPrivate<QList<int>>::get(pyArg);
    *reinterpret_cast<QList<int>**>(cppOut) = d->m_list;
}

extern "C" PythonToCppFunc isQIntListPythonToCppConvertible(PyObject *pyArg)
{
    if (QIntList_Check(pyArg))
        return PythonToCppQIntList;
    return {};
}

// C++ to Python conversion for container type 'QList<Qt3DCore::QEntity*>'.
static PyObject *_QList_Qt3DCore_QEntityPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<Qt3DCore::QEntity*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(SbkPySide6_Qt3DCoreTypes[SBK_QT3DCORE_QENTITY_IDX], cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_Qt3DCore_QEntityPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<Qt3DCore::QEntity*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::Qt3DCore::QEntity* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_Qt3DCoreTypes[SBK_QT3DCORE_QENTITY_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_Qt3DCore_QEntityPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(SbkPySide6_Qt3DCoreTypes[SBK_QT3DCORE_QENTITY_IDX], pyIn))
        return PySequence_PythonToCpp__QList_Qt3DCore_QEntityPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<Qt3DRender::QRayCasterHit>'.
static PyObject *_QList_Qt3DRender_QRayCasterHit__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<Qt3DRender::QRayCasterHit> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QRAYCASTERHIT_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_Qt3DRender_QRayCasterHit_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<Qt3DRender::QRayCasterHit> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::Qt3DRender::QRayCasterHit cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QRAYCASTERHIT_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_Qt3DRender_QRayCasterHit__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QRAYCASTERHIT_IDX], pyIn))
        return PySequence_PythonToCpp__QList_Qt3DRender_QRayCasterHit_;
    return {};
}

// C++ to Python conversion for container type 'QList<Qt3DRender::QLayer*>'.
static PyObject *_QList_Qt3DRender_QLayerPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<Qt3DRender::QLayer*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QLAYER_IDX], cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_Qt3DRender_QLayerPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<Qt3DRender::QLayer*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::Qt3DRender::QLayer* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QLAYER_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_Qt3DRender_QLayerPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QLAYER_IDX], pyIn))
        return PySequence_PythonToCpp__QList_Qt3DRender_QLayerPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QObject*>'.
static PyObject *_QList_QObjectPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QObject*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(SbkPySide6_QtCoreTypes[SBK_QOBJECT_IDX], cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QObjectPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QObject*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QObject* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_QtCoreTypes[SBK_QOBJECT_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QObjectPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(SbkPySide6_QtCoreTypes[SBK_QOBJECT_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QObjectPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QByteArray>'.
static PyObject *_QList_QByteArray__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QByteArray> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypes[SBK_QBYTEARRAY_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QByteArray_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QByteArray> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QByteArray cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypes[SBK_QBYTEARRAY_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QByteArray__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypes[SBK_QBYTEARRAY_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QByteArray_;
    return {};
}

// C++ to Python conversion for container type 'QList<Qt3DRender::QAbstractTextureImage*>'.
static PyObject *_QList_Qt3DRender_QAbstractTextureImagePTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<Qt3DRender::QAbstractTextureImage*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QABSTRACTTEXTUREIMAGE_IDX], cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_Qt3DRender_QAbstractTextureImagePTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<Qt3DRender::QAbstractTextureImage*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::Qt3DRender::QAbstractTextureImage* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QABSTRACTTEXTUREIMAGE_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_Qt3DRender_QAbstractTextureImagePTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QABSTRACTTEXTUREIMAGE_IDX], pyIn))
        return PySequence_PythonToCpp__QList_Qt3DRender_QAbstractTextureImagePTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<Qt3DCore::QNode*>'.
static PyObject *_QList_Qt3DCore_QNodePTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<Qt3DCore::QNode*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(SbkPySide6_Qt3DCoreTypes[SBK_QT3DCORE_QNODE_IDX], cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_Qt3DCore_QNodePTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<Qt3DCore::QNode*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::Qt3DCore::QNode* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_Qt3DCoreTypes[SBK_QT3DCORE_QNODE_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_Qt3DCore_QNodePTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(SbkPySide6_Qt3DCoreTypes[SBK_QT3DCORE_QNODE_IDX], pyIn))
        return PySequence_PythonToCpp__QList_Qt3DCore_QNodePTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<Qt3DRender::QFilterKey*>'.
static PyObject *_QList_Qt3DRender_QFilterKeyPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<Qt3DRender::QFilterKey*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QFILTERKEY_IDX], cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_Qt3DRender_QFilterKeyPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<Qt3DRender::QFilterKey*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::Qt3DRender::QFilterKey* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QFILTERKEY_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_Qt3DRender_QFilterKeyPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QFILTERKEY_IDX], pyIn))
        return PySequence_PythonToCpp__QList_Qt3DRender_QFilterKeyPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<Qt3DRender::QParameter*>'.
static PyObject *_QList_Qt3DRender_QParameterPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<Qt3DRender::QParameter*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QPARAMETER_IDX], cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_Qt3DRender_QParameterPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<Qt3DRender::QParameter*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::Qt3DRender::QParameter* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QPARAMETER_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_Qt3DRender_QParameterPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QPARAMETER_IDX], pyIn))
        return PySequence_PythonToCpp__QList_Qt3DRender_QParameterPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<Qt3DRender::QRenderState*>'.
static PyObject *_QList_Qt3DRender_QRenderStatePTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<Qt3DRender::QRenderState*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QRENDERSTATE_IDX], cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_Qt3DRender_QRenderStatePTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<Qt3DRender::QRenderState*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::Qt3DRender::QRenderState* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QRENDERSTATE_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_Qt3DRender_QRenderStatePTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QRENDERSTATE_IDX], pyIn))
        return PySequence_PythonToCpp__QList_Qt3DRender_QRenderStatePTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<Qt3DRender::QSortPolicy::SortType>'.
static PyObject *_QList_Qt3DRender_QSortPolicy_SortType__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<Qt3DRender::QSortPolicy::SortType> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QSORTPOLICY_SORTTYPE_IDX]))->converter, &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_Qt3DRender_QSortPolicy_SortType_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<Qt3DRender::QSortPolicy::SortType> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::Qt3DRender::QSortPolicy::SortType cppItem = static_cast< ::Qt3DRender::QSortPolicy::SortType>(0);
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QSORTPOLICY_SORTTYPE_IDX]))->converter, pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_Qt3DRender_QSortPolicy_SortType__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QSORTPOLICY_SORTTYPE_IDX]))->converter, pyIn))
        return PySequence_PythonToCpp__QList_Qt3DRender_QSortPolicy_SortType_;
    return {};
}

// C++ to Python conversion for container type 'QList<Qt3DRender::QRenderTargetOutput*>'.
static PyObject *_QList_Qt3DRender_QRenderTargetOutputPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<Qt3DRender::QRenderTargetOutput*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QRENDERTARGETOUTPUT_IDX], cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_Qt3DRender_QRenderTargetOutputPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<Qt3DRender::QRenderTargetOutput*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::Qt3DRender::QRenderTargetOutput* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QRENDERTARGETOUTPUT_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_Qt3DRender_QRenderTargetOutputPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QRENDERTARGETOUTPUT_IDX], pyIn))
        return PySequence_PythonToCpp__QList_Qt3DRender_QRenderTargetOutputPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<Qt3DCore::QComponent*>'.
static PyObject *_QList_Qt3DCore_QComponentPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<Qt3DCore::QComponent*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(SbkPySide6_Qt3DCoreTypes[SBK_QT3DCORE_QCOMPONENT_IDX], cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_Qt3DCore_QComponentPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<Qt3DCore::QComponent*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::Qt3DCore::QComponent* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_Qt3DCoreTypes[SBK_QT3DCORE_QCOMPONENT_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_Qt3DCore_QComponentPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(SbkPySide6_Qt3DCoreTypes[SBK_QT3DCORE_QCOMPONENT_IDX], pyIn))
        return PySequence_PythonToCpp__QList_Qt3DCore_QComponentPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<Qt3DRender::QTechnique*>'.
static PyObject *_QList_Qt3DRender_QTechniquePTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<Qt3DRender::QTechnique*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QTECHNIQUE_IDX], cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_Qt3DRender_QTechniquePTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<Qt3DRender::QTechnique*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::Qt3DRender::QTechnique* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QTECHNIQUE_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_Qt3DRender_QTechniquePTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QTECHNIQUE_IDX], pyIn))
        return PySequence_PythonToCpp__QList_Qt3DRender_QTechniquePTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<qreal>'.
static PyObject *_QList_qreal__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<qreal> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_qreal_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<qreal> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        qreal cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_qreal__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), pyIn))
        return PySequence_PythonToCpp__QList_qreal_;
    return {};
}

// C++ to Python conversion for container type 'std::vector<QSharedPointer< Qt3DCore::QAspectJob>>'.
static PyObject *std_vector_QSharedPointer_Qt3DCore_QAspectJob___CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::std::vector<QSharedPointer< Qt3DCore::QAspectJob>> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_Qt3DCoreTypes[SBK_QSHAREDPOINTER_QT3DCORE_QASPECTJOB_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp_std_vector_QSharedPointer_Qt3DCore_QAspectJob__(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::std::vector<QSharedPointer< Qt3DCore::QAspectJob>> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QSharedPointer<Qt3DCore::QAspectJob> cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_Qt3DCoreTypes[SBK_QSHAREDPOINTER_QT3DCORE_QASPECTJOB_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_std_vector_QSharedPointer_Qt3DCore_QAspectJob___Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_Qt3DCoreTypes[SBK_QSHAREDPOINTER_QT3DCORE_QASPECTJOB_IDX], pyIn))
        return PySequence_PythonToCpp_std_vector_QSharedPointer_Qt3DCore_QAspectJob__;
    return {};
}

// C++ to Python conversion for container type 'QList<Qt3DRender::QRenderPass*>'.
static PyObject *_QList_Qt3DRender_QRenderPassPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<Qt3DRender::QRenderPass*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QRENDERPASS_IDX], cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_Qt3DRender_QRenderPassPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<Qt3DRender::QRenderPass*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::Qt3DRender::QRenderPass* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QRENDERPASS_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_Qt3DRender_QRenderPassPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QRENDERPASS_IDX], pyIn))
        return PySequence_PythonToCpp__QList_Qt3DRender_QRenderPassPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QSharedPointer< Qt3DRender::QTextureImageData>>'.
static PyObject *_QList_QSharedPointer_Qt3DRender_QTextureImageData___CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QSharedPointer< Qt3DRender::QTextureImageData>> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_Qt3DRenderTypes[SBK_QSHAREDPOINTER_QT3DRENDER_QTEXTUREIMAGEDATA_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QSharedPointer_Qt3DRender_QTextureImageData__(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QSharedPointer< Qt3DRender::QTextureImageData>> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QSharedPointer<Qt3DRender::QTextureImageData> cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_Qt3DRenderTypes[SBK_QSHAREDPOINTER_QT3DRENDER_QTEXTUREIMAGEDATA_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QSharedPointer_Qt3DRender_QTextureImageData___Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_Qt3DRenderTypes[SBK_QSHAREDPOINTER_QT3DRENDER_QTEXTUREIMAGEDATA_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QSharedPointer_Qt3DRender_QTextureImageData__;
    return {};
}

// C++ to Python conversion for container type 'QList<QVariant>'.
static PyObject *_QList_QVariant__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QVariant> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVARIANT_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QVariant_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QVariant> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QVariant cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QVARIANT_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QVariant__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypeConverters[SBK_QVARIANT_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QVariant_;
    return {};
}

// C++ to Python conversion for container type 'QList<QString>'.
static PyObject *_QList_QString__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QString> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QSTRING_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QString_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QString> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QString cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QSTRING_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QString__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypeConverters[SBK_QSTRING_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QString_;
    return {};
}

// C++ to Python conversion for container type 'QMap<QString,QVariant>'.
static PyObject *_QMap_QString_QVariant__CppToPython_PyDict(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QMap<QString,QVariant> *>(cppIn);
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - START
    PyObject *pyOut = PyDict_New();
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it) {
        const auto &key = it.key();
        const auto &value = it.value();
        PyObject *pyKey = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QSTRING_IDX], &key);
        PyObject *pyValue = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVARIANT_IDX], &value);
        PyDict_SetItem(pyOut, pyKey, pyValue);
        Py_DECREF(pyKey);
        Py_DECREF(pyValue);
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - END

}
static void PyDict_PythonToCpp__QMap_QString_QVariant_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QMap<QString,QVariant> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - START
    PyObject *key;
    PyObject *value;
    cppOutRef.clear();
    Py_ssize_t pos = 0;
    while (PyDict_Next(pyIn, &pos, &key, &value)) {
        ::QString cppKey;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QSTRING_IDX], key, &(cppKey));
        ::QVariant cppValue;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QVARIANT_IDX], value, &(cppValue));
        cppOutRef.insert(cppKey, cppValue);
    }
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - END

}
static PythonToCppFunc is_PyDict_PythonToCpp__QMap_QString_QVariant__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleDictTypes(SbkPySide6_QtCoreTypeConverters[SBK_QSTRING_IDX], false, SbkPySide6_QtCoreTypeConverters[SBK_QVARIANT_IDX], false, pyIn))
        return PyDict_PythonToCpp__QMap_QString_QVariant_;
    return {};
}


// SmartPointers converters.

// C++ to Python conversion for smart pointer type 'QSharedPointer<Qt3DRender::QTextureImageData>'.
// C++ to Python conversion for smart pointer type 'QSharedPointer<Qt3DRender::QTextureImageDataGenerator>'.
// Register smartpointer conversion for all derived classes
// C++ to Python conversion for smart pointer type 'QSharedPointer<Qt3DRender::PropertyReaderInterface>'.

static struct PyModuleDef moduledef = {
    /* m_base     */ PyModuleDef_HEAD_INIT,
    /* m_name     */ "Qt3DRender",
    /* m_doc      */ nullptr,
    /* m_size     */ -1,
    /* m_methods  */ Qt3DRender_methods,
    /* m_reload   */ nullptr,
    /* m_traverse */ nullptr,
    /* m_clear    */ nullptr,
    /* m_free     */ nullptr
};

// The signatures string for the global functions.
// Multiple signatures have their index "n:" in front.
static const char *Qt3DRender_SignatureStrings[] = {
    nullptr}; // Sentinel

extern "C" LIBSHIBOKEN_EXPORT PyObject *PyInit_Qt3DRender()
{
    if (SbkPySide6_Qt3DRenderModuleObject != nullptr)
        return SbkPySide6_Qt3DRenderModuleObject;
    {
        Shiboken::AutoDecRef requiredModule(Shiboken::Module::import("PySide6.Qt3DCore"));
        if (requiredModule.isNull())
            return nullptr;
        SbkPySide6_Qt3DCoreTypes = Shiboken::Module::getTypes(requiredModule);
        SbkPySide6_Qt3DCoreTypeConverters = Shiboken::Module::getTypeConverters(requiredModule);
    }

    {
        Shiboken::AutoDecRef requiredModule(Shiboken::Module::import("PySide6.QtGui"));
        if (requiredModule.isNull())
            return nullptr;
        SbkPySide6_QtGuiTypes = Shiboken::Module::getTypes(requiredModule);
        SbkPySide6_QtGuiTypeConverters = Shiboken::Module::getTypeConverters(requiredModule);
    }

    {
        Shiboken::AutoDecRef requiredModule(Shiboken::Module::import("PySide6.QtCore"));
        if (requiredModule.isNull())
            return nullptr;
        SbkPySide6_QtCoreTypes = Shiboken::Module::getTypes(requiredModule);
        SbkPySide6_QtCoreTypeConverters = Shiboken::Module::getTypeConverters(requiredModule);
    }

    // Create an array of wrapper types for the current module.
    static PyTypeObject *cppApi[SBK_Qt3DRender_IDX_COUNT];
    SbkPySide6_Qt3DRenderTypes = cppApi;

    // Create an array of primitive type converters for the current module.
    static SbkConverter *sbkConverters[SBK_Qt3DRender_CONVERTERS_IDX_COUNT];
    SbkPySide6_Qt3DRenderTypeConverters = sbkConverters;

    PyObject *module = Shiboken::Module::create("Qt3DRender", &moduledef);

    // Make module available from global scope
    SbkPySide6_Qt3DRenderModuleObject = module;

    // Initialize classes in the type system
    init_Qt3DRenderQt3DRender(module);
    init_Qt3DRender_QTextureWrapMode(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QTextureImageData(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QTextureDataUpdate(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QTextureData(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QStencilTestArguments(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QStencilOperationArguments(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QRenderCaptureReply(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QRenderCapabilities(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QRayCasterHit(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QPickEvent(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QPickTriangleEvent(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QPickPointEvent(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QPickLineEvent(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QLevelOfDetailBoundingSphere(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QGraphicsApiFilter(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_PropertyReaderInterface(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QTechnique(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QShaderProgramBuilder(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QShaderProgram(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QShaderImage(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QRenderTargetOutput(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QRenderState(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QStencilTest(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QStencilOperation(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QStencilMask(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QSeamlessCubemap(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QScissorTest(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QRasterMode(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QPolygonOffset(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QPointSize(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QNoDepthMask(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QMultiSampleAntiAliasing(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QLineWidth(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QFrontFace(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QDithering(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QDepthTest(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QDepthRange(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QCullFace(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QColorMask(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QClipPlane(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QBlendEquationArguments(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QBlendEquation(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QAlphaTest(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QAlphaCoverage(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QRenderPass(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QPickingSettings(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QParameter(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QFrameGraphNode(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QWaitFence(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QViewport(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QTechniqueFilter(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QSubtreeEnabler(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QSortPolicy(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QSetFence(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QRenderTargetSelector(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QRenderSurfaceSelector(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QRenderStateSet(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QRenderPassFilter(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QRenderCapture(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QProximityFilter(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QNoPicking(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QNoDraw(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QMemoryBarrier(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QLayerFilter(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QFrustumCulling(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QDispatchCompute(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QClearBuffers(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QCameraSelector(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QBufferCapture(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QBlitFramebuffer(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QFilterKey(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QEffect(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QAbstractTextureImage(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QTextureImage(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QPaintedTextureImage(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QAbstractTexture(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QTextureRectangle(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QTextureLoader(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QTextureCubeMapArray(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QTextureCubeMap(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QTextureBuffer(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QTexture3D(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QTexture2DMultisampleArray(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QTexture2DMultisample(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QTexture2DArray(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QTexture2D(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QTexture1DArray(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QTexture1D(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QSharedGLTexture(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QCamera(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QShaderData(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QSceneLoader(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QRenderTarget(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QRenderSettings(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QObjectPicker(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QMaterial(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QLevelOfDetail(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QLevelOfDetailSwitch(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QLayer(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QEnvironmentLight(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QComputeCommand(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QCameraLens(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QAbstractRayCaster(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QScreenRayCaster(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QRayCaster(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QAbstractLight(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QSpotLight(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QPointLight(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QDirectionalLight(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QPickingProxy(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QGeometryRenderer(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QMesh(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QTextureImageDataGenerator(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QRenderAspect(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QTextureImageDataPtr(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_QTextureImageDataGeneratorPtr(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));
    init_Qt3DRender_PropertyReaderInterfacePtr(reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypes[SBK_Qt3DRenderQT3DRENDER_IDX]));

    // Register converter for type 'QList<int>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_INT_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_int__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_INT_IDX], "QList<int>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_INT_IDX],
        PySequence_PythonToCpp__QList_int_,
        is_PySequence_PythonToCpp__QList_int__Convertible);
    Shiboken::Conversions::setPythonToCppPointerFunctions(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_INT_IDX],
        PythonToCppQIntList,
        isQIntListPythonToCppConvertible);

    // Register converter for type 'QList<Qt3DCore::QEntity*>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QT3DCORE_QENTITYPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_Qt3DCore_QEntityPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QT3DCORE_QENTITYPTR_IDX], "QList<Qt3DCore::QEntity*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QT3DCORE_QENTITYPTR_IDX],
        PySequence_PythonToCpp__QList_Qt3DCore_QEntityPTR_,
        is_PySequence_PythonToCpp__QList_Qt3DCore_QEntityPTR__Convertible);

    // Register converter for type 'QList<Qt3DRender::QRayCasterHit>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QT3DRENDER_QRAYCASTERHIT_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_Qt3DRender_QRayCasterHit__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QT3DRENDER_QRAYCASTERHIT_IDX], "QList<Qt3DRender::QRayCasterHit>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QT3DRENDER_QRAYCASTERHIT_IDX],
        PySequence_PythonToCpp__QList_Qt3DRender_QRayCasterHit_,
        is_PySequence_PythonToCpp__QList_Qt3DRender_QRayCasterHit__Convertible);

    // Register converter for type 'QList<Qt3DRender::QLayer*>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QT3DRENDER_QLAYERPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_Qt3DRender_QLayerPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QT3DRENDER_QLAYERPTR_IDX], "QList<Qt3DRender::QLayer*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QT3DRENDER_QLAYERPTR_IDX],
        PySequence_PythonToCpp__QList_Qt3DRender_QLayerPTR_,
        is_PySequence_PythonToCpp__QList_Qt3DRender_QLayerPTR__Convertible);

    // Register converter for type 'QList<QObject*>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QOBJECTPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QObjectPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QOBJECTPTR_IDX], "QList<QObject*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QOBJECTPTR_IDX],
        PySequence_PythonToCpp__QList_QObjectPTR_,
        is_PySequence_PythonToCpp__QList_QObjectPTR__Convertible);

    // Register converter for type 'QList<QByteArray>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QBYTEARRAY_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QByteArray__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QBYTEARRAY_IDX], "QList<QByteArray>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QBYTEARRAY_IDX],
        PySequence_PythonToCpp__QList_QByteArray_,
        is_PySequence_PythonToCpp__QList_QByteArray__Convertible);

    // Register converter for type 'QList<Qt3DRender::QAbstractTextureImage*>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QT3DRENDER_QABSTRACTTEXTUREIMAGEPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_Qt3DRender_QAbstractTextureImagePTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QT3DRENDER_QABSTRACTTEXTUREIMAGEPTR_IDX], "QList<Qt3DRender::QAbstractTextureImage*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QT3DRENDER_QABSTRACTTEXTUREIMAGEPTR_IDX],
        PySequence_PythonToCpp__QList_Qt3DRender_QAbstractTextureImagePTR_,
        is_PySequence_PythonToCpp__QList_Qt3DRender_QAbstractTextureImagePTR__Convertible);

    // Register converter for type 'QList<Qt3DCore::QNode*>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QT3DCORE_QNODEPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_Qt3DCore_QNodePTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QT3DCORE_QNODEPTR_IDX], "QList<Qt3DCore::QNode*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QT3DCORE_QNODEPTR_IDX],
        PySequence_PythonToCpp__QList_Qt3DCore_QNodePTR_,
        is_PySequence_PythonToCpp__QList_Qt3DCore_QNodePTR__Convertible);

    // Register converter for type 'QList<Qt3DRender::QFilterKey*>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QT3DRENDER_QFILTERKEYPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_Qt3DRender_QFilterKeyPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QT3DRENDER_QFILTERKEYPTR_IDX], "QList<Qt3DRender::QFilterKey*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QT3DRENDER_QFILTERKEYPTR_IDX],
        PySequence_PythonToCpp__QList_Qt3DRender_QFilterKeyPTR_,
        is_PySequence_PythonToCpp__QList_Qt3DRender_QFilterKeyPTR__Convertible);

    // Register converter for type 'QList<Qt3DRender::QParameter*>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QT3DRENDER_QPARAMETERPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_Qt3DRender_QParameterPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QT3DRENDER_QPARAMETERPTR_IDX], "QList<Qt3DRender::QParameter*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QT3DRENDER_QPARAMETERPTR_IDX],
        PySequence_PythonToCpp__QList_Qt3DRender_QParameterPTR_,
        is_PySequence_PythonToCpp__QList_Qt3DRender_QParameterPTR__Convertible);

    // Register converter for type 'QList<Qt3DRender::QRenderState*>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QT3DRENDER_QRENDERSTATEPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_Qt3DRender_QRenderStatePTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QT3DRENDER_QRENDERSTATEPTR_IDX], "QList<Qt3DRender::QRenderState*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QT3DRENDER_QRENDERSTATEPTR_IDX],
        PySequence_PythonToCpp__QList_Qt3DRender_QRenderStatePTR_,
        is_PySequence_PythonToCpp__QList_Qt3DRender_QRenderStatePTR__Convertible);

    // Register converter for type 'QList<Qt3DRender::QSortPolicy::SortType>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QT3DRENDER_QSORTPOLICY_SORTTYPE_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_Qt3DRender_QSortPolicy_SortType__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QT3DRENDER_QSORTPOLICY_SORTTYPE_IDX], "QList<Qt3DRender::QSortPolicy::SortType>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QT3DRENDER_QSORTPOLICY_SORTTYPE_IDX],
        PySequence_PythonToCpp__QList_Qt3DRender_QSortPolicy_SortType_,
        is_PySequence_PythonToCpp__QList_Qt3DRender_QSortPolicy_SortType__Convertible);

    // Register converter for type 'QList<Qt3DRender::QRenderTargetOutput*>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QT3DRENDER_QRENDERTARGETOUTPUTPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_Qt3DRender_QRenderTargetOutputPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QT3DRENDER_QRENDERTARGETOUTPUTPTR_IDX], "QList<Qt3DRender::QRenderTargetOutput*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QT3DRENDER_QRENDERTARGETOUTPUTPTR_IDX],
        PySequence_PythonToCpp__QList_Qt3DRender_QRenderTargetOutputPTR_,
        is_PySequence_PythonToCpp__QList_Qt3DRender_QRenderTargetOutputPTR__Convertible);

    // Register converter for type 'QList<Qt3DCore::QComponent*>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QT3DCORE_QCOMPONENTPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_Qt3DCore_QComponentPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QT3DCORE_QCOMPONENTPTR_IDX], "QList<Qt3DCore::QComponent*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QT3DCORE_QCOMPONENTPTR_IDX],
        PySequence_PythonToCpp__QList_Qt3DCore_QComponentPTR_,
        is_PySequence_PythonToCpp__QList_Qt3DCore_QComponentPTR__Convertible);

    // Register converter for type 'QList<Qt3DRender::QTechnique*>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QT3DRENDER_QTECHNIQUEPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_Qt3DRender_QTechniquePTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QT3DRENDER_QTECHNIQUEPTR_IDX], "QList<Qt3DRender::QTechnique*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QT3DRENDER_QTECHNIQUEPTR_IDX],
        PySequence_PythonToCpp__QList_Qt3DRender_QTechniquePTR_,
        is_PySequence_PythonToCpp__QList_Qt3DRender_QTechniquePTR__Convertible);

    // Register converter for type 'QList<qreal>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QREAL_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_qreal__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QREAL_IDX], "QList<qreal>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QREAL_IDX],
        PySequence_PythonToCpp__QList_qreal_,
        is_PySequence_PythonToCpp__QList_qreal__Convertible);

    // Register converter for type 'std::vector<QSharedPointer<Qt3DCore::QAspectJob>>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_STD_VECTOR_QSHAREDPOINTER_QT3DCORE_QASPECTJOB_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, std_vector_QSharedPointer_Qt3DCore_QAspectJob___CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_STD_VECTOR_QSHAREDPOINTER_QT3DCORE_QASPECTJOB_IDX], "std::vector<QSharedPointer<Qt3DCore::QAspectJob>>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_STD_VECTOR_QSHAREDPOINTER_QT3DCORE_QASPECTJOB_IDX],
        PySequence_PythonToCpp_std_vector_QSharedPointer_Qt3DCore_QAspectJob__,
        is_PySequence_PythonToCpp_std_vector_QSharedPointer_Qt3DCore_QAspectJob___Convertible);

    // Register converter for type 'QList<Qt3DRender::QRenderPass*>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QT3DRENDER_QRENDERPASSPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_Qt3DRender_QRenderPassPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QT3DRENDER_QRENDERPASSPTR_IDX], "QList<Qt3DRender::QRenderPass*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QT3DRENDER_QRENDERPASSPTR_IDX],
        PySequence_PythonToCpp__QList_Qt3DRender_QRenderPassPTR_,
        is_PySequence_PythonToCpp__QList_Qt3DRender_QRenderPassPTR__Convertible);

    // Register converter for type 'QList<QSharedPointer<Qt3DRender::QTextureImageData>>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QSHAREDPOINTER_QT3DRENDER_QTEXTUREIMAGEDATA_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QSharedPointer_Qt3DRender_QTextureImageData___CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QSHAREDPOINTER_QT3DRENDER_QTEXTUREIMAGEDATA_IDX], "QList<QSharedPointer<Qt3DRender::QTextureImageData>>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QSHAREDPOINTER_QT3DRENDER_QTEXTUREIMAGEDATA_IDX],
        PySequence_PythonToCpp__QList_QSharedPointer_Qt3DRender_QTextureImageData__,
        is_PySequence_PythonToCpp__QList_QSharedPointer_Qt3DRender_QTextureImageData___Convertible);

    // Register converter for type 'QList<QVariant>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QVARIANT_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QVariant__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QVARIANT_IDX], "QList<QVariant>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QVARIANT_IDX],
        PySequence_PythonToCpp__QList_QVariant_,
        is_PySequence_PythonToCpp__QList_QVariant__Convertible);

    // Register converter for type 'QList<QString>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QSTRING_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QString__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QSTRING_IDX], "QList<QString>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QLIST_QSTRING_IDX],
        PySequence_PythonToCpp__QList_QString_,
        is_PySequence_PythonToCpp__QList_QString__Convertible);

    // Register converter for type 'QMap<QString,QVariant>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QMAP_QSTRING_QVARIANT_IDX] = Shiboken::Conversions::createConverter(&PyDict_Type, _QMap_QString_QVariant__CppToPython_PyDict);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QMAP_QSTRING_QVARIANT_IDX], "QMap<QString,QVariant>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_QT3DRENDER_QMAP_QSTRING_QVARIANT_IDX],
        PyDict_PythonToCpp__QMap_QString_QVariant_,
        is_PyDict_PythonToCpp__QMap_QString_QVariant__Convertible);


    // Opaque container type registration
    PyObject *ob_type{};
    ob_type = reinterpret_cast<PyObject *>(QIntList_TypeF());
    Py_XINCREF(ob_type);
    PyModule_AddObject(module, "QIntList", ob_type);



    // Register SmartPointer converter for type 'QSharedPointer<Qt3DRender::QTextureImageDataGenerator>'.
    ///////////////////////////////////////////////////////////////////////////////////////

    // Class not found:Qt3DRender::QTextureImageDataGenerator///////////////////////////////////////////////////////////////////////////////////////



    // Register primitive types converters.
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "GLbitfield");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "GLboolean");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), "GLbyte");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<char>(), "GLchar");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<char>(), "GLcharARB");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<double>(), "GLclampd");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<float>(), "GLclampf");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<double>(), "GLdouble");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "GLenum");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "GLfixed");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<float>(), "GLfloat");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "GLhalf");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "GLhalfARB");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "GLhalfNV");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "GLhandleARB");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "GLint");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "GLint64");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "GLint64EXT");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "GLintptr");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "GLintptrARB");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<short>(), "GLshort");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "GLsizei");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "GLsizeiptr");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "GLsizeiptrARB");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "GLubyte");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "GLuint");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "GLuint64");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "GLuint64EXT");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "GLushort");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "GLvdpauSurfaceNV");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLACQUIREKEYEDMUTEXWIN32EXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLAREPROGRAMSRESIDENTNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLARETEXTURESRESIDENTEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLBINDLIGHTPARAMETEREXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLBINDMATERIALPARAMETEREXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLBINDPARAMETEREXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLBINDTEXGENPARAMETEREXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLBINDTEXTUREUNITPARAMETEREXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCHECKFRAMEBUFFERSTATUSEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCHECKFRAMEBUFFERSTATUSPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCHECKNAMEDFRAMEBUFFERSTATUSEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCHECKNAMEDFRAMEBUFFERSTATUSPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCLIENTWAITSYNCPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCREATEPROGRAMOBJECTARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCREATEPROGRAMPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCREATESHADEROBJECTARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCREATESHADERPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCREATESHADERPROGRAMEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCREATESHADERPROGRAMVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLFINISHASYNCSGIXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGENASYNCMARKERSSGIXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGENFRAGMENTSHADERSATIPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGENPATHSNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGENSYMBOLSEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGENVERTEXSHADERSEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETATTRIBLOCATIONARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETATTRIBLOCATIONPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETCOMMANDHEADERNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETDEBUGMESSAGELOGAMDPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETDEBUGMESSAGELOGARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETDEBUGMESSAGELOGPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETFRAGDATAINDEXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETFRAGDATALOCATIONEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETFRAGDATALOCATIONPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETGRAPHICSRESETSTATUSARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETGRAPHICSRESETSTATUSPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETHANDLEARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "PFNGLGETIMAGEHANDLEARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "PFNGLGETIMAGEHANDLENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETINSTRUMENTSSGIXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<float>(), "PFNGLGETPATHLENGTHNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETPROGRAMRESOURCEINDEXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETPROGRAMRESOURCELOCATIONINDEXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETPROGRAMRESOURCELOCATIONPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "PFNGLGETSTAGEINDEXNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLGETSTRINGIPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETSUBROUTINEINDEXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETSUBROUTINEUNIFORMLOCATIONPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "PFNGLGETTEXTUREHANDLEARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "PFNGLGETTEXTUREHANDLENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "PFNGLGETTEXTURESAMPLERHANDLEARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "PFNGLGETTEXTURESAMPLERHANDLENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETUNIFORMBLOCKINDEXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETUNIFORMBUFFERSIZEEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETUNIFORMLOCATIONARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETUNIFORMLOCATIONPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "PFNGLGETUNIFORMOFFSETEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETVARYINGLOCATIONNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISASYNCMARKERSGIXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISBUFFERARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISBUFFERPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISBUFFERRESIDENTNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISCOMMANDLISTNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISENABLEDINDEXEDEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISENABLEDIPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISFENCEAPPLEPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISFENCENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISFRAMEBUFFEREXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISFRAMEBUFFERPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISIMAGEHANDLERESIDENTARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISIMAGEHANDLERESIDENTNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISMEMORYOBJECTEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISNAMEAMDPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISNAMEDBUFFERRESIDENTNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISNAMEDSTRINGARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISOBJECTBUFFERATIPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISOCCLUSIONQUERYNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISPATHNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISPOINTINFILLPATHNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISPOINTINSTROKEPATHNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISPROGRAMARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISPROGRAMNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISPROGRAMPIPELINEPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISPROGRAMPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISQUERYARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISQUERYPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISRENDERBUFFEREXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISRENDERBUFFERPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISSAMPLERPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISSEMAPHOREEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISSHADERPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISSTATENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISSYNCPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISTEXTUREEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISTEXTUREHANDLERESIDENTARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISTEXTUREHANDLERESIDENTNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISTRANSFORMFEEDBACKNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISTRANSFORMFEEDBACKPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISVARIANTENABLEDEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISVERTEXARRAYAPPLEPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISVERTEXARRAYPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISVERTEXATTRIBENABLEDAPPLEPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLNEWOBJECTBUFFERATIPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLOBJECTPURGEABLEAPPLEPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLOBJECTUNPURGEABLEAPPLEPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLPATHGLYPHINDEXARRAYNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLPATHGLYPHINDEXRANGENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLPATHMEMORYGLYPHINDEXARRAYNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLPOINTALONGPATHNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLPOLLASYNCSGIXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLPOLLINSTRUMENTSSGIXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLQUERYMATRIXXOESPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLQUERYRESOURCENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLRELEASEKEYEDMUTEXWIN32EXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLTESTFENCEAPPLEPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLTESTFENCENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLTESTOBJECTAPPLEPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLUNMAPBUFFERARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLUNMAPBUFFERPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLUNMAPNAMEDBUFFEREXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLUNMAPNAMEDBUFFERPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLVDPAUISSURFACENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "PFNGLVDPAUREGISTEROUTPUTSURFACENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "PFNGLVDPAUREGISTERVIDEOSURFACENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "PFNGLVDPAUREGISTERVIDEOSURFACEWITHPICTURESTRUCTURENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLVIDEOCAPTURENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "QRgb");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__blkcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__blkcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__blksize_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<char>(), "__caddr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__clock_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__clockid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__compar_d_fn_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__compar_fn_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__daddr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__dev_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__fsblkcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__fsblkcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__fsfilcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__fsfilcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__fsword_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__gid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__id_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__ino64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__ino_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<short>(), "__int16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__int32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__int64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), "__int8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<short>(), "__int_least16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__int_least32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__int_least64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), "__int_least8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__intmax_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__intptr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__key_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__loff_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__mode_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__nlink_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__off64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__off_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__pid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__quad_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__rlim64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__rlim_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__sig_atomic_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__socklen_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__ssize_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__suseconds64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__suseconds_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__syscall_slong_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__syscall_ulong_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__time_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "__u_char");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__u_int");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__u_long");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__u_quad_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "__u_short");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__uid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "__uint16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__uint32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__uint64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "__uint8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "__uint_least16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__uint_least32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__uint_least64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "__uint_least8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__uintmax_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__useconds_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "blkcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "blkcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "blksize_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<char>(), "caddr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "comparison_fn_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "daddr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "dev_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "fsblkcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "fsblkcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "fsfilcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "fsfilcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "gid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "id_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "ino64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "ino_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "int_fast16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "int_fast32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "int_fast64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), "int_fast8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<short>(), "int_least16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "int_least32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "int_least64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), "int_least8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "intmax_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "key_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "loff_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "mode_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "nlink_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "off64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "off_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "pid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "ptrdiff_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), "qInternalCallback");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "qopengl_GLintptr");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "qopengl_GLsizeiptr");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "quad_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "register_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "ssize_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "suseconds_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "u_char");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "u_int");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "u_int16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "u_int32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "u_int64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "u_int8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "u_long");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "u_quad_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "u_short");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "uid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uint_fast16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uint_fast32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uint_fast64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "uint_fast8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "uint_least16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "uint_least32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uint_least64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "uint_least8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uintmax_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "useconds_t");

    Shiboken::Module::registerTypes(module, SbkPySide6_Qt3DRenderTypes);
    Shiboken::Module::registerTypeConverters(module, SbkPySide6_Qt3DRenderTypeConverters);

    if (Shiboken::Errors::occurred() != nullptr) {
        PyErr_Print();
        Py_FatalError("can't initialize module Qt3DRender");
    }
    PySide::registerCleanupFunction(cleanTypesAttributes);

    FinishSignatureInitialization(module, Qt3DRender_SignatureStrings);

    return module;
}
