// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

#include <sbkpython.h>
#include <shiboken.h>
#include <algorithm>
#include <signature.h>
#include <sbkcontainer.h>
#include <sbkstaticstrings.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysidecleanup.h>
#include <pysideqenum.h>
#include <feature_select.h>
#include <pysidestaticstrings.h>
#include "pyside6_qtgui_python.h"

#include <QHash>
#include <QInputMethodEvent>
#include <QList>
#include <QMap>
#include <QPainterPath>
#include <QSet>
#include <QString>
#include <QTextLayout>
#include <QtGui/qabstracttextdocumentlayout.h>
#include <QtGui/qaccessible.h>
#include <QtGui/qaction.h>
#include <QtGui/qcolor.h>
#include <QtGui/qeventpoint.h>
#include <QtGui/qfontdatabase.h>
#include <QtGui/qglyphrun.h>
#include <QtGui/qinputdevice.h>
#include <QtGui/qkeysequence.h>
#include <QtGui/qopenglcontext.h>
#include <QtGui/qpageranges.h>
#include <QtGui/qpixelformat.h>
#include <QtGui/qpolygon.h>
#include <QtGui/qrgb.h>
#include <QtGui/qscreen.h>
#include <QtGui/qstandarditemmodel.h>
#include <QtGui/qtextformat.h>
#include <QtGui/qtextobject.h>
#include <QtGui/qtextoption.h>
#include <QtGui/qundostack.h>
#include <QtGui/qvectornd.h>
#include <QtGui/qwindow.h>
#include <array>
#include <qabstractitemmodel.h>
#include <qbytearray.h>
#include <qline.h>
#include <qobject.h>
#include <qpoint.h>
#include <qrect.h>
#include <qsize.h>
#include <qvariant.h>
#include <rhi/qrhi.h>
#include <rhi/qshader.h>
#include <utility>


// Current module's type array.
PyTypeObject **SbkPySide6_QtGuiTypes = nullptr;
// Current module's PyObject pointer.
PyObject *SbkPySide6_QtGuiModuleObject = nullptr;
// Current module's converter array.
SbkConverter **SbkPySide6_QtGuiTypeConverters = nullptr;
// Begin code injection
// ========================================================================
// START of custom code block [file: ../glue/qtgui.cpp (gui-declarations)]
void qt_set_sequence_auto_mnemonic(bool);
// END of custom code block [file: ../glue/qtgui.cpp (gui-declarations)]
// ========================================================================
// End of code injection

void cleanTypesAttributes() {
    static PyObject *attrName = Shiboken::PyName::qtStaticMetaObject();
    for (int i = 0, imax = SBK_QtGui_IDX_COUNT; i < imax; i++) {
        PyObject *pyType = reinterpret_cast<PyObject *>(SbkPySide6_QtGuiTypes[i]);
        if (pyType && PyObject_HasAttr(pyType, attrName))
            PyObject_SetAttr(pyType, attrName, Py_None);
    }
}
// Global functions ------------------------------------------------------------
static PyObject *SbkQtGuiModule_qAlpha(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.qAlpha";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: qAlpha(uint)->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // qAlpha(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qAlpha(uint)
            int cppResult = qAlpha(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtGuiModule_qBlue(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.qBlue";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: qBlue(uint)->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // qBlue(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qBlue(uint)
            int cppResult = qBlue(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtGuiModule_qFuzzyCompare(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.qFuzzyCompare";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "qFuzzyCompare", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qFuzzyCompare(QTransform,QTransform)->bool
    // 1: qFuzzyCompare(QQuaternion,QQuaternion)->bool
    // 2: qFuzzyCompare(QMatrix4x4,QMatrix4x4)->bool
    // 3: qFuzzyCompare(QVector2D,QVector2D)->bool
    // 4: qFuzzyCompare(QVector3D,QVector3D)->bool
    // 5: qFuzzyCompare(QVector4D,QVector4D)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(SbkPySide6_QtGuiTypes[SBK_QVECTOR4D_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(SbkPySide6_QtGuiTypes[SBK_QVECTOR4D_IDX], (pyArgs[1])))) {
        overloadId = 5; // qFuzzyCompare(QVector4D,QVector4D)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(SbkPySide6_QtGuiTypes[SBK_QVECTOR3D_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(SbkPySide6_QtGuiTypes[SBK_QVECTOR3D_IDX], (pyArgs[1])))) {
        overloadId = 4; // qFuzzyCompare(QVector3D,QVector3D)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(SbkPySide6_QtGuiTypes[SBK_QVECTOR2D_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(SbkPySide6_QtGuiTypes[SBK_QVECTOR2D_IDX], (pyArgs[1])))) {
        overloadId = 3; // qFuzzyCompare(QVector2D,QVector2D)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(SbkPySide6_QtGuiTypes[SBK_QQUATERNION_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(SbkPySide6_QtGuiTypes[SBK_QQUATERNION_IDX], (pyArgs[1])))) {
        overloadId = 1; // qFuzzyCompare(QQuaternion,QQuaternion)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(SbkPySide6_QtGuiTypes[SBK_QTRANSFORM_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(SbkPySide6_QtGuiTypes[SBK_QTRANSFORM_IDX], (pyArgs[1])))) {
        overloadId = 0; // qFuzzyCompare(QTransform,QTransform)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(SbkPySide6_QtGuiTypes[SBK_QMATRIX4X4_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(SbkPySide6_QtGuiTypes[SBK_QMATRIX4X4_IDX], (pyArgs[1])))) {
        overloadId = 2; // qFuzzyCompare(QMatrix4x4,QMatrix4x4)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // qFuzzyCompare(QTransform arg__1, QTransform arg__2)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QTransform cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QTransform cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qFuzzyCompare(QTransform,QTransform)
                bool cppResult = qFuzzyCompare(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // qFuzzyCompare(QQuaternion arg__1, QQuaternion arg__2)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QQuaternion cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QQuaternion cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qFuzzyCompare(QQuaternion,QQuaternion)
                bool cppResult = qFuzzyCompare(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 2: // qFuzzyCompare(QMatrix4x4 arg__1, QMatrix4x4 arg__2)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QMatrix4x4 cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QMatrix4x4 cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qFuzzyCompare(QMatrix4x4,QMatrix4x4)
                bool cppResult = qFuzzyCompare(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 3: // qFuzzyCompare(QVector2D arg__1, QVector2D arg__2)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QVector2D cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QVector2D cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qFuzzyCompare(QVector2D,QVector2D)
                bool cppResult = qFuzzyCompare(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 4: // qFuzzyCompare(QVector3D arg__1, QVector3D arg__2)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QVector3D cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QVector3D cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qFuzzyCompare(QVector3D,QVector3D)
                bool cppResult = qFuzzyCompare(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 5: // qFuzzyCompare(QVector4D arg__1, QVector4D arg__2)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QVector4D cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QVector4D cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qFuzzyCompare(QVector4D,QVector4D)
                bool cppResult = qFuzzyCompare(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtGuiModule_qGray(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.qGray";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_UnpackTuple(args, "qGray", 1, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qGray(uint)->int
    // 1: qGray(int,int,int)->int
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        overloadId = 1; // qGray(int,int,int)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))) {
        overloadId = 0; // qGray(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // qGray(unsigned int rgb)
        {
            unsigned int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qGray(uint)
                int cppResult = qGray(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            }
            break;
        }
        case 1: // qGray(int r, int g, int b)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qGray(int,int,int)
                int cppResult = qGray(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtGuiModule_qGreen(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.qGreen";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: qGreen(uint)->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // qGreen(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qGreen(uint)
            int cppResult = qGreen(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtGuiModule_qIsGray(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.qIsGray";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: qIsGray(uint)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // qIsGray(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qIsGray(uint)
            bool cppResult = qIsGray(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtGuiModule_qPixelFormatAlpha(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.qPixelFormatAlpha";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:qPixelFormatAlpha", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qPixelFormatAlpha(uchar,QPixelFormat::TypeInterpretation=)->QPixelFormat
    if (numArgs >= 1
        && SbkChar_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // qPixelFormatAlpha(uchar,QPixelFormat::TypeInterpretation)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_TYPEINTERPRETATION_IDX]))->converter, (pyArgs[1])))) {
            overloadId = 0; // qPixelFormatAlpha(uchar,QPixelFormat::TypeInterpretation)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_typeInt = Shiboken::String::createStaticString("typeInt");
            if (PyDict_Contains(kwds, key_typeInt) != 0) {
                value = PyDict_GetItem(kwds, key_typeInt);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_typeInt);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_TYPEINTERPRETATION_IDX]))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_typeInt);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        uchar cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QPixelFormat::TypeInterpretation cppArg1(QPixelFormat::UnsignedInteger);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qPixelFormatAlpha(uchar,QPixelFormat::TypeInterpretation)
            QPixelFormat cppResult = qPixelFormatAlpha(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtGuiModule_qPixelFormatCmyk(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.qPixelFormatCmyk";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOOO:qPixelFormatCmyk", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qPixelFormatCmyk(uchar,uchar=,QPixelFormat::AlphaUsage=,QPixelFormat::AlphaPosition=,QPixelFormat::TypeInterpretation=)->QPixelFormat
    if (numArgs >= 1
        && SbkChar_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // qPixelFormatCmyk(uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::TypeInterpretation)
        } else if (numArgs >= 2
            && SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // qPixelFormatCmyk(uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::TypeInterpretation)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_ALPHAUSAGE_IDX]))->converter, (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // qPixelFormatCmyk(uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::TypeInterpretation)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_ALPHAPOSITION_IDX]))->converter, (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 0; // qPixelFormatCmyk(uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::TypeInterpretation)
                    } else if (numArgs >= 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_TYPEINTERPRETATION_IDX]))->converter, (pyArgs[4])))) {
                        overloadId = 0; // qPixelFormatCmyk(uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::TypeInterpretation)
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_alfa = Shiboken::String::createStaticString("alfa");
            if (PyDict_Contains(kwds, key_alfa) != 0) {
                value = PyDict_GetItem(kwds, key_alfa);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_alfa);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_alfa);
            }
            static PyObject *const key_usage = Shiboken::String::createStaticString("usage");
            if (PyDict_Contains(kwds, key_usage) != 0) {
                value = PyDict_GetItem(kwds, key_usage);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_usage);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_ALPHAUSAGE_IDX]))->converter, (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_usage);
            }
            static PyObject *const key_position = Shiboken::String::createStaticString("position");
            if (PyDict_Contains(kwds, key_position) != 0) {
                value = PyDict_GetItem(kwds, key_position);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_position);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_ALPHAPOSITION_IDX]))->converter, (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_position);
            }
            static PyObject *const key_typeInt = Shiboken::String::createStaticString("typeInt");
            if (PyDict_Contains(kwds, key_typeInt) != 0) {
                value = PyDict_GetItem(kwds, key_typeInt);
                if (value != nullptr && pyArgs[4] != nullptr ) {
                    errInfo.reset(key_typeInt);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[4] = value;
                    if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_TYPEINTERPRETATION_IDX]))->converter, (pyArgs[4]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_typeInt);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        uchar cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        uchar cppArg1 = 0;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QPixelFormat::AlphaUsage cppArg2(QPixelFormat::IgnoresAlpha);
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);
        ::QPixelFormat::AlphaPosition cppArg3(QPixelFormat::AtBeginning);
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);
        ::QPixelFormat::TypeInterpretation cppArg4(QPixelFormat::UnsignedInteger);
        if (pythonToCpp[4])
            pythonToCpp[4](pyArgs[4], &cppArg4);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qPixelFormatCmyk(uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::TypeInterpretation)
            QPixelFormat cppResult = qPixelFormatCmyk(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtGuiModule_qPixelFormatGrayscale(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.qPixelFormatGrayscale";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:qPixelFormatGrayscale", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qPixelFormatGrayscale(uchar,QPixelFormat::TypeInterpretation=)->QPixelFormat
    if (numArgs >= 1
        && SbkChar_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // qPixelFormatGrayscale(uchar,QPixelFormat::TypeInterpretation)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_TYPEINTERPRETATION_IDX]))->converter, (pyArgs[1])))) {
            overloadId = 0; // qPixelFormatGrayscale(uchar,QPixelFormat::TypeInterpretation)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_typeInt = Shiboken::String::createStaticString("typeInt");
            if (PyDict_Contains(kwds, key_typeInt) != 0) {
                value = PyDict_GetItem(kwds, key_typeInt);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_typeInt);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_TYPEINTERPRETATION_IDX]))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_typeInt);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        uchar cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QPixelFormat::TypeInterpretation cppArg1(QPixelFormat::UnsignedInteger);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qPixelFormatGrayscale(uchar,QPixelFormat::TypeInterpretation)
            QPixelFormat cppResult = qPixelFormatGrayscale(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtGuiModule_qPixelFormatHsl(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.qPixelFormatHsl";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOOO:qPixelFormatHsl", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qPixelFormatHsl(uchar,uchar=,QPixelFormat::AlphaUsage=,QPixelFormat::AlphaPosition=,QPixelFormat::TypeInterpretation=)->QPixelFormat
    if (numArgs >= 1
        && SbkChar_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // qPixelFormatHsl(uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::TypeInterpretation)
        } else if (numArgs >= 2
            && SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // qPixelFormatHsl(uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::TypeInterpretation)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_ALPHAUSAGE_IDX]))->converter, (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // qPixelFormatHsl(uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::TypeInterpretation)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_ALPHAPOSITION_IDX]))->converter, (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 0; // qPixelFormatHsl(uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::TypeInterpretation)
                    } else if (numArgs >= 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_TYPEINTERPRETATION_IDX]))->converter, (pyArgs[4])))) {
                        overloadId = 0; // qPixelFormatHsl(uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::TypeInterpretation)
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_alfa = Shiboken::String::createStaticString("alfa");
            if (PyDict_Contains(kwds, key_alfa) != 0) {
                value = PyDict_GetItem(kwds, key_alfa);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_alfa);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_alfa);
            }
            static PyObject *const key_usage = Shiboken::String::createStaticString("usage");
            if (PyDict_Contains(kwds, key_usage) != 0) {
                value = PyDict_GetItem(kwds, key_usage);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_usage);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_ALPHAUSAGE_IDX]))->converter, (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_usage);
            }
            static PyObject *const key_position = Shiboken::String::createStaticString("position");
            if (PyDict_Contains(kwds, key_position) != 0) {
                value = PyDict_GetItem(kwds, key_position);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_position);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_ALPHAPOSITION_IDX]))->converter, (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_position);
            }
            static PyObject *const key_typeInt = Shiboken::String::createStaticString("typeInt");
            if (PyDict_Contains(kwds, key_typeInt) != 0) {
                value = PyDict_GetItem(kwds, key_typeInt);
                if (value != nullptr && pyArgs[4] != nullptr ) {
                    errInfo.reset(key_typeInt);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[4] = value;
                    if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_TYPEINTERPRETATION_IDX]))->converter, (pyArgs[4]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_typeInt);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        uchar cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        uchar cppArg1 = 0;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QPixelFormat::AlphaUsage cppArg2(QPixelFormat::IgnoresAlpha);
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);
        ::QPixelFormat::AlphaPosition cppArg3(QPixelFormat::AtBeginning);
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);
        ::QPixelFormat::TypeInterpretation cppArg4(QPixelFormat::FloatingPoint);
        if (pythonToCpp[4])
            pythonToCpp[4](pyArgs[4], &cppArg4);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qPixelFormatHsl(uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::TypeInterpretation)
            QPixelFormat cppResult = qPixelFormatHsl(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtGuiModule_qPixelFormatHsv(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.qPixelFormatHsv";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOOO:qPixelFormatHsv", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qPixelFormatHsv(uchar,uchar=,QPixelFormat::AlphaUsage=,QPixelFormat::AlphaPosition=,QPixelFormat::TypeInterpretation=)->QPixelFormat
    if (numArgs >= 1
        && SbkChar_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // qPixelFormatHsv(uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::TypeInterpretation)
        } else if (numArgs >= 2
            && SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // qPixelFormatHsv(uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::TypeInterpretation)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_ALPHAUSAGE_IDX]))->converter, (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // qPixelFormatHsv(uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::TypeInterpretation)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_ALPHAPOSITION_IDX]))->converter, (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 0; // qPixelFormatHsv(uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::TypeInterpretation)
                    } else if (numArgs >= 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_TYPEINTERPRETATION_IDX]))->converter, (pyArgs[4])))) {
                        overloadId = 0; // qPixelFormatHsv(uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::TypeInterpretation)
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_alfa = Shiboken::String::createStaticString("alfa");
            if (PyDict_Contains(kwds, key_alfa) != 0) {
                value = PyDict_GetItem(kwds, key_alfa);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_alfa);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_alfa);
            }
            static PyObject *const key_usage = Shiboken::String::createStaticString("usage");
            if (PyDict_Contains(kwds, key_usage) != 0) {
                value = PyDict_GetItem(kwds, key_usage);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_usage);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_ALPHAUSAGE_IDX]))->converter, (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_usage);
            }
            static PyObject *const key_position = Shiboken::String::createStaticString("position");
            if (PyDict_Contains(kwds, key_position) != 0) {
                value = PyDict_GetItem(kwds, key_position);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_position);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_ALPHAPOSITION_IDX]))->converter, (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_position);
            }
            static PyObject *const key_typeInt = Shiboken::String::createStaticString("typeInt");
            if (PyDict_Contains(kwds, key_typeInt) != 0) {
                value = PyDict_GetItem(kwds, key_typeInt);
                if (value != nullptr && pyArgs[4] != nullptr ) {
                    errInfo.reset(key_typeInt);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[4] = value;
                    if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_TYPEINTERPRETATION_IDX]))->converter, (pyArgs[4]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_typeInt);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        uchar cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        uchar cppArg1 = 0;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QPixelFormat::AlphaUsage cppArg2(QPixelFormat::IgnoresAlpha);
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);
        ::QPixelFormat::AlphaPosition cppArg3(QPixelFormat::AtBeginning);
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);
        ::QPixelFormat::TypeInterpretation cppArg4(QPixelFormat::FloatingPoint);
        if (pythonToCpp[4])
            pythonToCpp[4](pyArgs[4], &cppArg4);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qPixelFormatHsv(uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::TypeInterpretation)
            QPixelFormat cppResult = qPixelFormatHsv(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtGuiModule_qPixelFormatRgba(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.qPixelFormatRgba";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[8];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 6, 8));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOOOOOO:qPixelFormatRgba", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qPixelFormatRgba(uchar,uchar,uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::AlphaPremultiplied=,QPixelFormat::TypeInterpretation=)->QPixelFormat
    if (numArgs >= 6
        && SbkChar_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[0])))
        && SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[1])))
        && SbkChar_Check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[2])))
        && SbkChar_Check(pyArgs[3]) && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_ALPHAUSAGE_IDX]))->converter, (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_ALPHAPOSITION_IDX]))->converter, (pyArgs[5])))) {
        if (numArgs == 6) {
            overloadId = 0; // qPixelFormatRgba(uchar,uchar,uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::AlphaPremultiplied,QPixelFormat::TypeInterpretation)
        } else if (numArgs >= 7
            && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_ALPHAPREMULTIPLIED_IDX]))->converter, (pyArgs[6])))) {
            if (numArgs == 7) {
                overloadId = 0; // qPixelFormatRgba(uchar,uchar,uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::AlphaPremultiplied,QPixelFormat::TypeInterpretation)
            } else if (numArgs >= 8
                && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_TYPEINTERPRETATION_IDX]))->converter, (pyArgs[7])))) {
                overloadId = 0; // qPixelFormatRgba(uchar,uchar,uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::AlphaPremultiplied,QPixelFormat::TypeInterpretation)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_pmul = Shiboken::String::createStaticString("pmul");
            if (PyDict_Contains(kwds, key_pmul) != 0) {
                value = PyDict_GetItem(kwds, key_pmul);
                if (value != nullptr && pyArgs[6] != nullptr ) {
                    errInfo.reset(key_pmul);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[6] = value;
                    if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_ALPHAPREMULTIPLIED_IDX]))->converter, (pyArgs[6]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_pmul);
            }
            static PyObject *const key_typeInt = Shiboken::String::createStaticString("typeInt");
            if (PyDict_Contains(kwds, key_typeInt) != 0) {
                value = PyDict_GetItem(kwds, key_typeInt);
                if (value != nullptr && pyArgs[7] != nullptr ) {
                    errInfo.reset(key_typeInt);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[7] = value;
                    if (!(pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_TYPEINTERPRETATION_IDX]))->converter, (pyArgs[7]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_typeInt);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        uchar cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        uchar cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        uchar cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        uchar cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        ::QPixelFormat::AlphaUsage cppArg4{QPixelFormat::UsesAlpha};
        pythonToCpp[4](pyArgs[4], &cppArg4);
        ::QPixelFormat::AlphaPosition cppArg5{QPixelFormat::AtBeginning};
        pythonToCpp[5](pyArgs[5], &cppArg5);
        ::QPixelFormat::AlphaPremultiplied cppArg6(QPixelFormat::NotPremultiplied);
        if (pythonToCpp[6])
            pythonToCpp[6](pyArgs[6], &cppArg6);
        ::QPixelFormat::TypeInterpretation cppArg7(QPixelFormat::UnsignedInteger);
        if (pythonToCpp[7])
            pythonToCpp[7](pyArgs[7], &cppArg7);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qPixelFormatRgba(uchar,uchar,uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::AlphaPremultiplied,QPixelFormat::TypeInterpretation)
            QPixelFormat cppResult = qPixelFormatRgba(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtGuiModule_qPixelFormatYuv(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.qPixelFormatYuv";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[7];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 7));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOOOOO:qPixelFormatYuv", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qPixelFormatYuv(QPixelFormat::YUVLayout,uchar=,QPixelFormat::AlphaUsage=,QPixelFormat::AlphaPosition=,QPixelFormat::AlphaPremultiplied=,QPixelFormat::TypeInterpretation=,QPixelFormat::ByteOrder=)->QPixelFormat
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_YUVLAYOUT_IDX]))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // qPixelFormatYuv(QPixelFormat::YUVLayout,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::AlphaPremultiplied,QPixelFormat::TypeInterpretation,QPixelFormat::ByteOrder)
        } else if (numArgs >= 2
            && SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // qPixelFormatYuv(QPixelFormat::YUVLayout,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::AlphaPremultiplied,QPixelFormat::TypeInterpretation,QPixelFormat::ByteOrder)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_ALPHAUSAGE_IDX]))->converter, (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // qPixelFormatYuv(QPixelFormat::YUVLayout,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::AlphaPremultiplied,QPixelFormat::TypeInterpretation,QPixelFormat::ByteOrder)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_ALPHAPOSITION_IDX]))->converter, (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 0; // qPixelFormatYuv(QPixelFormat::YUVLayout,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::AlphaPremultiplied,QPixelFormat::TypeInterpretation,QPixelFormat::ByteOrder)
                    } else if (numArgs >= 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_ALPHAPREMULTIPLIED_IDX]))->converter, (pyArgs[4])))) {
                        if (numArgs == 5) {
                            overloadId = 0; // qPixelFormatYuv(QPixelFormat::YUVLayout,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::AlphaPremultiplied,QPixelFormat::TypeInterpretation,QPixelFormat::ByteOrder)
                        } else if (numArgs >= 6
                            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_TYPEINTERPRETATION_IDX]))->converter, (pyArgs[5])))) {
                            if (numArgs == 6) {
                                overloadId = 0; // qPixelFormatYuv(QPixelFormat::YUVLayout,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::AlphaPremultiplied,QPixelFormat::TypeInterpretation,QPixelFormat::ByteOrder)
                            } else if (numArgs >= 7
                                && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_BYTEORDER_IDX]))->converter, (pyArgs[6])))) {
                                overloadId = 0; // qPixelFormatYuv(QPixelFormat::YUVLayout,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::AlphaPremultiplied,QPixelFormat::TypeInterpretation,QPixelFormat::ByteOrder)
                            }
                        }
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_alfa = Shiboken::String::createStaticString("alfa");
            if (PyDict_Contains(kwds, key_alfa) != 0) {
                value = PyDict_GetItem(kwds, key_alfa);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_alfa);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_alfa);
            }
            static PyObject *const key_usage = Shiboken::String::createStaticString("usage");
            if (PyDict_Contains(kwds, key_usage) != 0) {
                value = PyDict_GetItem(kwds, key_usage);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_usage);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_ALPHAUSAGE_IDX]))->converter, (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_usage);
            }
            static PyObject *const key_position = Shiboken::String::createStaticString("position");
            if (PyDict_Contains(kwds, key_position) != 0) {
                value = PyDict_GetItem(kwds, key_position);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_position);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_ALPHAPOSITION_IDX]))->converter, (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_position);
            }
            static PyObject *const key_p_mul = Shiboken::String::createStaticString("p_mul");
            if (PyDict_Contains(kwds, key_p_mul) != 0) {
                value = PyDict_GetItem(kwds, key_p_mul);
                if (value != nullptr && pyArgs[4] != nullptr ) {
                    errInfo.reset(key_p_mul);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[4] = value;
                    if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_ALPHAPREMULTIPLIED_IDX]))->converter, (pyArgs[4]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_p_mul);
            }
            static PyObject *const key_typeInt = Shiboken::String::createStaticString("typeInt");
            if (PyDict_Contains(kwds, key_typeInt) != 0) {
                value = PyDict_GetItem(kwds, key_typeInt);
                if (value != nullptr && pyArgs[5] != nullptr ) {
                    errInfo.reset(key_typeInt);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[5] = value;
                    if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_TYPEINTERPRETATION_IDX]))->converter, (pyArgs[5]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_typeInt);
            }
            static PyObject *const key_b_order = Shiboken::String::createStaticString("b_order");
            if (PyDict_Contains(kwds, key_b_order) != 0) {
                value = PyDict_GetItem(kwds, key_b_order);
                if (value != nullptr && pyArgs[6] != nullptr ) {
                    errInfo.reset(key_b_order);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[6] = value;
                    if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_BYTEORDER_IDX]))->converter, (pyArgs[6]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_b_order);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QPixelFormat::YUVLayout cppArg0{QPixelFormat::YUV444};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        uchar cppArg1 = 0;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QPixelFormat::AlphaUsage cppArg2(QPixelFormat::IgnoresAlpha);
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);
        ::QPixelFormat::AlphaPosition cppArg3(QPixelFormat::AtBeginning);
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);
        ::QPixelFormat::AlphaPremultiplied cppArg4(QPixelFormat::NotPremultiplied);
        if (pythonToCpp[4])
            pythonToCpp[4](pyArgs[4], &cppArg4);
        ::QPixelFormat::TypeInterpretation cppArg5(QPixelFormat::UnsignedByte);
        if (pythonToCpp[5])
            pythonToCpp[5](pyArgs[5], &cppArg5);
        ::QPixelFormat::ByteOrder cppArg6(QPixelFormat::LittleEndian);
        if (pythonToCpp[6])
            pythonToCpp[6](pyArgs[6], &cppArg6);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qPixelFormatYuv(QPixelFormat::YUVLayout,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::AlphaPremultiplied,QPixelFormat::TypeInterpretation,QPixelFormat::ByteOrder)
            QPixelFormat cppResult = qPixelFormatYuv(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypes[SBK_QPIXELFORMAT_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtGuiModule_qRed(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.qRed";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: qRed(uint)->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // qRed(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qRed(uint)
            int cppResult = qRed(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtGuiModule_qRgb(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.qRgb";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "qRgb", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qRgb(int,int,int)->unsigned int
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        overloadId = 0; // qRgb(int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qRgb(int,int,int)
            unsigned int cppResult = qRgb(cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtGuiModule_qRgba(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.qRgba";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "qRgba", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qRgba(int,int,int,int)->unsigned int
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
        overloadId = 0; // qRgba(int,int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qRgba(int,int,int,int)
            unsigned int cppResult = qRgba(cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtGuiModule_qt_set_sequence_auto_mnemonic(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.qt_set_sequence_auto_mnemonic";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: qt_set_sequence_auto_mnemonic(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // qt_set_sequence_auto_mnemonic(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qt_set_sequence_auto_mnemonic(bool)
            qt_set_sequence_auto_mnemonic(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static PyMethodDef QtGui_methods[] = {
    {"qAlpha", reinterpret_cast<PyCFunction>(SbkQtGuiModule_qAlpha), METH_O, nullptr},
    {"qBlue", reinterpret_cast<PyCFunction>(SbkQtGuiModule_qBlue), METH_O, nullptr},
    {"qFuzzyCompare", reinterpret_cast<PyCFunction>(SbkQtGuiModule_qFuzzyCompare), METH_VARARGS, nullptr},
    {"qGray", reinterpret_cast<PyCFunction>(SbkQtGuiModule_qGray), METH_VARARGS, nullptr},
    {"qGreen", reinterpret_cast<PyCFunction>(SbkQtGuiModule_qGreen), METH_O, nullptr},
    {"qIsGray", reinterpret_cast<PyCFunction>(SbkQtGuiModule_qIsGray), METH_O, nullptr},
    {"qPixelFormatAlpha", reinterpret_cast<PyCFunction>(SbkQtGuiModule_qPixelFormatAlpha), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"qPixelFormatCmyk", reinterpret_cast<PyCFunction>(SbkQtGuiModule_qPixelFormatCmyk), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"qPixelFormatGrayscale", reinterpret_cast<PyCFunction>(SbkQtGuiModule_qPixelFormatGrayscale), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"qPixelFormatHsl", reinterpret_cast<PyCFunction>(SbkQtGuiModule_qPixelFormatHsl), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"qPixelFormatHsv", reinterpret_cast<PyCFunction>(SbkQtGuiModule_qPixelFormatHsv), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"qPixelFormatRgba", reinterpret_cast<PyCFunction>(SbkQtGuiModule_qPixelFormatRgba), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"qPixelFormatYuv", reinterpret_cast<PyCFunction>(SbkQtGuiModule_qPixelFormatYuv), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"qRed", reinterpret_cast<PyCFunction>(SbkQtGuiModule_qRed), METH_O, nullptr},
    {"qRgb", reinterpret_cast<PyCFunction>(SbkQtGuiModule_qRgb), METH_VARARGS, nullptr},
    {"qRgba", reinterpret_cast<PyCFunction>(SbkQtGuiModule_qRgba), METH_VARARGS, nullptr},
    {"qt_set_sequence_auto_mnemonic", reinterpret_cast<PyCFunction>(SbkQtGuiModule_qt_set_sequence_auto_mnemonic), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Classes initialization functions ------------------------------------------------------------
void init_QtGuiQt(PyObject *module);
void init_QVector4D(PyObject *module);
void init_QVector3D(PyObject *module);
void init_QVector2D(PyObject *module);
void init_QUndoCommand(PyObject *module);
void init_QTransform(PyObject *module);
void init_QTextTableCell(PyObject *module);
void init_QTextOption(PyObject *module);
void init_QTextOption_Tab(PyObject *enclosingClass);
void init_QTextObjectInterface(PyObject *module);
void init_QTextLine(PyObject *module);
void init_QTextLength(PyObject *module);
void init_QTextItem(PyObject *module);
void init_QTextInlineObject(PyObject *module);
void init_QTextFragment(PyObject *module);
void init_QTextFormat(PyObject *module);
void init_QTextListFormat(PyObject *module);
void init_QTextFrameFormat(PyObject *module);
void init_QTextTableFormat(PyObject *module);
void init_QTextDocumentFragment(PyObject *module);
void init_QTextCursor(PyObject *module);
void init_QTextCharFormat(PyObject *module);
void init_QTextTableCellFormat(PyObject *module);
void init_QTextImageFormat(PyObject *module);
void init_QTextBlockUserData(PyObject *module);
void init_QTextBlockFormat(PyObject *module);
void init_QTextBlock(PyObject *module);
void init_QTextBlock_iterator(PyObject *enclosingClass);
void init_QSurfaceFormat(PyObject *module);
void init_QSurface(PyObject *module);
void init_QStandardItem(PyObject *module);
void init_QShaderVersion(PyObject *module);
void init_QShaderKey(PyObject *module);
void init_QShader(PyObject *module);
void init_QRhiViewport(PyObject *module);
void init_QRhiVertexInputLayout(PyObject *module);
void init_QRhiVertexInputBinding(PyObject *module);
void init_QRhiVertexInputAttribute(PyObject *module);
void init_QRhiTextureUploadEntry(PyObject *module);
void init_QRhiTextureUploadDescription(PyObject *module);
void init_QRhiTextureSubresourceUploadDescription(PyObject *module);
void init_QRhiTextureRenderTargetDescription(PyObject *module);
void init_QRhiTextureCopyDescription(PyObject *module);
void init_QRhiStats(PyObject *module);
void init_QRhiShaderStage(PyObject *module);
void init_QRhiShaderResourceBinding(PyObject *module);
void init_QRhiShaderResourceBindingStaticFields();
void init_QRhiShaderResourceBinding_Data(PyObject *enclosingClass);
void init_QRhiShaderResourceBinding_DataStaticFields();
void init_QRhiScissor(PyObject *module);
void init_QRhiResourceUpdateBatch(PyObject *module);
void init_QRhiReadbackDescription(PyObject *module);
void init_QRhiNativeHandles(PyObject *module);
void init_QRhiInitParams(PyObject *module);
void init_QRhiNullInitParams(PyObject *module);
void init_QRhiDepthStencilClearValue(PyObject *module);
void init_QRhiColorAttachment(PyObject *module);
void init_QRhi(PyObject *module);
void init_QRhiStaticFields();
void init_QRgba64(PyObject *module);
void init_QRegion(PyObject *module);
void init_QRawFont(PyObject *module);
void init_QQuaternion(PyObject *module);
void init_QPolygonF(PyObject *module);
void init_QPolygon(PyObject *module);
void init_QPointingDeviceUniqueId(PyObject *module);
void init_QPixmapCache(PyObject *module);
void init_QPixmapCache_Key(PyObject *enclosingClass);
void init_QPixelFormat(PyObject *module);
void init_QPen(PyObject *module);
void init_QPalette(PyObject *module);
void init_QPainterPathStroker(PyObject *module);
void init_QPainterPath(PyObject *module);
void init_QPainterPath_Element(PyObject *enclosingClass);
void init_QPaintEngineState(PyObject *module);
void init_QPaintEngine(PyObject *module);
void init_QPaintDevice(PyObject *module);
void init_QPicture(PyObject *module);
void init_QPagedPaintDevice(PyObject *module);
void init_QPageSize(PyObject *module);
void init_QPageRanges(PyObject *module);
void init_QPageRanges_Range(PyObject *enclosingClass);
void init_QtGuiHelper_QOverrideCursorGuard(PyObject *module);
void init_QOpenGLFunctions(PyObject *module);
void init_QOpenGLExtraFunctions(PyObject *module);
void init_QMatrix4x4(PyObject *module);
void init_QMatrix4x3(PyObject *module);
void init_QMatrix4x2(PyObject *module);
void init_QMatrix3x4(PyObject *module);
void init_QMatrix3x3(PyObject *module);
void init_QMatrix3x2(PyObject *module);
void init_QMatrix2x4(PyObject *module);
void init_QMatrix2x3(PyObject *module);
void init_QMatrix2x2(PyObject *module);
void init_QImageIOHandler(PyObject *module);
void init_QIconEngine(PyObject *module);
void init_QGradient(PyObject *module);
void init_QRadialGradient(PyObject *module);
void init_QLinearGradient(PyObject *module);
void init_QGlyphRun(PyObject *module);
void init_QFontMetricsF(PyObject *module);
void init_QFontMetrics(PyObject *module);
void init_QFontInfo(PyObject *module);
void init_QFontDatabase(PyObject *module);
void init_QFont(PyObject *module);
void init_QStaticText(PyObject *module);
void init_QEventPoint(PyObject *module);
void init_QDesktopServices(PyObject *module);
void init_QCursor(PyObject *module);
void init_QConicalGradient(PyObject *module);
void init_QColorTransform(PyObject *module);
void init_QColorSpace(PyObject *module);
void init_QColor(PyObject *module);
void init_QtGuiQColorConstants(PyObject *module);
void init_QtGuiQColorConstantsStaticFields();
void init_QtGuiQColorConstants_Svg(PyObject *enclosingClass);
void init_QtGuiQColorConstants_SvgStaticFields();
void init_QBrush(PyObject *module);
void init_QAccessibleValueInterface(PyObject *module);
void init_QAccessibleTextInterface(PyObject *module);
void init_QAccessibleTableCellInterface(PyObject *module);
void init_QAccessibleInterface(PyObject *module);
void init_QAccessibleObject(PyObject *module);
void init_QAccessibleEvent(PyObject *module);
void init_QAccessibleValueChangeEvent(PyObject *module);
void init_QAccessibleTextCursorEvent(PyObject *module);
void init_QAccessibleTextUpdateEvent(PyObject *module);
void init_QAccessibleTextSelectionEvent(PyObject *module);
void init_QAccessibleTextRemoveEvent(PyObject *module);
void init_QAccessibleTextInsertEvent(PyObject *module);
void init_QAccessibleTableModelChangeEvent(PyObject *module);
void init_QAccessibleStateChangeEvent(PyObject *module);
void init_QAccessibleEditableTextInterface(PyObject *module);
void init_QAccessibleActionInterface(PyObject *module);
void init_QAccessible(PyObject *module);
void init_QAccessible_State(PyObject *enclosingClass);
void init_QAbstractFileIconProvider(PyObject *module);
void init_QIcon(PyObject *module);
void init_QTextLayout(PyObject *module);
void init_QTextLayout_FormatRange(PyObject *enclosingClass);
void init_QPixmap(PyObject *module);
void init_QIconEngine_ScaledPixmapArgument(PyObject *enclosingClass);
void init_QImage(PyObject *module);
void init_QBitmap(PyObject *module);
void init_QPainter(PyObject *module);
void init_QPainter_PixmapFragment(PyObject *enclosingClass);
void init_QBackingStore(PyObject *module);
void init_QPageLayout(PyObject *module);
void init_QKeySequence(PyObject *module);
void init_QWindow(PyObject *module);
void init_QPaintDeviceWindow(PyObject *module);
void init_QRasterWindow(PyObject *module);
void init_QValidator(PyObject *module);
void init_QRegularExpressionValidator(PyObject *module);
void init_QIntValidator(PyObject *module);
void init_QDoubleValidator(PyObject *module);
void init_QUndoStack(PyObject *module);
void init_QUndoGroup(PyObject *module);
void init_QTextObject(PyObject *module);
void init_QTextFrame(PyObject *module);
void init_QTextTable(PyObject *module);
void init_QTextFrame_iterator(PyObject *enclosingClass);
void init_QTextBlockGroup(PyObject *module);
void init_QTextList(PyObject *module);
void init_QTextDocument(PyObject *module);
void init_QSyntaxHighlighter(PyObject *module);
void init_QStyleHints(PyObject *module);
void init_QShortcut(PyObject *module);
void init_QSessionManager(PyObject *module);
void init_QScreen(PyObject *module);
void init_QPyTextObject(PyObject *module);
void init_QPdfWriter(PyObject *module);
void init_QOpenGLContextGroup(PyObject *module);
void init_QOpenGLContext(PyObject *module);
void init_QRhiGles2NativeHandles(PyObject *module);
void init_QRhiGles2InitParams(PyObject *module);
void init_QOffscreenSurface(PyObject *module);
void init_QInputMethod(PyObject *module);
void init_QInputDevice(PyObject *module);
void init_QPointingDevice(PyObject *module);
void init_QDrag(PyObject *module);
void init_QClipboard(PyObject *module);
void init_QActionGroup(PyObject *module);
void init_QAction(PyObject *module);
void init_QAbstractTextDocumentLayout(PyObject *module);
void init_QAbstractTextDocumentLayout_Selection(PyObject *enclosingClass);
void init_QAbstractTextDocumentLayout_PaintContext(PyObject *enclosingClass);
void init_QWindowStateChangeEvent(PyObject *module);
void init_QWhatsThisClickedEvent(PyObject *module);
void init_QToolBarChangeEvent(PyObject *module);
void init_QStatusTipEvent(PyObject *module);
void init_QShowEvent(PyObject *module);
void init_QShortcutEvent(PyObject *module);
void init_QScrollPrepareEvent(PyObject *module);
void init_QScrollEvent(PyObject *module);
void init_QResizeEvent(PyObject *module);
void init_QPlatformSurfaceEvent(PyObject *module);
void init_QPaintEvent(PyObject *module);
void init_QMoveEvent(PyObject *module);
void init_QInputMethodQueryEvent(PyObject *module);
void init_QInputMethodEvent(PyObject *module);
void init_QInputMethodEvent_Attribute(PyObject *enclosingClass);
void init_QInputEvent(PyObject *module);
void init_QPointerEvent(PyObject *module);
void init_QTouchEvent(PyObject *module);
void init_QSinglePointEvent(PyObject *module);
void init_QWheelEvent(PyObject *module);
void init_QTabletEvent(PyObject *module);
void init_QNativeGestureEvent(PyObject *module);
void init_QMouseEvent(PyObject *module);
void init_QHoverEvent(PyObject *module);
void init_QEnterEvent(PyObject *module);
void init_QKeyEvent(PyObject *module);
void init_QContextMenuEvent(PyObject *module);
void init_QIconDragEvent(PyObject *module);
void init_QHideEvent(PyObject *module);
void init_QHelpEvent(PyObject *module);
void init_QFocusEvent(PyObject *module);
void init_QFileOpenEvent(PyObject *module);
void init_QExposeEvent(PyObject *module);
void init_QDropEvent(PyObject *module);
void init_QDragMoveEvent(PyObject *module);
void init_QDragEnterEvent(PyObject *module);
void init_QDragLeaveEvent(PyObject *module);
void init_QCloseEvent(PyObject *module);
void init_QActionEvent(PyObject *module);
void init_QGuiApplication(PyObject *module);
void init_QTextDocumentWriter(PyObject *module);
void init_QShaderCode(PyObject *module);
void init_QRhiResource(PyObject *module);
void init_QRhiTexture(PyObject *module);
void init_QRhiShaderResourceBinding_Data_StorageImageData(PyObject *enclosingClass);
void init_QRhiShaderResourceBindings(PyObject *module);
void init_QRhiSampler(PyObject *module);
void init_QRhiShaderResourceBinding_TextureAndSampler(PyObject *enclosingClass);
void init_QRhiRenderPassDescriptor(PyObject *module);
void init_QRhiRenderTarget(PyObject *module);
void init_QRhiTextureRenderTarget(PyObject *module);
void init_QRhiRenderBuffer(PyObject *module);
void init_QRhiSwapChain(PyObject *module);
void init_QRhiSwapChainRenderTarget(PyObject *module);
void init_QRhiGraphicsPipeline(PyObject *module);
void init_QRhiGraphicsPipeline_TargetBlend(PyObject *enclosingClass);
void init_QRhiComputePipeline(PyObject *module);
void init_QRhiCommandBuffer(PyObject *module);
void init_QRhiBuffer(PyObject *module);
void init_QRhiShaderResourceBinding_Data_StorageBufferData(PyObject *enclosingClass);
void init_QRhiReadbackResult(PyObject *module);
void init_QRhiDriverInfo(PyObject *module);
void init_QMovie(PyObject *module);
void init_QImageWriter(PyObject *module);
void init_QImageReader(PyObject *module);
void init_QStandardItemModel(PyObject *module);

// Required modules' type and converter arrays.
PyTypeObject **SbkPySide6_QtCoreTypes;
SbkConverter **SbkPySide6_QtCoreTypeConverters;

// Module initialization ------------------------------------------------------------

// Extended Converters.

// Extended implicit conversions for PySide6.QtCore.QPointF.
static void QPainterPath_Element_PythonToCpp_PySide6_QtCore_QPointF(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QPointF *>(cppOut) = ::QPointF(*reinterpret_cast< ::QPainterPath::Element *>(Shiboken::Conversions::cppPointer(SbkPySide6_QtGuiTypes[SBK_QPAINTERPATH_ELEMENT_IDX], reinterpret_cast<SbkObject *>(pyIn))));
}
static PythonToCppFunc is_QPainterPath_Element_PythonToCpp_PySide6_QtCore_QPointF_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, SbkPySide6_QtGuiTypes[SBK_QPAINTERPATH_ELEMENT_IDX]))
        return QPainterPath_Element_PythonToCpp_PySide6_QtCore_QPointF;
    return {};
}


// Primitive Type converters.

// C++ to Python conversion for primitive type 'WId'.
static PyObject *WId_CppToPython_WId(const void *cppIn)
{
    auto &cppInRef = *reinterpret_cast<::WId *>(const_cast<void *>(cppIn));
    // ========================================================================
    // START of custom code block [file: ../glue/qtgui.cpp (return-pylong-voidptr)]
    return PyLong_FromVoidPtr(reinterpret_cast<void *>(cppInRef));
    // END of custom code block [file: ../glue/qtgui.cpp (return-pylong-voidptr)]
    // ========================================================================

}
// Python to C++ conversions for type 'WId'.
static void PyLong_PythonToCpp_WId(PyObject *pyIn, void *cppOut)
{
    // ========================================================================
    // START of custom code block [file: ../glue/qtgui.cpp (conversion-pylong)]
    *reinterpret_cast<::WId *>(cppOut) = reinterpret_cast<WId>(PyLong_AsVoidPtr(pyIn));
    // END of custom code block [file: ../glue/qtgui.cpp (conversion-pylong)]
    // ========================================================================

}
static PythonToCppFunc is_PyLong_PythonToCpp_WId_Convertible(PyObject *pyIn)
{
    if (PyLong_Check(pyIn))
        return PyLong_PythonToCpp_WId;
    return {};
}


// Container Type converters.

// C++ to Python conversion for container type 'QList<int>'.
static PyObject *_QList_int__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<int> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_int_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<int> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        int cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_int__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyIn))
        return PySequence_PythonToCpp__QList_int_;
    return {};
}


// Binding for QList<int>

template <>
struct ShibokenContainerValueConverter<int>
{
    static bool checkValue(PyObject *pyArg)
    {
        return PyLong_Check(pyArg);
    }

    static PyObject *convertValueToPython(int cppArg)
    {
        return Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppArg);
    }

    static std::optional<int> convertValueToCpp(PyObject *pyArg)
    {
        Shiboken::Conversions::PythonToCppConversion pythonToCpp;
        if (!(PyLong_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg))))) {
            Shiboken::Errors::setWrongContainerType();
            return {};
        }
        int cppArg;
        pythonToCpp(pyArg, &cppArg);
        return cppArg;
    }
};

static PyMethodDef QIntList_methods[] = {
    {"push_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::push_back), METH_O, "push_back"},
    {"append", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::push_back), METH_O, "append"},
    {"clear", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::clear), METH_NOARGS, "clear"},
    {"pop_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::pop_back), METH_NOARGS, "pop_back"},
    {"removeLast", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::pop_back), METH_NOARGS, "removeLast"},
    {"push_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::push_front), METH_O, "push_front"},
    {"prepend", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::push_front), METH_O, "prepend"},
    {"pop_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::pop_front), METH_NOARGS, "pop_front"},
    {"removeFirst", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::pop_front), METH_O, "removeFirst"},
    {"reserve", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::reserve), METH_O, "reserve"},
    {"capacity", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::capacity), METH_NOARGS, "capacity"},
    {"data", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::data), METH_NOARGS, "data"},
    {"constData", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::constData), METH_NOARGS, "constData"},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyType_Slot QIntList_slots[] = {
    {Py_tp_init, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::tpInit)},
    {Py_tp_new, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::tpNew)},
    {Py_tp_free, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::tpFree)},
    {Py_tp_dealloc, reinterpret_cast<void *>(Sbk_object_dealloc)},
    {Py_tp_methods, reinterpret_cast<void *>(QIntList_methods)},
    {Py_sq_ass_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::sqSetItem)},
    {Py_sq_length, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::sqLen)},
    {Py_sq_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::sqGetItem)},
    {0, nullptr}
};

static PyType_Spec QIntList_spec = {
    "2:PySide6.QtGui.QIntList",
    sizeof(ShibokenContainer),
    0,
    Py_TPFLAGS_DEFAULT,
    QIntList_slots
};

static inline PyTypeObject *createQIntListType()
{
    auto *result = reinterpret_cast<PyTypeObject *>(SbkType_FromSpec(&QIntList_spec));
    Py_INCREF(Py_True);
    Shiboken::AutoDecRef tpDict(PepType_GetDict(result));
    PyDict_SetItem(tpDict.object(), Shiboken::PyMagicName::opaque_container(), Py_True);
    return result;
}

static PyTypeObject *QIntList_TypeF()
{
    static PyTypeObject *type = createQIntListType();
    return type;
}

extern "C" PyObject *createQIntList(QList<int>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QIntList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<int>>();
    d->m_list = ct;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" PyObject *createConstQIntList(const QList<int>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QIntList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<int>>();
    d->m_list = const_cast<QList<int> *>(ct);
    d->m_const = true;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" int QIntList_Check(PyObject *pyArg)
{
    return pyArg != nullptr && pyArg != Py_None && pyArg->ob_type == QIntList_TypeF();
}

extern "C" void PythonToCppQIntList(PyObject *pyArg, void *cppOut)
{
    auto *d = ShibokenSequenceContainerPrivate<QList<int>>::get(pyArg);
    *reinterpret_cast<QList<int>**>(cppOut) = d->m_list;
}

extern "C" PythonToCppFunc isQIntListPythonToCppConvertible(PyObject *pyArg)
{
    if (QIntList_Check(pyArg))
        return PythonToCppQIntList;
    return {};
}

// C++ to Python conversion for container type 'QList<QVector2D>'.
static PyObject *_QList_QVector2D__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QVector2D> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypes[SBK_QVECTOR2D_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QVector2D_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QVector2D> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QVector2D cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtGuiTypes[SBK_QVECTOR2D_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QVector2D__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtGuiTypes[SBK_QVECTOR2D_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QVector2D_;
    return {};
}


// Binding for QList<QVector2D>

template <>
struct ShibokenContainerValueConverter<QVector2D>
{
    static bool checkValue(PyObject *pyArg)
    {
        return SbkObject_TypeCheck(SbkPySide6_QtGuiTypes[SBK_QVECTOR2D_IDX], pyArg);
    }

    static PyObject *convertValueToPython(const QVector2D &cppArg)
    {
        return Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypes[SBK_QVECTOR2D_IDX], &cppArg);
    }

    static std::optional<QVector2D> convertValueToCpp(PyObject *pyArg)
    {
        Shiboken::Conversions::PythonToCppConversion pythonToCpp;
        if (!((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(SbkPySide6_QtGuiTypes[SBK_QVECTOR2D_IDX], (pyArg))))) {
            Shiboken::Errors::setWrongContainerType();
            return {};
        }
        ::QVector2D cppArg;
        pythonToCpp(pyArg, &cppArg);
        return cppArg;
    }
};

static PyMethodDef QVector2DList_methods[] = {
    {"push_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector2D>>::push_back), METH_O, "push_back"},
    {"append", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector2D>>::push_back), METH_O, "append"},
    {"clear", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector2D>>::clear), METH_NOARGS, "clear"},
    {"pop_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector2D>>::pop_back), METH_NOARGS, "pop_back"},
    {"removeLast", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector2D>>::pop_back), METH_NOARGS, "removeLast"},
    {"push_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector2D>>::push_front), METH_O, "push_front"},
    {"prepend", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector2D>>::push_front), METH_O, "prepend"},
    {"pop_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector2D>>::pop_front), METH_NOARGS, "pop_front"},
    {"removeFirst", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector2D>>::pop_front), METH_O, "removeFirst"},
    {"reserve", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector2D>>::reserve), METH_O, "reserve"},
    {"capacity", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector2D>>::capacity), METH_NOARGS, "capacity"},
    {"data", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector2D>>::data), METH_NOARGS, "data"},
    {"constData", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector2D>>::constData), METH_NOARGS, "constData"},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyType_Slot QVector2DList_slots[] = {
    {Py_tp_init, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QVector2D>>::tpInit)},
    {Py_tp_new, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QVector2D>>::tpNew)},
    {Py_tp_free, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QVector2D>>::tpFree)},
    {Py_tp_dealloc, reinterpret_cast<void *>(Sbk_object_dealloc)},
    {Py_tp_methods, reinterpret_cast<void *>(QVector2DList_methods)},
    {Py_sq_ass_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QVector2D>>::sqSetItem)},
    {Py_sq_length, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QVector2D>>::sqLen)},
    {Py_sq_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QVector2D>>::sqGetItem)},
    {0, nullptr}
};

static PyType_Spec QVector2DList_spec = {
    "2:PySide6.QtGui.QVector2DList",
    sizeof(ShibokenContainer),
    0,
    Py_TPFLAGS_DEFAULT,
    QVector2DList_slots
};

static inline PyTypeObject *createQVector2DListType()
{
    auto *result = reinterpret_cast<PyTypeObject *>(SbkType_FromSpec(&QVector2DList_spec));
    Py_INCREF(Py_True);
    Shiboken::AutoDecRef tpDict(PepType_GetDict(result));
    PyDict_SetItem(tpDict.object(), Shiboken::PyMagicName::opaque_container(), Py_True);
    return result;
}

static PyTypeObject *QVector2DList_TypeF()
{
    static PyTypeObject *type = createQVector2DListType();
    return type;
}

extern "C" PyObject *createQVector2DList(QList<QVector2D>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QVector2DList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<QVector2D>>();
    d->m_list = ct;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" PyObject *createConstQVector2DList(const QList<QVector2D>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QVector2DList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<QVector2D>>();
    d->m_list = const_cast<QList<QVector2D> *>(ct);
    d->m_const = true;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" int QVector2DList_Check(PyObject *pyArg)
{
    return pyArg != nullptr && pyArg != Py_None && pyArg->ob_type == QVector2DList_TypeF();
}

extern "C" void PythonToCppQVector2DList(PyObject *pyArg, void *cppOut)
{
    auto *d = ShibokenSequenceContainerPrivate<QList<QVector2D>>::get(pyArg);
    *reinterpret_cast<QList<QVector2D>**>(cppOut) = d->m_list;
}

extern "C" PythonToCppFunc isQVector2DListPythonToCppConvertible(PyObject *pyArg)
{
    if (QVector2DList_Check(pyArg))
        return PythonToCppQVector2DList;
    return {};
}

// C++ to Python conversion for container type 'QList<QVector3D>'.
static PyObject *_QList_QVector3D__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QVector3D> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypes[SBK_QVECTOR3D_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QVector3D_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QVector3D> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QVector3D cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtGuiTypes[SBK_QVECTOR3D_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QVector3D__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtGuiTypes[SBK_QVECTOR3D_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QVector3D_;
    return {};
}


// Binding for QList<QVector3D>

template <>
struct ShibokenContainerValueConverter<QVector3D>
{
    static bool checkValue(PyObject *pyArg)
    {
        return SbkObject_TypeCheck(SbkPySide6_QtGuiTypes[SBK_QVECTOR3D_IDX], pyArg);
    }

    static PyObject *convertValueToPython(const QVector3D &cppArg)
    {
        return Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypes[SBK_QVECTOR3D_IDX], &cppArg);
    }

    static std::optional<QVector3D> convertValueToCpp(PyObject *pyArg)
    {
        Shiboken::Conversions::PythonToCppConversion pythonToCpp;
        if (!((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(SbkPySide6_QtGuiTypes[SBK_QVECTOR3D_IDX], (pyArg))))) {
            Shiboken::Errors::setWrongContainerType();
            return {};
        }
        ::QVector3D cppArg;
        pythonToCpp(pyArg, &cppArg);
        return cppArg;
    }
};

static PyMethodDef QVector3DList_methods[] = {
    {"push_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector3D>>::push_back), METH_O, "push_back"},
    {"append", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector3D>>::push_back), METH_O, "append"},
    {"clear", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector3D>>::clear), METH_NOARGS, "clear"},
    {"pop_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector3D>>::pop_back), METH_NOARGS, "pop_back"},
    {"removeLast", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector3D>>::pop_back), METH_NOARGS, "removeLast"},
    {"push_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector3D>>::push_front), METH_O, "push_front"},
    {"prepend", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector3D>>::push_front), METH_O, "prepend"},
    {"pop_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector3D>>::pop_front), METH_NOARGS, "pop_front"},
    {"removeFirst", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector3D>>::pop_front), METH_O, "removeFirst"},
    {"reserve", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector3D>>::reserve), METH_O, "reserve"},
    {"capacity", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector3D>>::capacity), METH_NOARGS, "capacity"},
    {"data", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector3D>>::data), METH_NOARGS, "data"},
    {"constData", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector3D>>::constData), METH_NOARGS, "constData"},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyType_Slot QVector3DList_slots[] = {
    {Py_tp_init, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QVector3D>>::tpInit)},
    {Py_tp_new, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QVector3D>>::tpNew)},
    {Py_tp_free, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QVector3D>>::tpFree)},
    {Py_tp_dealloc, reinterpret_cast<void *>(Sbk_object_dealloc)},
    {Py_tp_methods, reinterpret_cast<void *>(QVector3DList_methods)},
    {Py_sq_ass_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QVector3D>>::sqSetItem)},
    {Py_sq_length, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QVector3D>>::sqLen)},
    {Py_sq_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QVector3D>>::sqGetItem)},
    {0, nullptr}
};

static PyType_Spec QVector3DList_spec = {
    "2:PySide6.QtGui.QVector3DList",
    sizeof(ShibokenContainer),
    0,
    Py_TPFLAGS_DEFAULT,
    QVector3DList_slots
};

static inline PyTypeObject *createQVector3DListType()
{
    auto *result = reinterpret_cast<PyTypeObject *>(SbkType_FromSpec(&QVector3DList_spec));
    Py_INCREF(Py_True);
    Shiboken::AutoDecRef tpDict(PepType_GetDict(result));
    PyDict_SetItem(tpDict.object(), Shiboken::PyMagicName::opaque_container(), Py_True);
    return result;
}

static PyTypeObject *QVector3DList_TypeF()
{
    static PyTypeObject *type = createQVector3DListType();
    return type;
}

extern "C" PyObject *createQVector3DList(QList<QVector3D>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QVector3DList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<QVector3D>>();
    d->m_list = ct;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" PyObject *createConstQVector3DList(const QList<QVector3D>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QVector3DList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<QVector3D>>();
    d->m_list = const_cast<QList<QVector3D> *>(ct);
    d->m_const = true;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" int QVector3DList_Check(PyObject *pyArg)
{
    return pyArg != nullptr && pyArg != Py_None && pyArg->ob_type == QVector3DList_TypeF();
}

extern "C" void PythonToCppQVector3DList(PyObject *pyArg, void *cppOut)
{
    auto *d = ShibokenSequenceContainerPrivate<QList<QVector3D>>::get(pyArg);
    *reinterpret_cast<QList<QVector3D>**>(cppOut) = d->m_list;
}

extern "C" PythonToCppFunc isQVector3DListPythonToCppConvertible(PyObject *pyArg)
{
    if (QVector3DList_Check(pyArg))
        return PythonToCppQVector3DList;
    return {};
}

// C++ to Python conversion for container type 'QList<QVector4D>'.
static PyObject *_QList_QVector4D__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QVector4D> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypes[SBK_QVECTOR4D_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QVector4D_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QVector4D> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QVector4D cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtGuiTypes[SBK_QVECTOR4D_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QVector4D__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtGuiTypes[SBK_QVECTOR4D_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QVector4D_;
    return {};
}


// Binding for QList<QVector4D>

template <>
struct ShibokenContainerValueConverter<QVector4D>
{
    static bool checkValue(PyObject *pyArg)
    {
        return SbkObject_TypeCheck(SbkPySide6_QtGuiTypes[SBK_QVECTOR4D_IDX], pyArg);
    }

    static PyObject *convertValueToPython(const QVector4D &cppArg)
    {
        return Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypes[SBK_QVECTOR4D_IDX], &cppArg);
    }

    static std::optional<QVector4D> convertValueToCpp(PyObject *pyArg)
    {
        Shiboken::Conversions::PythonToCppConversion pythonToCpp;
        if (!((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(SbkPySide6_QtGuiTypes[SBK_QVECTOR4D_IDX], (pyArg))))) {
            Shiboken::Errors::setWrongContainerType();
            return {};
        }
        ::QVector4D cppArg;
        pythonToCpp(pyArg, &cppArg);
        return cppArg;
    }
};

static PyMethodDef QVector4DList_methods[] = {
    {"push_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector4D>>::push_back), METH_O, "push_back"},
    {"append", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector4D>>::push_back), METH_O, "append"},
    {"clear", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector4D>>::clear), METH_NOARGS, "clear"},
    {"pop_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector4D>>::pop_back), METH_NOARGS, "pop_back"},
    {"removeLast", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector4D>>::pop_back), METH_NOARGS, "removeLast"},
    {"push_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector4D>>::push_front), METH_O, "push_front"},
    {"prepend", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector4D>>::push_front), METH_O, "prepend"},
    {"pop_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector4D>>::pop_front), METH_NOARGS, "pop_front"},
    {"removeFirst", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector4D>>::pop_front), METH_O, "removeFirst"},
    {"reserve", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector4D>>::reserve), METH_O, "reserve"},
    {"capacity", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector4D>>::capacity), METH_NOARGS, "capacity"},
    {"data", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector4D>>::data), METH_NOARGS, "data"},
    {"constData", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector4D>>::constData), METH_NOARGS, "constData"},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyType_Slot QVector4DList_slots[] = {
    {Py_tp_init, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QVector4D>>::tpInit)},
    {Py_tp_new, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QVector4D>>::tpNew)},
    {Py_tp_free, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QVector4D>>::tpFree)},
    {Py_tp_dealloc, reinterpret_cast<void *>(Sbk_object_dealloc)},
    {Py_tp_methods, reinterpret_cast<void *>(QVector4DList_methods)},
    {Py_sq_ass_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QVector4D>>::sqSetItem)},
    {Py_sq_length, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QVector4D>>::sqLen)},
    {Py_sq_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QVector4D>>::sqGetItem)},
    {0, nullptr}
};

static PyType_Spec QVector4DList_spec = {
    "2:PySide6.QtGui.QVector4DList",
    sizeof(ShibokenContainer),
    0,
    Py_TPFLAGS_DEFAULT,
    QVector4DList_slots
};

static inline PyTypeObject *createQVector4DListType()
{
    auto *result = reinterpret_cast<PyTypeObject *>(SbkType_FromSpec(&QVector4DList_spec));
    Py_INCREF(Py_True);
    Shiboken::AutoDecRef tpDict(PepType_GetDict(result));
    PyDict_SetItem(tpDict.object(), Shiboken::PyMagicName::opaque_container(), Py_True);
    return result;
}

static PyTypeObject *QVector4DList_TypeF()
{
    static PyTypeObject *type = createQVector4DListType();
    return type;
}

extern "C" PyObject *createQVector4DList(QList<QVector4D>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QVector4DList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<QVector4D>>();
    d->m_list = ct;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" PyObject *createConstQVector4DList(const QList<QVector4D>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QVector4DList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<QVector4D>>();
    d->m_list = const_cast<QList<QVector4D> *>(ct);
    d->m_const = true;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" int QVector4DList_Check(PyObject *pyArg)
{
    return pyArg != nullptr && pyArg != Py_None && pyArg->ob_type == QVector4DList_TypeF();
}

extern "C" void PythonToCppQVector4DList(PyObject *pyArg, void *cppOut)
{
    auto *d = ShibokenSequenceContainerPrivate<QList<QVector4D>>::get(pyArg);
    *reinterpret_cast<QList<QVector4D>**>(cppOut) = d->m_list;
}

extern "C" PythonToCppFunc isQVector4DListPythonToCppConvertible(PyObject *pyArg)
{
    if (QVector4DList_Check(pyArg))
        return PythonToCppQVector4DList;
    return {};
}

// C++ to Python conversion for container type 'QList<qreal>'.
static PyObject *_QList_qreal__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<qreal> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_qreal_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<qreal> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        qreal cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_qreal__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), pyIn))
        return PySequence_PythonToCpp__QList_qreal_;
    return {};
}

// C++ to Python conversion for container type 'QList<QTextOption::Tab>'.
static PyObject *_QList_QTextOption_Tab__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QTextOption::Tab> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypes[SBK_QTEXTOPTION_TAB_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QTextOption_Tab_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QTextOption::Tab> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QTextOption::Tab cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtGuiTypes[SBK_QTEXTOPTION_TAB_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QTextOption_Tab__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtGuiTypes[SBK_QTEXTOPTION_TAB_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QTextOption_Tab_;
    return {};
}

// C++ to Python conversion for container type 'QList<QGlyphRun>'.
static PyObject *_QList_QGlyphRun__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QGlyphRun> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypes[SBK_QGLYPHRUN_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QGlyphRun_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QGlyphRun> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QGlyphRun cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtGuiTypes[SBK_QGLYPHRUN_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QGlyphRun__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtGuiTypes[SBK_QGLYPHRUN_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QGlyphRun_;
    return {};
}

// C++ to Python conversion for container type 'QList<QTextLength>'.
static PyObject *_QList_QTextLength__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QTextLength> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypes[SBK_QTEXTLENGTH_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QTextLength_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QTextLength> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QTextLength cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtGuiTypes[SBK_QTEXTLENGTH_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QTextLength__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtGuiTypes[SBK_QTEXTLENGTH_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QTextLength_;
    return {};
}

// C++ to Python conversion for container type 'QMap<int,QVariant>'.
static PyObject *_QMap_int_QVariant__CppToPython_PyDict(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QMap<int,QVariant> *>(cppIn);
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - START
    PyObject *pyOut = PyDict_New();
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it) {
        const auto &key = it.key();
        const auto &value = it.value();
        PyObject *pyKey = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &key);
        PyObject *pyValue = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVARIANT_IDX], &value);
        PyDict_SetItem(pyOut, pyKey, pyValue);
        Py_DECREF(pyKey);
        Py_DECREF(pyValue);
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - END

}
static void PyDict_PythonToCpp__QMap_int_QVariant_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QMap<int,QVariant> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - START
    PyObject *key;
    PyObject *value;
    cppOutRef.clear();
    Py_ssize_t pos = 0;
    while (PyDict_Next(pyIn, &pos, &key, &value)) {
        int cppKey;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<int>(), key, &(cppKey));
        ::QVariant cppValue;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QVARIANT_IDX], value, &(cppValue));
        cppOutRef.insert(cppKey, cppValue);
    }
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - END

}
static PythonToCppFunc is_PyDict_PythonToCpp__QMap_int_QVariant__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleDictTypes(Shiboken::Conversions::PrimitiveTypeConverter<int>(), false, SbkPySide6_QtCoreTypeConverters[SBK_QVARIANT_IDX], false, pyIn))
        return PyDict_PythonToCpp__QMap_int_QVariant_;
    return {};
}

// C++ to Python conversion for container type 'QList<QTextLayout::FormatRange>'.
static PyObject *_QList_QTextLayout_FormatRange__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QTextLayout::FormatRange> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypes[SBK_QTEXTLAYOUT_FORMATRANGE_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QTextLayout_FormatRange_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QTextLayout::FormatRange> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QTextLayout::FormatRange cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtGuiTypes[SBK_QTEXTLAYOUT_FORMATRANGE_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QTextLayout_FormatRange__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtGuiTypes[SBK_QTEXTLAYOUT_FORMATRANGE_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QTextLayout_FormatRange_;
    return {};
}

// C++ to Python conversion for container type 'std::pair<int,int>'.
static PyObject *std_pair_int_int__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::std::pair<int,int> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - START
    PyObject *pyOut = PyTuple_New(2);
    PyTuple_SET_ITEM(pyOut, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppInRef.first));
    PyTuple_SET_ITEM(pyOut, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppInRef.second));
    return pyOut;
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - END

}
static void PySequence_PythonToCpp_std_pair_int_int_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::std::pair<int,int> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - START
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<int>(), PySequence_Fast_GET_ITEM(pyIn, 0), &(cppOutRef.first));
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<int>(), PySequence_Fast_GET_ITEM(pyIn, 1), &(cppOutRef.second));
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_std_pair_int_int__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertiblePairTypes(Shiboken::Conversions::PrimitiveTypeConverter<int>(), false, Shiboken::Conversions::PrimitiveTypeConverter<int>(), false, pyIn))
        return PySequence_PythonToCpp_std_pair_int_int_;
    return {};
}

// C++ to Python conversion for container type 'QList<QStandardItem*>'.
static PyObject *_QList_QStandardItemPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QStandardItem*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(SbkPySide6_QtGuiTypes[SBK_QSTANDARDITEM_IDX], cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QStandardItemPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QStandardItem*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QStandardItem* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_QtGuiTypes[SBK_QSTANDARDITEM_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QStandardItemPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(SbkPySide6_QtGuiTypes[SBK_QSTANDARDITEM_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QStandardItemPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QShaderKey>'.
static PyObject *_QList_QShaderKey__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QShaderKey> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypes[SBK_QSHADERKEY_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QShaderKey_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QShaderKey> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QShaderKey cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtGuiTypes[SBK_QSHADERKEY_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QShaderKey__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtGuiTypes[SBK_QSHADERKEY_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QShaderKey_;
    return {};
}

// C++ to Python conversion for container type 'QMap<int,std::pair< int,int>>'.
static PyObject *_QMap_int_std_pair_int_int___CppToPython_PyDict(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QMap<int,std::pair< int,int>> *>(cppIn);
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - START
    PyObject *pyOut = PyDict_New();
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it) {
        const auto &key = it.key();
        const auto &value = it.value();
        PyObject *pyKey = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &key);
        PyObject *pyValue = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_STD_PAIR_INT_INT_IDX], &value);
        PyDict_SetItem(pyOut, pyKey, pyValue);
        Py_DECREF(pyKey);
        Py_DECREF(pyValue);
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - END

}
static void PyDict_PythonToCpp__QMap_int_std_pair_int_int__(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QMap<int,std::pair< int,int>> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - START
    PyObject *key;
    PyObject *value;
    cppOutRef.clear();
    Py_ssize_t pos = 0;
    while (PyDict_Next(pyIn, &pos, &key, &value)) {
        int cppKey;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<int>(), key, &(cppKey));
        ::std::pair<int,int> cppValue;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_STD_PAIR_INT_INT_IDX], value, &(cppValue));
        cppOutRef.insert(cppKey, cppValue);
    }
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - END

}
static PythonToCppFunc is_PyDict_PythonToCpp__QMap_int_std_pair_int_int___Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleDictTypes(Shiboken::Conversions::PrimitiveTypeConverter<int>(), false, SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_STD_PAIR_INT_INT_IDX], false, pyIn))
        return PyDict_PythonToCpp__QMap_int_std_pair_int_int__;
    return {};
}

// C++ to Python conversion for container type 'std::array<float,4>'.
static PyObject *std_array_float_4__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::std::array<float,4> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp_std_array_float_4_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::std::array<float,4> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cpparray - START
    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    for (auto oit = std::begin(cppOutRef), oend = std::end(cppOutRef); oit != oend; ++oit) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        float cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<float>(), pyItem, &(cppItem));
        *oit = cppItem;
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cpparray - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_std_array_float_4__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Conversions::PrimitiveTypeConverter<float>(), pyIn))
        return PySequence_PythonToCpp_std_array_float_4_;
    return {};
}

// C++ to Python conversion for container type 'QList<QRhiVertexInputAttribute>'.
static PyObject *_QList_QRhiVertexInputAttribute__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QRhiVertexInputAttribute> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypes[SBK_QRHIVERTEXINPUTATTRIBUTE_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QRhiVertexInputAttribute_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QRhiVertexInputAttribute> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QRhiVertexInputAttribute cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtGuiTypes[SBK_QRHIVERTEXINPUTATTRIBUTE_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QRhiVertexInputAttribute__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtGuiTypes[SBK_QRHIVERTEXINPUTATTRIBUTE_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QRhiVertexInputAttribute_;
    return {};
}

// C++ to Python conversion for container type 'QList<QRhiVertexInputBinding>'.
static PyObject *_QList_QRhiVertexInputBinding__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QRhiVertexInputBinding> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypes[SBK_QRHIVERTEXINPUTBINDING_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QRhiVertexInputBinding_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QRhiVertexInputBinding> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QRhiVertexInputBinding cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtGuiTypes[SBK_QRHIVERTEXINPUTBINDING_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QRhiVertexInputBinding__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtGuiTypes[SBK_QRHIVERTEXINPUTBINDING_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QRhiVertexInputBinding_;
    return {};
}

// C++ to Python conversion for container type 'QList<QRhiTextureUploadEntry>'.
static PyObject *_QList_QRhiTextureUploadEntry__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QRhiTextureUploadEntry> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypes[SBK_QRHITEXTUREUPLOADENTRY_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QRhiTextureUploadEntry_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QRhiTextureUploadEntry> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QRhiTextureUploadEntry cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtGuiTypes[SBK_QRHITEXTUREUPLOADENTRY_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QRhiTextureUploadEntry__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtGuiTypes[SBK_QRHITEXTUREUPLOADENTRY_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QRhiTextureUploadEntry_;
    return {};
}

// C++ to Python conversion for container type 'QList<QRhiColorAttachment>'.
static PyObject *_QList_QRhiColorAttachment__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QRhiColorAttachment> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypes[SBK_QRHICOLORATTACHMENT_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QRhiColorAttachment_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QRhiColorAttachment> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QRhiColorAttachment cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtGuiTypes[SBK_QRHICOLORATTACHMENT_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QRhiColorAttachment__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtGuiTypes[SBK_QRHICOLORATTACHMENT_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QRhiColorAttachment_;
    return {};
}

// C++ to Python conversion for container type 'std::array<int,4>'.
static PyObject *std_array_int_4__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::std::array<int,4> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp_std_array_int_4_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::std::array<int,4> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cpparray - START
    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    for (auto oit = std::begin(cppOutRef), oend = std::end(cppOutRef); oit != oend; ++oit) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        int cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyItem, &(cppItem));
        *oit = cppItem;
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cpparray - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_std_array_int_4__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyIn))
        return PySequence_PythonToCpp_std_array_int_4_;
    return {};
}

// C++ to Python conversion for container type 'QList<QPointF>'.
static PyObject *_QList_QPointF__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QPointF> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypes[SBK_QPOINTF_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QPointF_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QPointF> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QPointF cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypes[SBK_QPOINTF_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QPointF__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypes[SBK_QPOINTF_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QPointF_;
    return {};
}


// Binding for QList<QPointF>

template <>
struct ShibokenContainerValueConverter<QPointF>
{
    static bool checkValue(PyObject *pyArg)
    {
        return SbkObject_TypeCheck(SbkPySide6_QtCoreTypes[SBK_QPOINTF_IDX], pyArg);
    }

    static PyObject *convertValueToPython(const QPointF &cppArg)
    {
        return Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypes[SBK_QPOINTF_IDX], &cppArg);
    }

    static std::optional<QPointF> convertValueToCpp(PyObject *pyArg)
    {
        Shiboken::Conversions::PythonToCppConversion pythonToCpp;
        if (!((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(SbkPySide6_QtCoreTypes[SBK_QPOINTF_IDX], (pyArg))))) {
            Shiboken::Errors::setWrongContainerType();
            return {};
        }
        ::QPointF cppArg;
        pythonToCpp(pyArg, &cppArg);
        return cppArg;
    }
};

static PyMethodDef QPointFList_methods[] = {
    {"push_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::push_back), METH_O, "push_back"},
    {"append", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::push_back), METH_O, "append"},
    {"clear", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::clear), METH_NOARGS, "clear"},
    {"pop_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::pop_back), METH_NOARGS, "pop_back"},
    {"removeLast", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::pop_back), METH_NOARGS, "removeLast"},
    {"push_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::push_front), METH_O, "push_front"},
    {"prepend", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::push_front), METH_O, "prepend"},
    {"pop_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::pop_front), METH_NOARGS, "pop_front"},
    {"removeFirst", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::pop_front), METH_O, "removeFirst"},
    {"reserve", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::reserve), METH_O, "reserve"},
    {"capacity", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::capacity), METH_NOARGS, "capacity"},
    {"data", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::data), METH_NOARGS, "data"},
    {"constData", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::constData), METH_NOARGS, "constData"},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyType_Slot QPointFList_slots[] = {
    {Py_tp_init, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPointF>>::tpInit)},
    {Py_tp_new, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPointF>>::tpNew)},
    {Py_tp_free, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPointF>>::tpFree)},
    {Py_tp_dealloc, reinterpret_cast<void *>(Sbk_object_dealloc)},
    {Py_tp_methods, reinterpret_cast<void *>(QPointFList_methods)},
    {Py_sq_ass_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPointF>>::sqSetItem)},
    {Py_sq_length, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPointF>>::sqLen)},
    {Py_sq_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPointF>>::sqGetItem)},
    {0, nullptr}
};

static PyType_Spec QPointFList_spec = {
    "2:PySide6.QtGui.QPointFList",
    sizeof(ShibokenContainer),
    0,
    Py_TPFLAGS_DEFAULT,
    QPointFList_slots
};

static inline PyTypeObject *createQPointFListType()
{
    auto *result = reinterpret_cast<PyTypeObject *>(SbkType_FromSpec(&QPointFList_spec));
    Py_INCREF(Py_True);
    Shiboken::AutoDecRef tpDict(PepType_GetDict(result));
    PyDict_SetItem(tpDict.object(), Shiboken::PyMagicName::opaque_container(), Py_True);
    return result;
}

static PyTypeObject *QPointFList_TypeF()
{
    static PyTypeObject *type = createQPointFListType();
    return type;
}

extern "C" PyObject *createQPointFList(QList<QPointF>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QPointFList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<QPointF>>();
    d->m_list = ct;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" PyObject *createConstQPointFList(const QList<QPointF>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QPointFList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<QPointF>>();
    d->m_list = const_cast<QList<QPointF> *>(ct);
    d->m_const = true;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" int QPointFList_Check(PyObject *pyArg)
{
    return pyArg != nullptr && pyArg != Py_None && pyArg->ob_type == QPointFList_TypeF();
}

extern "C" void PythonToCppQPointFList(PyObject *pyArg, void *cppOut)
{
    auto *d = ShibokenSequenceContainerPrivate<QList<QPointF>>::get(pyArg);
    *reinterpret_cast<QList<QPointF>**>(cppOut) = d->m_list;
}

extern "C" PythonToCppFunc isQPointFListPythonToCppConvertible(PyObject *pyArg)
{
    if (QPointFList_Check(pyArg))
        return PythonToCppQPointFList;
    return {};
}

// C++ to Python conversion for container type 'QList<quint32>'.
static PyObject *_QList_quint32__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<quint32> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_quint32_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<quint32> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        quint32 cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_quint32__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), pyIn))
        return PySequence_PythonToCpp__QList_quint32_;
    return {};
}

// C++ to Python conversion for container type 'QList<QFontDatabase::WritingSystem>'.
static PyObject *_QList_QFontDatabase_WritingSystem__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QFontDatabase::WritingSystem> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QFONTDATABASE_WRITINGSYSTEM_IDX]))->converter, &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QFontDatabase_WritingSystem_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QFontDatabase::WritingSystem> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QFontDatabase::WritingSystem cppItem{QFontDatabase::Any};
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QFONTDATABASE_WRITINGSYSTEM_IDX]))->converter, pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QFontDatabase_WritingSystem__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QFONTDATABASE_WRITINGSYSTEM_IDX]))->converter, pyIn))
        return PySequence_PythonToCpp__QList_QFontDatabase_WritingSystem_;
    return {};
}

// C++ to Python conversion for container type 'QList<QPoint>'.
static PyObject *_QList_QPoint__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QPoint> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypes[SBK_QPOINT_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QPoint_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QPoint> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QPoint cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypes[SBK_QPOINT_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QPoint__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypes[SBK_QPOINT_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QPoint_;
    return {};
}


// Binding for QList<QPoint>

template <>
struct ShibokenContainerValueConverter<QPoint>
{
    static bool checkValue(PyObject *pyArg)
    {
        return SbkObject_TypeCheck(SbkPySide6_QtCoreTypes[SBK_QPOINT_IDX], pyArg);
    }

    static PyObject *convertValueToPython(const QPoint &cppArg)
    {
        return Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypes[SBK_QPOINT_IDX], &cppArg);
    }

    static std::optional<QPoint> convertValueToCpp(PyObject *pyArg)
    {
        Shiboken::Conversions::PythonToCppConversion pythonToCpp;
        if (!((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(SbkPySide6_QtCoreTypes[SBK_QPOINT_IDX], (pyArg))))) {
            Shiboken::Errors::setWrongContainerType();
            return {};
        }
        ::QPoint cppArg;
        pythonToCpp(pyArg, &cppArg);
        return cppArg;
    }
};

static PyMethodDef QPointList_methods[] = {
    {"push_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::push_back), METH_O, "push_back"},
    {"append", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::push_back), METH_O, "append"},
    {"clear", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::clear), METH_NOARGS, "clear"},
    {"pop_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::pop_back), METH_NOARGS, "pop_back"},
    {"removeLast", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::pop_back), METH_NOARGS, "removeLast"},
    {"push_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::push_front), METH_O, "push_front"},
    {"prepend", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::push_front), METH_O, "prepend"},
    {"pop_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::pop_front), METH_NOARGS, "pop_front"},
    {"removeFirst", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::pop_front), METH_O, "removeFirst"},
    {"reserve", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::reserve), METH_O, "reserve"},
    {"capacity", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::capacity), METH_NOARGS, "capacity"},
    {"data", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::data), METH_NOARGS, "data"},
    {"constData", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::constData), METH_NOARGS, "constData"},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyType_Slot QPointList_slots[] = {
    {Py_tp_init, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPoint>>::tpInit)},
    {Py_tp_new, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPoint>>::tpNew)},
    {Py_tp_free, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPoint>>::tpFree)},
    {Py_tp_dealloc, reinterpret_cast<void *>(Sbk_object_dealloc)},
    {Py_tp_methods, reinterpret_cast<void *>(QPointList_methods)},
    {Py_sq_ass_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPoint>>::sqSetItem)},
    {Py_sq_length, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPoint>>::sqLen)},
    {Py_sq_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPoint>>::sqGetItem)},
    {0, nullptr}
};

static PyType_Spec QPointList_spec = {
    "2:PySide6.QtGui.QPointList",
    sizeof(ShibokenContainer),
    0,
    Py_TPFLAGS_DEFAULT,
    QPointList_slots
};

static inline PyTypeObject *createQPointListType()
{
    auto *result = reinterpret_cast<PyTypeObject *>(SbkType_FromSpec(&QPointList_spec));
    Py_INCREF(Py_True);
    Shiboken::AutoDecRef tpDict(PepType_GetDict(result));
    PyDict_SetItem(tpDict.object(), Shiboken::PyMagicName::opaque_container(), Py_True);
    return result;
}

static PyTypeObject *QPointList_TypeF()
{
    static PyTypeObject *type = createQPointListType();
    return type;
}

extern "C" PyObject *createQPointList(QList<QPoint>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QPointList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<QPoint>>();
    d->m_list = ct;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" PyObject *createConstQPointList(const QList<QPoint>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QPointList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<QPoint>>();
    d->m_list = const_cast<QList<QPoint> *>(ct);
    d->m_const = true;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" int QPointList_Check(PyObject *pyArg)
{
    return pyArg != nullptr && pyArg != Py_None && pyArg->ob_type == QPointList_TypeF();
}

extern "C" void PythonToCppQPointList(PyObject *pyArg, void *cppOut)
{
    auto *d = ShibokenSequenceContainerPrivate<QList<QPoint>>::get(pyArg);
    *reinterpret_cast<QList<QPoint>**>(cppOut) = d->m_list;
}

extern "C" PythonToCppFunc isQPointListPythonToCppConvertible(PyObject *pyArg)
{
    if (QPointList_Check(pyArg))
        return PythonToCppQPointList;
    return {};
}

// C++ to Python conversion for container type 'QList<QPolygonF>'.
static PyObject *_QList_QPolygonF__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QPolygonF> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypes[SBK_QPOLYGONF_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QPolygonF_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QPolygonF> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QPolygonF cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtGuiTypes[SBK_QPOLYGONF_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QPolygonF__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtGuiTypes[SBK_QPOLYGONF_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QPolygonF_;
    return {};
}

// C++ to Python conversion for container type 'QList<QPageRanges::Range>'.
static PyObject *_QList_QPageRanges_Range__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QPageRanges::Range> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypes[SBK_QPAGERANGES_RANGE_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QPageRanges_Range_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QPageRanges::Range> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QPageRanges::Range cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtGuiTypes[SBK_QPAGERANGES_RANGE_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QPageRanges_Range__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtGuiTypes[SBK_QPAGERANGES_RANGE_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QPageRanges_Range_;
    return {};
}

// C++ to Python conversion for container type 'QList<float>'.
static PyObject *_QList_float__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<float> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_float_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<float> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        float cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<float>(), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_float__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Conversions::PrimitiveTypeConverter<float>(), pyIn))
        return PySequence_PythonToCpp__QList_float_;
    return {};
}

// C++ to Python conversion for container type 'QList<QSize>'.
static PyObject *_QList_QSize__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QSize> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypes[SBK_QSIZE_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QSize_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QSize> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QSize cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypes[SBK_QSIZE_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QSize__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypes[SBK_QSIZE_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QSize_;
    return {};
}

// C++ to Python conversion for container type 'std::pair<qreal,QColor>'.
static PyObject *std_pair_qreal_QColor__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::std::pair<qreal,QColor> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - START
    PyObject *pyOut = PyTuple_New(2);
    PyTuple_SET_ITEM(pyOut, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppInRef.first));
    PyTuple_SET_ITEM(pyOut, 1, Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypes[SBK_QCOLOR_IDX], &cppInRef.second));
    return pyOut;
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - END

}
static void PySequence_PythonToCpp_std_pair_qreal_QColor_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::std::pair<qreal,QColor> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - START
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), PySequence_Fast_GET_ITEM(pyIn, 0), &(cppOutRef.first));
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtGuiTypes[SBK_QCOLOR_IDX], PySequence_Fast_GET_ITEM(pyIn, 1), &(cppOutRef.second));
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_std_pair_qreal_QColor__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertiblePairTypes(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), false, PepType_SOTP(reinterpret_cast<PyTypeObject *>(SbkPySide6_QtGuiTypes[SBK_QCOLOR_IDX]))->converter, false, pyIn))
        return PySequence_PythonToCpp_std_pair_qreal_QColor_;
    return {};
}

// C++ to Python conversion for container type 'QList<std::pair< qreal,QColor>>'.
static PyObject *_QList_std_pair_qreal_QColor___CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<std::pair< qreal,QColor>> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_STD_PAIR_QREAL_QCOLOR_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_std_pair_qreal_QColor__(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<std::pair< qreal,QColor>> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::std::pair<qreal,QColor> cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_STD_PAIR_QREAL_QCOLOR_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_std_pair_qreal_QColor___Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_STD_PAIR_QREAL_QCOLOR_IDX], pyIn))
        return PySequence_PythonToCpp__QList_std_pair_qreal_QColor__;
    return {};
}

// C++ to Python conversion for container type 'QList<qsizetype>'.
static PyObject *_QList_qsizetype__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<qsizetype> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_qsizetype_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<qsizetype> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        qsizetype cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_qsizetype__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), pyIn))
        return PySequence_PythonToCpp__QList_qsizetype_;
    return {};
}

// C++ to Python conversion for container type 'QList<uint16_t>'.
static PyObject *_QList_uint16_t__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<uint16_t> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<uint16_t>(), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_uint16_t_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<uint16_t> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        uint16_t cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<uint16_t>(), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_uint16_t__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Conversions::PrimitiveTypeConverter<uint16_t>(), pyIn))
        return PySequence_PythonToCpp__QList_uint16_t_;
    return {};
}

// C++ to Python conversion for container type 'QList<QAccessibleInterface*>'.
static PyObject *_QList_QAccessibleInterfacePTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QAccessibleInterface*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(SbkPySide6_QtGuiTypes[SBK_QACCESSIBLEINTERFACE_IDX], cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QAccessibleInterfacePTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QAccessibleInterface*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QAccessibleInterface* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_QtGuiTypes[SBK_QACCESSIBLEINTERFACE_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QAccessibleInterfacePTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(SbkPySide6_QtGuiTypes[SBK_QACCESSIBLEINTERFACE_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QAccessibleInterfacePTR_;
    return {};
}

// C++ to Python conversion for container type 'std::pair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag>>'.
static PyObject *std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag___CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::std::pair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag>> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - START
    PyObject *pyOut = PyTuple_New(2);
    PyTuple_SET_ITEM(pyOut, 0, Shiboken::Conversions::pointerToPython(SbkPySide6_QtGuiTypes[SBK_QACCESSIBLEINTERFACE_IDX], cppInRef.first));
    PyTuple_SET_ITEM(pyOut, 1, Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QFLAGS_QACCESSIBLE_RELATIONFLAG_IDX]))->converter, &cppInRef.second));
    return pyOut;
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - END

}
static void PySequence_PythonToCpp_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag__(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::std::pair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag>> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - START
    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_QtGuiTypes[SBK_QACCESSIBLEINTERFACE_IDX], PySequence_Fast_GET_ITEM(pyIn, 0), &(cppOutRef.first));
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QFLAGS_QACCESSIBLE_RELATIONFLAG_IDX]))->converter, PySequence_Fast_GET_ITEM(pyIn, 1), &(cppOutRef.second));
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag___Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertiblePairTypes(PepType_SOTP(reinterpret_cast<PyTypeObject *>(SbkPySide6_QtGuiTypes[SBK_QACCESSIBLEINTERFACE_IDX]))->converter, true, PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QFLAGS_QACCESSIBLE_RELATIONFLAG_IDX]))->converter, false, pyIn))
        return PySequence_PythonToCpp_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag__;
    return {};
}

// C++ to Python conversion for container type 'QList<std::pair< QAccessibleInterface*,QFlags<QAccessible::RelationFlag>>>'.
static PyObject *_QList_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag____CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<std::pair< QAccessibleInterface*,QFlags<QAccessible::RelationFlag>>> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_STD_PAIR_QACCESSIBLEINTERFACEPTR_QFLAGS_QACCESSIBLE_RELATIONFLAG_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag___(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<std::pair< QAccessibleInterface*,QFlags<QAccessible::RelationFlag>>> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::std::pair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag>> cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_STD_PAIR_QACCESSIBLEINTERFACEPTR_QFLAGS_QACCESSIBLE_RELATIONFLAG_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag____Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_STD_PAIR_QACCESSIBLEINTERFACEPTR_QFLAGS_QACCESSIBLE_RELATIONFLAG_IDX], pyIn))
        return PySequence_PythonToCpp__QList_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag___;
    return {};
}

// C++ to Python conversion for container type 'QList<unsigned int>'.
static PyObject *_QList_unsignedint__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<unsigned int> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_unsignedint_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<unsigned int> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        unsigned int cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_unsignedint__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), pyIn))
        return PySequence_PythonToCpp__QList_unsignedint_;
    return {};
}

// C++ to Python conversion for container type 'QList<QLine>'.
static PyObject *_QList_QLine__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QLine> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypes[SBK_QLINE_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QLine_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QLine> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QLine cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypes[SBK_QLINE_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QLine__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypes[SBK_QLINE_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QLine_;
    return {};
}

// C++ to Python conversion for container type 'QList<QLineF>'.
static PyObject *_QList_QLineF__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QLineF> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypes[SBK_QLINEF_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QLineF_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QLineF> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QLineF cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypes[SBK_QLINEF_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QLineF__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypes[SBK_QLINEF_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QLineF_;
    return {};
}

// C++ to Python conversion for container type 'QList<QRect>'.
static PyObject *_QList_QRect__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QRect> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypes[SBK_QRECT_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QRect_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QRect> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QRect cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypes[SBK_QRECT_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QRect__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypes[SBK_QRECT_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QRect_;
    return {};
}

// C++ to Python conversion for container type 'QList<QRectF>'.
static PyObject *_QList_QRectF__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QRectF> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypes[SBK_QRECTF_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QRectF_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QRectF> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QRectF cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypes[SBK_QRECTF_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QRectF__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypes[SBK_QRECTF_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QRectF_;
    return {};
}

// C++ to Python conversion for container type 'QList<QKeySequence>'.
static PyObject *_QList_QKeySequence__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QKeySequence> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypes[SBK_QKEYSEQUENCE_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QKeySequence_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QKeySequence> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QKeySequence cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtGuiTypes[SBK_QKEYSEQUENCE_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QKeySequence__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtGuiTypes[SBK_QKEYSEQUENCE_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QKeySequence_;
    return {};
}

// C++ to Python conversion for container type 'QList<QObject*>'.
static PyObject *_QList_QObjectPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QObject*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(SbkPySide6_QtCoreTypes[SBK_QOBJECT_IDX], cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QObjectPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QObject*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QObject* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_QtCoreTypes[SBK_QOBJECT_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QObjectPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(SbkPySide6_QtCoreTypes[SBK_QOBJECT_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QObjectPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QByteArray>'.
static PyObject *_QList_QByteArray__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QByteArray> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypes[SBK_QBYTEARRAY_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QByteArray_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QByteArray> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QByteArray cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypes[SBK_QBYTEARRAY_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QByteArray__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypes[SBK_QBYTEARRAY_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QByteArray_;
    return {};
}

// C++ to Python conversion for container type 'QList<QUndoStack*>'.
static PyObject *_QList_QUndoStackPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QUndoStack*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(SbkPySide6_QtGuiTypes[SBK_QUNDOSTACK_IDX], cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QUndoStackPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QUndoStack*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QUndoStack* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_QtGuiTypes[SBK_QUNDOSTACK_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QUndoStackPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(SbkPySide6_QtGuiTypes[SBK_QUNDOSTACK_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QUndoStackPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QTextFrame*>'.
static PyObject *_QList_QTextFramePTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QTextFrame*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(SbkPySide6_QtGuiTypes[SBK_QTEXTFRAME_IDX], cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QTextFramePTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QTextFrame*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QTextFrame* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_QtGuiTypes[SBK_QTEXTFRAME_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QTextFramePTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(SbkPySide6_QtGuiTypes[SBK_QTEXTFRAME_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QTextFramePTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QTextBlock>'.
static PyObject *_QList_QTextBlock__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QTextBlock> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypes[SBK_QTEXTBLOCK_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QTextBlock_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QTextBlock> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QTextBlock cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtGuiTypes[SBK_QTEXTBLOCK_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QTextBlock__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtGuiTypes[SBK_QTEXTBLOCK_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QTextBlock_;
    return {};
}

// C++ to Python conversion for container type 'QList<QTextFormat>'.
static PyObject *_QList_QTextFormat__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QTextFormat> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypes[SBK_QTEXTFORMAT_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QTextFormat_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QTextFormat> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QTextFormat cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtGuiTypes[SBK_QTEXTFORMAT_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QTextFormat__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtGuiTypes[SBK_QTEXTFORMAT_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QTextFormat_;
    return {};
}

// C++ to Python conversion for container type 'QList<QScreen*>'.
static PyObject *_QList_QScreenPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QScreen*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(SbkPySide6_QtGuiTypes[SBK_QSCREEN_IDX], cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QScreenPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QScreen*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QScreen* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_QtGuiTypes[SBK_QSCREEN_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QScreenPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(SbkPySide6_QtGuiTypes[SBK_QSCREEN_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QScreenPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QOpenGLContext*>'.
static PyObject *_QList_QOpenGLContextPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QOpenGLContext*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(SbkPySide6_QtGuiTypes[SBK_QOPENGLCONTEXT_IDX], cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QOpenGLContextPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QOpenGLContext*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QOpenGLContext* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_QtGuiTypes[SBK_QOPENGLCONTEXT_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QOpenGLContextPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(SbkPySide6_QtGuiTypes[SBK_QOPENGLCONTEXT_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QOpenGLContextPTR_;
    return {};
}

// C++ to Python conversion for container type 'QSet<QByteArray>'.
static PyObject *_QSet_QByteArray__CppToPython_PySet(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QSet<QByteArray> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pyset - START
    PyObject *pyOut = PySet_New(nullptr);
    for (const auto &cppItem : cppInRef) {
        PySet_Add(pyOut, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypes[SBK_QBYTEARRAY_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pyset - END

}
static void PySequence_PythonToCpp__QSet_QByteArray_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QSet<QByteArray> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsetcontainer - START
    (cppOutRef).clear();
    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QByteArray cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypes[SBK_QBYTEARRAY_IDX], pyItem, &(cppItem));
        (cppOutRef).insert(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsetcontainer - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QSet_QByteArray__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleIterableTypes(SbkPySide6_QtCoreTypes[SBK_QBYTEARRAY_IDX], pyIn))
        return PySequence_PythonToCpp__QSet_QByteArray_;
    return {};
}

// C++ to Python conversion for container type 'QList<const QInputDevice*>'.
static PyObject *_QList_constQInputDevicePTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<const QInputDevice*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(SbkPySide6_QtGuiTypes[SBK_QINPUTDEVICE_IDX], cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_constQInputDevicePTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<const QInputDevice*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QInputDevice* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_QtGuiTypes[SBK_QINPUTDEVICE_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_constQInputDevicePTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(SbkPySide6_QtGuiTypes[SBK_QINPUTDEVICE_IDX], pyIn))
        return PySequence_PythonToCpp__QList_constQInputDevicePTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QAction*>'.
static PyObject *_QList_QActionPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QAction*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(SbkPySide6_QtGuiTypes[SBK_QACTION_IDX], cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QActionPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QAction*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QAction* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_QtGuiTypes[SBK_QACTION_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QActionPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(SbkPySide6_QtGuiTypes[SBK_QACTION_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QActionPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QAbstractTextDocumentLayout::Selection>'.
static PyObject *_QList_QAbstractTextDocumentLayout_Selection__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QAbstractTextDocumentLayout::Selection> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypes[SBK_QABSTRACTTEXTDOCUMENTLAYOUT_SELECTION_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QAbstractTextDocumentLayout_Selection_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QAbstractTextDocumentLayout::Selection> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QAbstractTextDocumentLayout::Selection cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtGuiTypes[SBK_QABSTRACTTEXTDOCUMENTLAYOUT_SELECTION_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QAbstractTextDocumentLayout_Selection__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtGuiTypes[SBK_QABSTRACTTEXTDOCUMENTLAYOUT_SELECTION_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QAbstractTextDocumentLayout_Selection_;
    return {};
}

// C++ to Python conversion for container type 'QList<QInputMethodEvent::Attribute>'.
static PyObject *_QList_QInputMethodEvent_Attribute__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QInputMethodEvent::Attribute> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypes[SBK_QINPUTMETHODEVENT_ATTRIBUTE_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QInputMethodEvent_Attribute_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QInputMethodEvent::Attribute> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QInputMethodEvent::Attribute cppItem = ::QInputMethodEvent::Attribute(QInputMethodEvent::TextFormat, int(0), int(0));
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtGuiTypes[SBK_QINPUTMETHODEVENT_ATTRIBUTE_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QInputMethodEvent_Attribute__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtGuiTypes[SBK_QINPUTMETHODEVENT_ATTRIBUTE_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QInputMethodEvent_Attribute_;
    return {};
}

// C++ to Python conversion for container type 'QList<QEventPoint>'.
static PyObject *_QList_QEventPoint__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QEventPoint> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypes[SBK_QEVENTPOINT_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QEventPoint_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QEventPoint> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QEventPoint cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtGuiTypes[SBK_QEVENTPOINT_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QEventPoint__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtGuiTypes[SBK_QEVENTPOINT_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QEventPoint_;
    return {};
}

// C++ to Python conversion for container type 'QList<QWindow*>'.
static PyObject *_QList_QWindowPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QWindow*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(SbkPySide6_QtGuiTypes[SBK_QWINDOW_IDX], cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QWindowPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QWindow*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QWindow* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_QtGuiTypes[SBK_QWINDOW_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QWindowPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(SbkPySide6_QtGuiTypes[SBK_QWINDOW_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QWindowPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QRhiShaderResourceBinding>'.
static PyObject *_QList_QRhiShaderResourceBinding__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QRhiShaderResourceBinding> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypes[SBK_QRHISHADERRESOURCEBINDING_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QRhiShaderResourceBinding_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QRhiShaderResourceBinding> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QRhiShaderResourceBinding cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtGuiTypes[SBK_QRHISHADERRESOURCEBINDING_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QRhiShaderResourceBinding__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtGuiTypes[SBK_QRHISHADERRESOURCEBINDING_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QRhiShaderResourceBinding_;
    return {};
}

// C++ to Python conversion for container type 'QList<QRhiShaderStage>'.
static PyObject *_QList_QRhiShaderStage__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QRhiShaderStage> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypes[SBK_QRHISHADERSTAGE_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QRhiShaderStage_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QRhiShaderStage> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QRhiShaderStage cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtGuiTypes[SBK_QRHISHADERSTAGE_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QRhiShaderStage__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtGuiTypes[SBK_QRHISHADERSTAGE_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QRhiShaderStage_;
    return {};
}

// C++ to Python conversion for container type 'QList<QRhiGraphicsPipeline::TargetBlend>'.
static PyObject *_QList_QRhiGraphicsPipeline_TargetBlend__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QRhiGraphicsPipeline::TargetBlend> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypes[SBK_QRHIGRAPHICSPIPELINE_TARGETBLEND_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QRhiGraphicsPipeline_TargetBlend_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QRhiGraphicsPipeline::TargetBlend> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QRhiGraphicsPipeline::TargetBlend cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtGuiTypes[SBK_QRHIGRAPHICSPIPELINE_TARGETBLEND_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QRhiGraphicsPipeline_TargetBlend__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtGuiTypes[SBK_QRHIGRAPHICSPIPELINE_TARGETBLEND_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QRhiGraphicsPipeline_TargetBlend_;
    return {};
}

// C++ to Python conversion for container type 'std::pair<int,unsigned int>'.
static PyObject *std_pair_int_unsignedint__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::std::pair<int,unsigned int> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - START
    PyObject *pyOut = PyTuple_New(2);
    PyTuple_SET_ITEM(pyOut, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppInRef.first));
    PyTuple_SET_ITEM(pyOut, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), &cppInRef.second));
    return pyOut;
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - END

}
static void PySequence_PythonToCpp_std_pair_int_unsignedint_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::std::pair<int,unsigned int> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - START
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<int>(), PySequence_Fast_GET_ITEM(pyIn, 0), &(cppOutRef.first));
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), PySequence_Fast_GET_ITEM(pyIn, 1), &(cppOutRef.second));
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_std_pair_int_unsignedint__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertiblePairTypes(Shiboken::Conversions::PrimitiveTypeConverter<int>(), false, Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), false, pyIn))
        return PySequence_PythonToCpp_std_pair_int_unsignedint_;
    return {};
}

// C++ to Python conversion for container type 'std::pair<QRhiBuffer*,quint32>'.
static PyObject *std_pair_QRhiBufferPTR_quint32__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::std::pair<QRhiBuffer*,quint32> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - START
    PyObject *pyOut = PyTuple_New(2);
    PyTuple_SET_ITEM(pyOut, 0, Shiboken::Conversions::pointerToPython(SbkPySide6_QtGuiTypes[SBK_QRHIBUFFER_IDX], cppInRef.first));
    PyTuple_SET_ITEM(pyOut, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), &cppInRef.second));
    return pyOut;
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - END

}
static void PySequence_PythonToCpp_std_pair_QRhiBufferPTR_quint32_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::std::pair<QRhiBuffer*,quint32> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - START
    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_QtGuiTypes[SBK_QRHIBUFFER_IDX], PySequence_Fast_GET_ITEM(pyIn, 0), &(cppOutRef.first));
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), PySequence_Fast_GET_ITEM(pyIn, 1), &(cppOutRef.second));
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_std_pair_QRhiBufferPTR_quint32__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertiblePairTypes(PepType_SOTP(reinterpret_cast<PyTypeObject *>(SbkPySide6_QtGuiTypes[SBK_QRHIBUFFER_IDX]))->converter, true, Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), false, pyIn))
        return PySequence_PythonToCpp_std_pair_QRhiBufferPTR_quint32_;
    return {};
}

// C++ to Python conversion for container type 'QList<std::pair< QRhiBuffer*,quint32>>'.
static PyObject *_QList_std_pair_QRhiBufferPTR_quint32___CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<std::pair< QRhiBuffer*,quint32>> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_STD_PAIR_QRHIBUFFERPTR_QUINT32_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_std_pair_QRhiBufferPTR_quint32__(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<std::pair< QRhiBuffer*,quint32>> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::std::pair<QRhiBuffer*,quint32> cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_STD_PAIR_QRHIBUFFERPTR_QUINT32_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_std_pair_QRhiBufferPTR_quint32___Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_STD_PAIR_QRHIBUFFERPTR_QUINT32_IDX], pyIn))
        return PySequence_PythonToCpp__QList_std_pair_QRhiBufferPTR_quint32__;
    return {};
}

// C++ to Python conversion for container type 'std::pair<QRhiBuffer*,unsigned int>'.
static PyObject *std_pair_QRhiBufferPTR_unsignedint__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::std::pair<QRhiBuffer*,unsigned int> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - START
    PyObject *pyOut = PyTuple_New(2);
    PyTuple_SET_ITEM(pyOut, 0, Shiboken::Conversions::pointerToPython(SbkPySide6_QtGuiTypes[SBK_QRHIBUFFER_IDX], cppInRef.first));
    PyTuple_SET_ITEM(pyOut, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), &cppInRef.second));
    return pyOut;
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - END

}
static void PySequence_PythonToCpp_std_pair_QRhiBufferPTR_unsignedint_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::std::pair<QRhiBuffer*,unsigned int> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - START
    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_QtGuiTypes[SBK_QRHIBUFFER_IDX], PySequence_Fast_GET_ITEM(pyIn, 0), &(cppOutRef.first));
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), PySequence_Fast_GET_ITEM(pyIn, 1), &(cppOutRef.second));
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_std_pair_QRhiBufferPTR_unsignedint__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertiblePairTypes(PepType_SOTP(reinterpret_cast<PyTypeObject *>(SbkPySide6_QtGuiTypes[SBK_QRHIBUFFER_IDX]))->converter, true, Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), false, pyIn))
        return PySequence_PythonToCpp_std_pair_QRhiBufferPTR_unsignedint_;
    return {};
}

// C++ to Python conversion for container type 'QList<QModelIndex>'.
static PyObject *_QList_QModelIndex__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QModelIndex> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypes[SBK_QMODELINDEX_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QModelIndex_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QModelIndex> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QModelIndex cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypes[SBK_QMODELINDEX_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QModelIndex__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypes[SBK_QMODELINDEX_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QModelIndex_;
    return {};
}

// C++ to Python conversion for container type 'QHash<int,QByteArray>'.
static PyObject *_QHash_int_QByteArray__CppToPython_PyDict(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QHash<int,QByteArray> *>(cppIn);
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - START
    PyObject *pyOut = PyDict_New();
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it) {
        const auto &key = it.key();
        const auto &value = it.value();
        PyObject *pyKey = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &key);
        PyObject *pyValue = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypes[SBK_QBYTEARRAY_IDX], &value);
        PyDict_SetItem(pyOut, pyKey, pyValue);
        Py_DECREF(pyKey);
        Py_DECREF(pyValue);
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - END

}
static void PyDict_PythonToCpp__QHash_int_QByteArray_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QHash<int,QByteArray> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - START
    PyObject *key;
    PyObject *value;
    cppOutRef.clear();
    Py_ssize_t pos = 0;
    while (PyDict_Next(pyIn, &pos, &key, &value)) {
        int cppKey;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<int>(), key, &(cppKey));
        ::QByteArray cppValue;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypes[SBK_QBYTEARRAY_IDX], value, &(cppValue));
        cppOutRef.insert(cppKey, cppValue);
    }
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - END

}
static PythonToCppFunc is_PyDict_PythonToCpp__QHash_int_QByteArray__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleDictTypes(Shiboken::Conversions::PrimitiveTypeConverter<int>(), false, PepType_SOTP(reinterpret_cast<PyTypeObject *>(SbkPySide6_QtCoreTypes[SBK_QBYTEARRAY_IDX]))->converter, false, pyIn))
        return PyDict_PythonToCpp__QHash_int_QByteArray_;
    return {};
}

// C++ to Python conversion for container type 'QList<QVariant>'.
static PyObject *_QList_QVariant__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QVariant> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVARIANT_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QVariant_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QVariant> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QVariant cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QVARIANT_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QVariant__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypeConverters[SBK_QVARIANT_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QVariant_;
    return {};
}

// C++ to Python conversion for container type 'QList<QString>'.
static PyObject *_QList_QString__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QString> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QSTRING_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QString_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QString> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QString cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QSTRING_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QString__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypeConverters[SBK_QSTRING_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QString_;
    return {};
}

// C++ to Python conversion for container type 'QMap<QString,QVariant>'.
static PyObject *_QMap_QString_QVariant__CppToPython_PyDict(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QMap<QString,QVariant> *>(cppIn);
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - START
    PyObject *pyOut = PyDict_New();
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it) {
        const auto &key = it.key();
        const auto &value = it.value();
        PyObject *pyKey = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QSTRING_IDX], &key);
        PyObject *pyValue = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVARIANT_IDX], &value);
        PyDict_SetItem(pyOut, pyKey, pyValue);
        Py_DECREF(pyKey);
        Py_DECREF(pyValue);
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - END

}
static void PyDict_PythonToCpp__QMap_QString_QVariant_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QMap<QString,QVariant> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - START
    PyObject *key;
    PyObject *value;
    cppOutRef.clear();
    Py_ssize_t pos = 0;
    while (PyDict_Next(pyIn, &pos, &key, &value)) {
        ::QString cppKey;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QSTRING_IDX], key, &(cppKey));
        ::QVariant cppValue;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QVARIANT_IDX], value, &(cppValue));
        cppOutRef.insert(cppKey, cppValue);
    }
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - END

}
static PythonToCppFunc is_PyDict_PythonToCpp__QMap_QString_QVariant__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleDictTypes(SbkPySide6_QtCoreTypeConverters[SBK_QSTRING_IDX], false, SbkPySide6_QtCoreTypeConverters[SBK_QVARIANT_IDX], false, pyIn))
        return PyDict_PythonToCpp__QMap_QString_QVariant_;
    return {};
}


static struct PyModuleDef moduledef = {
    /* m_base     */ PyModuleDef_HEAD_INIT,
    /* m_name     */ "QtGui",
    /* m_doc      */ nullptr,
    /* m_size     */ -1,
    /* m_methods  */ QtGui_methods,
    /* m_reload   */ nullptr,
    /* m_traverse */ nullptr,
    /* m_clear    */ nullptr,
    /* m_free     */ nullptr
};

// The signatures string for the global functions.
// Multiple signatures have their index "n:" in front.
static const char *QtGui_SignatureStrings[] = {
    "PySide6.QtGui.qAlpha(rgb:unsigned int)->int",
    "PySide6.QtGui.qBlue(rgb:unsigned int)->int",
    "5:PySide6.QtGui.qFuzzyCompare(arg__1:PySide6.QtGui.QTransform,arg__2:PySide6.QtGui.QTransform)->bool",
    "4:PySide6.QtGui.qFuzzyCompare(arg__1:PySide6.QtGui.QQuaternion,arg__2:PySide6.QtGui.QQuaternion)->bool",
    "3:PySide6.QtGui.qFuzzyCompare(arg__1:typing.Union[PySide6.QtGui.QMatrix4x4, PySide6.QtGui.QTransform],arg__2:typing.Union[PySide6.QtGui.QMatrix4x4, PySide6.QtGui.QTransform])->bool",
    "2:PySide6.QtGui.qFuzzyCompare(arg__1:PySide6.QtGui.QVector2D,arg__2:PySide6.QtGui.QVector2D)->bool",
    "1:PySide6.QtGui.qFuzzyCompare(arg__1:PySide6.QtGui.QVector3D,arg__2:PySide6.QtGui.QVector3D)->bool",
    "0:PySide6.QtGui.qFuzzyCompare(arg__1:PySide6.QtGui.QVector4D,arg__2:PySide6.QtGui.QVector4D)->bool",
    "1:PySide6.QtGui.qGray(rgb:unsigned int)->int",
    "0:PySide6.QtGui.qGray(r:int,g:int,b:int)->int",
    "PySide6.QtGui.qGreen(rgb:unsigned int)->int",
    "PySide6.QtGui.qIsGray(rgb:unsigned int)->bool",
    "PySide6.QtGui.qPixelFormatAlpha(channelSize:uchar,typeInt:PySide6.QtGui.QPixelFormat.TypeInterpretation=QPixelFormat.UnsignedInteger)->PySide6.QtGui.QPixelFormat",
    "PySide6.QtGui.qPixelFormatCmyk(channelSize:uchar,alfa:uchar=0,usage:PySide6.QtGui.QPixelFormat.AlphaUsage=QPixelFormat.IgnoresAlpha,position:PySide6.QtGui.QPixelFormat.AlphaPosition=QPixelFormat.AtBeginning,typeInt:PySide6.QtGui.QPixelFormat.TypeInterpretation=QPixelFormat.UnsignedInteger)->PySide6.QtGui.QPixelFormat",
    "PySide6.QtGui.qPixelFormatGrayscale(channelSize:uchar,typeInt:PySide6.QtGui.QPixelFormat.TypeInterpretation=QPixelFormat.UnsignedInteger)->PySide6.QtGui.QPixelFormat",
    "PySide6.QtGui.qPixelFormatHsl(channelSize:uchar,alfa:uchar=0,usage:PySide6.QtGui.QPixelFormat.AlphaUsage=QPixelFormat.IgnoresAlpha,position:PySide6.QtGui.QPixelFormat.AlphaPosition=QPixelFormat.AtBeginning,typeInt:PySide6.QtGui.QPixelFormat.TypeInterpretation=QPixelFormat.FloatingPoint)->PySide6.QtGui.QPixelFormat",
    "PySide6.QtGui.qPixelFormatHsv(channelSize:uchar,alfa:uchar=0,usage:PySide6.QtGui.QPixelFormat.AlphaUsage=QPixelFormat.IgnoresAlpha,position:PySide6.QtGui.QPixelFormat.AlphaPosition=QPixelFormat.AtBeginning,typeInt:PySide6.QtGui.QPixelFormat.TypeInterpretation=QPixelFormat.FloatingPoint)->PySide6.QtGui.QPixelFormat",
    "PySide6.QtGui.qPixelFormatRgba(red:uchar,green:uchar,blue:uchar,alfa:uchar,usage:PySide6.QtGui.QPixelFormat.AlphaUsage,position:PySide6.QtGui.QPixelFormat.AlphaPosition,pmul:PySide6.QtGui.QPixelFormat.AlphaPremultiplied=QPixelFormat.NotPremultiplied,typeInt:PySide6.QtGui.QPixelFormat.TypeInterpretation=QPixelFormat.UnsignedInteger)->PySide6.QtGui.QPixelFormat",
    "PySide6.QtGui.qPixelFormatYuv(layout:PySide6.QtGui.QPixelFormat.YUVLayout,alfa:uchar=0,usage:PySide6.QtGui.QPixelFormat.AlphaUsage=QPixelFormat.IgnoresAlpha,position:PySide6.QtGui.QPixelFormat.AlphaPosition=QPixelFormat.AtBeginning,p_mul:PySide6.QtGui.QPixelFormat.AlphaPremultiplied=QPixelFormat.NotPremultiplied,typeInt:PySide6.QtGui.QPixelFormat.TypeInterpretation=QPixelFormat.UnsignedByte,b_order:PySide6.QtGui.QPixelFormat.ByteOrder=QPixelFormat.LittleEndian)->PySide6.QtGui.QPixelFormat",
    "PySide6.QtGui.qRed(rgb:unsigned int)->int",
    "PySide6.QtGui.qRgb(r:int,g:int,b:int)->unsigned int",
    "PySide6.QtGui.qRgba(r:int,g:int,b:int,a:int)->unsigned int",
    "PySide6.QtGui.qt_set_sequence_auto_mnemonic(b:bool)",
    nullptr}; // Sentinel

extern "C" LIBSHIBOKEN_EXPORT PyObject *PyInit_QtGui()
{
    if (SbkPySide6_QtGuiModuleObject != nullptr)
        return SbkPySide6_QtGuiModuleObject;
    {
        Shiboken::AutoDecRef requiredModule(Shiboken::Module::import("PySide6.QtCore"));
        if (requiredModule.isNull())
            return nullptr;
        SbkPySide6_QtCoreTypes = Shiboken::Module::getTypes(requiredModule);
        SbkPySide6_QtCoreTypeConverters = Shiboken::Module::getTypeConverters(requiredModule);
    }

    // Create an array of wrapper types for the current module.
    static PyTypeObject *cppApi[SBK_QtGui_IDX_COUNT];
    SbkPySide6_QtGuiTypes = cppApi;

    // Create an array of primitive type converters for the current module.
    static SbkConverter *sbkConverters[SBK_QtGui_CONVERTERS_IDX_COUNT];
    SbkPySide6_QtGuiTypeConverters = sbkConverters;

    PyObject *module = Shiboken::Module::create("QtGui", &moduledef);

    // Make module available from global scope
    SbkPySide6_QtGuiModuleObject = module;

    // Initialize classes in the type system
    init_QtGuiQt(module);
    init_QVector4D(module);
    init_QVector3D(module);
    init_QVector2D(module);
    init_QUndoCommand(module);
    init_QTransform(module);
    init_QTextTableCell(module);
    init_QTextOption(module);
    init_QTextOption_Tab(reinterpret_cast<PyObject *>(SbkPySide6_QtGuiTypes[SBK_QTEXTOPTION_IDX]));
    init_QTextObjectInterface(module);
    init_QTextLine(module);
    init_QTextLength(module);
    init_QTextItem(module);
    init_QTextInlineObject(module);
    init_QTextFragment(module);
    init_QTextFormat(module);
    init_QTextListFormat(module);
    init_QTextFrameFormat(module);
    init_QTextTableFormat(module);
    init_QTextDocumentFragment(module);
    init_QTextCursor(module);
    init_QTextCharFormat(module);
    init_QTextTableCellFormat(module);
    init_QTextImageFormat(module);
    init_QTextBlockUserData(module);
    init_QTextBlockFormat(module);
    init_QTextBlock(module);
    init_QTextBlock_iterator(reinterpret_cast<PyObject *>(SbkPySide6_QtGuiTypes[SBK_QTEXTBLOCK_IDX]));
    init_QSurfaceFormat(module);
    init_QSurface(module);
    init_QStandardItem(module);
    init_QShaderVersion(module);
    init_QShaderKey(module);
    init_QShader(module);
    init_QRhiViewport(module);
    init_QRhiVertexInputLayout(module);
    init_QRhiVertexInputBinding(module);
    init_QRhiVertexInputAttribute(module);
    init_QRhiTextureUploadEntry(module);
    init_QRhiTextureUploadDescription(module);
    init_QRhiTextureSubresourceUploadDescription(module);
    init_QRhiTextureRenderTargetDescription(module);
    init_QRhiTextureCopyDescription(module);
    init_QRhiStats(module);
    init_QRhiShaderStage(module);
    init_QRhiShaderResourceBinding(module);
    init_QRhiShaderResourceBinding_Data(reinterpret_cast<PyObject *>(SbkPySide6_QtGuiTypes[SBK_QRHISHADERRESOURCEBINDING_IDX]));
    init_QRhiScissor(module);
    init_QRhiResourceUpdateBatch(module);
    init_QRhiReadbackDescription(module);
    init_QRhiNativeHandles(module);
    init_QRhiInitParams(module);
    init_QRhiNullInitParams(module);
    init_QRhiDepthStencilClearValue(module);
    init_QRhiColorAttachment(module);
    init_QRhi(module);
    init_QRgba64(module);
    init_QRegion(module);
    init_QRawFont(module);
    init_QQuaternion(module);
    init_QPolygonF(module);
    init_QPolygon(module);
    init_QPointingDeviceUniqueId(module);
    init_QPixmapCache(module);
    init_QPixmapCache_Key(reinterpret_cast<PyObject *>(SbkPySide6_QtGuiTypes[SBK_QPIXMAPCACHE_IDX]));
    init_QPixelFormat(module);
    init_QPen(module);
    init_QPalette(module);
    init_QPainterPathStroker(module);
    init_QPainterPath(module);
    init_QPainterPath_Element(reinterpret_cast<PyObject *>(SbkPySide6_QtGuiTypes[SBK_QPAINTERPATH_IDX]));
    init_QPaintEngineState(module);
    init_QPaintEngine(module);
    init_QPaintDevice(module);
    init_QPicture(module);
    init_QPagedPaintDevice(module);
    init_QPageSize(module);
    init_QPageRanges(module);
    init_QPageRanges_Range(reinterpret_cast<PyObject *>(SbkPySide6_QtGuiTypes[SBK_QPAGERANGES_IDX]));
    init_QtGuiHelper_QOverrideCursorGuard(module);
    init_QOpenGLFunctions(module);
    init_QOpenGLExtraFunctions(module);
    init_QMatrix4x4(module);
    init_QMatrix4x3(module);
    init_QMatrix4x2(module);
    init_QMatrix3x4(module);
    init_QMatrix3x3(module);
    init_QMatrix3x2(module);
    init_QMatrix2x4(module);
    init_QMatrix2x3(module);
    init_QMatrix2x2(module);
    init_QImageIOHandler(module);
    init_QIconEngine(module);
    init_QGradient(module);
    init_QRadialGradient(module);
    init_QLinearGradient(module);
    init_QGlyphRun(module);
    init_QFontMetricsF(module);
    init_QFontMetrics(module);
    init_QFontInfo(module);
    init_QFontDatabase(module);
    init_QFont(module);
    init_QStaticText(module);
    init_QEventPoint(module);
    init_QDesktopServices(module);
    init_QCursor(module);
    init_QConicalGradient(module);
    init_QColorTransform(module);
    init_QColorSpace(module);
    init_QColor(module);
    init_QtGuiQColorConstants(module);
    init_QtGuiQColorConstants_Svg(reinterpret_cast<PyObject *>(SbkPySide6_QtGuiTypes[SBK_QtGuiQCOLORCONSTANTS_IDX]));
    init_QBrush(module);
    init_QAccessibleValueInterface(module);
    init_QAccessibleTextInterface(module);
    init_QAccessibleTableCellInterface(module);
    init_QAccessibleInterface(module);
    init_QAccessibleObject(module);
    init_QAccessibleEvent(module);
    init_QAccessibleValueChangeEvent(module);
    init_QAccessibleTextCursorEvent(module);
    init_QAccessibleTextUpdateEvent(module);
    init_QAccessibleTextSelectionEvent(module);
    init_QAccessibleTextRemoveEvent(module);
    init_QAccessibleTextInsertEvent(module);
    init_QAccessibleTableModelChangeEvent(module);
    init_QAccessibleStateChangeEvent(module);
    init_QAccessibleEditableTextInterface(module);
    init_QAccessibleActionInterface(module);
    init_QAccessible(module);
    init_QAccessible_State(reinterpret_cast<PyObject *>(SbkPySide6_QtGuiTypes[SBK_QACCESSIBLE_IDX]));
    init_QAbstractFileIconProvider(module);
    init_QIcon(module);
    init_QTextLayout(module);
    init_QTextLayout_FormatRange(reinterpret_cast<PyObject *>(SbkPySide6_QtGuiTypes[SBK_QTEXTLAYOUT_IDX]));
    init_QPixmap(module);
    init_QIconEngine_ScaledPixmapArgument(reinterpret_cast<PyObject *>(SbkPySide6_QtGuiTypes[SBK_QICONENGINE_IDX]));
    init_QImage(module);
    init_QBitmap(module);
    init_QPainter(module);
    init_QPainter_PixmapFragment(reinterpret_cast<PyObject *>(SbkPySide6_QtGuiTypes[SBK_QPAINTER_IDX]));
    init_QBackingStore(module);
    init_QPageLayout(module);
    init_QKeySequence(module);
    init_QWindow(module);
    init_QPaintDeviceWindow(module);
    init_QRasterWindow(module);
    init_QValidator(module);
    init_QRegularExpressionValidator(module);
    init_QIntValidator(module);
    init_QDoubleValidator(module);
    init_QUndoStack(module);
    init_QUndoGroup(module);
    init_QTextObject(module);
    init_QTextFrame(module);
    init_QTextTable(module);
    init_QTextFrame_iterator(reinterpret_cast<PyObject *>(SbkPySide6_QtGuiTypes[SBK_QTEXTFRAME_IDX]));
    init_QTextBlockGroup(module);
    init_QTextList(module);
    init_QTextDocument(module);
    init_QSyntaxHighlighter(module);
    init_QStyleHints(module);
    init_QShortcut(module);
    init_QSessionManager(module);
    init_QScreen(module);
    init_QPyTextObject(module);
    init_QPdfWriter(module);
    init_QOpenGLContextGroup(module);
    init_QOpenGLContext(module);
    init_QRhiGles2NativeHandles(module);
    init_QRhiGles2InitParams(module);
    init_QOffscreenSurface(module);
    init_QInputMethod(module);
    init_QInputDevice(module);
    init_QPointingDevice(module);
    init_QDrag(module);
    init_QClipboard(module);
    init_QActionGroup(module);
    init_QAction(module);
    init_QAbstractTextDocumentLayout(module);
    init_QAbstractTextDocumentLayout_Selection(reinterpret_cast<PyObject *>(SbkPySide6_QtGuiTypes[SBK_QABSTRACTTEXTDOCUMENTLAYOUT_IDX]));
    init_QAbstractTextDocumentLayout_PaintContext(reinterpret_cast<PyObject *>(SbkPySide6_QtGuiTypes[SBK_QABSTRACTTEXTDOCUMENTLAYOUT_IDX]));
    init_QWindowStateChangeEvent(module);
    init_QWhatsThisClickedEvent(module);
    init_QToolBarChangeEvent(module);
    init_QStatusTipEvent(module);
    init_QShowEvent(module);
    init_QShortcutEvent(module);
    init_QScrollPrepareEvent(module);
    init_QScrollEvent(module);
    init_QResizeEvent(module);
    init_QPlatformSurfaceEvent(module);
    init_QPaintEvent(module);
    init_QMoveEvent(module);
    init_QInputMethodQueryEvent(module);
    init_QInputMethodEvent(module);
    init_QInputMethodEvent_Attribute(reinterpret_cast<PyObject *>(SbkPySide6_QtGuiTypes[SBK_QINPUTMETHODEVENT_IDX]));
    init_QInputEvent(module);
    init_QPointerEvent(module);
    init_QTouchEvent(module);
    init_QSinglePointEvent(module);
    init_QWheelEvent(module);
    init_QTabletEvent(module);
    init_QNativeGestureEvent(module);
    init_QMouseEvent(module);
    init_QHoverEvent(module);
    init_QEnterEvent(module);
    init_QKeyEvent(module);
    init_QContextMenuEvent(module);
    init_QIconDragEvent(module);
    init_QHideEvent(module);
    init_QHelpEvent(module);
    init_QFocusEvent(module);
    init_QFileOpenEvent(module);
    init_QExposeEvent(module);
    init_QDropEvent(module);
    init_QDragMoveEvent(module);
    init_QDragEnterEvent(module);
    init_QDragLeaveEvent(module);
    init_QCloseEvent(module);
    init_QActionEvent(module);
    init_QGuiApplication(module);
    init_QTextDocumentWriter(module);
    init_QShaderCode(module);
    init_QRhiResource(module);
    init_QRhiTexture(module);
    init_QRhiShaderResourceBinding_Data_StorageImageData(reinterpret_cast<PyObject *>(SbkPySide6_QtGuiTypes[SBK_QRHISHADERRESOURCEBINDING_DATA_IDX]));
    init_QRhiShaderResourceBindings(module);
    init_QRhiSampler(module);
    init_QRhiShaderResourceBinding_TextureAndSampler(reinterpret_cast<PyObject *>(SbkPySide6_QtGuiTypes[SBK_QRHISHADERRESOURCEBINDING_IDX]));
    init_QRhiRenderPassDescriptor(module);
    init_QRhiRenderTarget(module);
    init_QRhiTextureRenderTarget(module);
    init_QRhiRenderBuffer(module);
    init_QRhiSwapChain(module);
    init_QRhiSwapChainRenderTarget(module);
    init_QRhiGraphicsPipeline(module);
    init_QRhiGraphicsPipeline_TargetBlend(reinterpret_cast<PyObject *>(SbkPySide6_QtGuiTypes[SBK_QRHIGRAPHICSPIPELINE_IDX]));
    init_QRhiComputePipeline(module);
    init_QRhiCommandBuffer(module);
    init_QRhiBuffer(module);
    init_QRhiShaderResourceBinding_Data_StorageBufferData(reinterpret_cast<PyObject *>(SbkPySide6_QtGuiTypes[SBK_QRHISHADERRESOURCEBINDING_DATA_IDX]));
    init_QRhiReadbackResult(module);
    init_QRhiDriverInfo(module);
    init_QMovie(module);
    init_QImageWriter(module);
    init_QImageReader(module);
    init_QStandardItemModel(module);

    // Register converter for type 'PySide6.QtGui.WId'.
    SbkPySide6_QtGuiTypeConverters[SBK_WID_IDX] = Shiboken::Conversions::createConverter(&PyLong_Type, WId_CppToPython_WId);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_WID_IDX], "WId");
    // Add user defined implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_WID_IDX],
        PyLong_PythonToCpp_WId,
        is_PyLong_PythonToCpp_WId_Convertible);


    // Register converter for type 'QList<int>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_INT_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_int__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_INT_IDX], "QList<int>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_INT_IDX],
        PySequence_PythonToCpp__QList_int_,
        is_PySequence_PythonToCpp__QList_int__Convertible);
    Shiboken::Conversions::setPythonToCppPointerFunctions(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_INT_IDX],
        PythonToCppQIntList,
        isQIntListPythonToCppConvertible);

    // Register converter for type 'QList<QVector2D>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QVECTOR2D_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QVector2D__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QVECTOR2D_IDX], "QList<QVector2D>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QVECTOR2D_IDX],
        PySequence_PythonToCpp__QList_QVector2D_,
        is_PySequence_PythonToCpp__QList_QVector2D__Convertible);
    Shiboken::Conversions::setPythonToCppPointerFunctions(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QVECTOR2D_IDX],
        PythonToCppQVector2DList,
        isQVector2DListPythonToCppConvertible);

    // Register converter for type 'QList<QVector3D>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QVECTOR3D_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QVector3D__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QVECTOR3D_IDX], "QList<QVector3D>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QVECTOR3D_IDX],
        PySequence_PythonToCpp__QList_QVector3D_,
        is_PySequence_PythonToCpp__QList_QVector3D__Convertible);
    Shiboken::Conversions::setPythonToCppPointerFunctions(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QVECTOR3D_IDX],
        PythonToCppQVector3DList,
        isQVector3DListPythonToCppConvertible);

    // Register converter for type 'QList<QVector4D>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QVECTOR4D_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QVector4D__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QVECTOR4D_IDX], "QList<QVector4D>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QVECTOR4D_IDX],
        PySequence_PythonToCpp__QList_QVector4D_,
        is_PySequence_PythonToCpp__QList_QVector4D__Convertible);
    Shiboken::Conversions::setPythonToCppPointerFunctions(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QVECTOR4D_IDX],
        PythonToCppQVector4DList,
        isQVector4DListPythonToCppConvertible);

    // Register converter for type 'QList<qreal>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QREAL_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_qreal__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QREAL_IDX], "QList<qreal>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QREAL_IDX],
        PySequence_PythonToCpp__QList_qreal_,
        is_PySequence_PythonToCpp__QList_qreal__Convertible);

    // Register converter for type 'QList<QTextOption::Tab>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QTEXTOPTION_TAB_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QTextOption_Tab__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QTEXTOPTION_TAB_IDX], "QList<QTextOption::Tab>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QTEXTOPTION_TAB_IDX],
        PySequence_PythonToCpp__QList_QTextOption_Tab_,
        is_PySequence_PythonToCpp__QList_QTextOption_Tab__Convertible);

    // Register converter for type 'QList<QGlyphRun>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QGLYPHRUN_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QGlyphRun__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QGLYPHRUN_IDX], "QList<QGlyphRun>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QGLYPHRUN_IDX],
        PySequence_PythonToCpp__QList_QGlyphRun_,
        is_PySequence_PythonToCpp__QList_QGlyphRun__Convertible);

    // Register converter for type 'QList<QTextLength>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QTEXTLENGTH_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QTextLength__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QTEXTLENGTH_IDX], "QList<QTextLength>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QTEXTLENGTH_IDX],
        PySequence_PythonToCpp__QList_QTextLength_,
        is_PySequence_PythonToCpp__QList_QTextLength__Convertible);

    // Register converter for type 'QMap<int,QVariant>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QMAP_INT_QVARIANT_IDX] = Shiboken::Conversions::createConverter(&PyDict_Type, _QMap_int_QVariant__CppToPython_PyDict);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QMAP_INT_QVARIANT_IDX], "QMap<int,QVariant>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QMAP_INT_QVARIANT_IDX],
        PyDict_PythonToCpp__QMap_int_QVariant_,
        is_PyDict_PythonToCpp__QMap_int_QVariant__Convertible);

    // Register converter for type 'QList<QTextLayout::FormatRange>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QTEXTLAYOUT_FORMATRANGE_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QTextLayout_FormatRange__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QTEXTLAYOUT_FORMATRANGE_IDX], "QList<QTextLayout::FormatRange>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QTEXTLAYOUT_FORMATRANGE_IDX],
        PySequence_PythonToCpp__QList_QTextLayout_FormatRange_,
        is_PySequence_PythonToCpp__QList_QTextLayout_FormatRange__Convertible);

    // Register converter for type 'std::pair<int,int>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_STD_PAIR_INT_INT_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, std_pair_int_int__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_STD_PAIR_INT_INT_IDX], "std::pair<int,int>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_STD_PAIR_INT_INT_IDX],
        PySequence_PythonToCpp_std_pair_int_int_,
        is_PySequence_PythonToCpp_std_pair_int_int__Convertible);

    // Register converter for type 'QList<QStandardItem*>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QSTANDARDITEMPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QStandardItemPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QSTANDARDITEMPTR_IDX], "QList<QStandardItem*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QSTANDARDITEMPTR_IDX],
        PySequence_PythonToCpp__QList_QStandardItemPTR_,
        is_PySequence_PythonToCpp__QList_QStandardItemPTR__Convertible);

    // Register converter for type 'QList<QShaderKey>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QSHADERKEY_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QShaderKey__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QSHADERKEY_IDX], "QList<QShaderKey>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QSHADERKEY_IDX],
        PySequence_PythonToCpp__QList_QShaderKey_,
        is_PySequence_PythonToCpp__QList_QShaderKey__Convertible);

    // Register converter for type 'QMap<int,std::pair<int,int>>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QMAP_INT_STD_PAIR_INT_INT_IDX] = Shiboken::Conversions::createConverter(&PyDict_Type, _QMap_int_std_pair_int_int___CppToPython_PyDict);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QMAP_INT_STD_PAIR_INT_INT_IDX], "QMap<int,std::pair<int,int>>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QMAP_INT_STD_PAIR_INT_INT_IDX],
        PyDict_PythonToCpp__QMap_int_std_pair_int_int__,
        is_PyDict_PythonToCpp__QMap_int_std_pair_int_int___Convertible);

    // Register converter for type 'std::array<float,4>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_STD_ARRAY_FLOAT_4_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, std_array_float_4__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_STD_ARRAY_FLOAT_4_IDX], "std::array<float,4>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_STD_ARRAY_FLOAT_4_IDX],
        PySequence_PythonToCpp_std_array_float_4_,
        is_PySequence_PythonToCpp_std_array_float_4__Convertible);

    // Register converter for type 'QList<QRhiVertexInputAttribute>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QRHIVERTEXINPUTATTRIBUTE_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QRhiVertexInputAttribute__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QRHIVERTEXINPUTATTRIBUTE_IDX], "QList<QRhiVertexInputAttribute>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QRHIVERTEXINPUTATTRIBUTE_IDX],
        PySequence_PythonToCpp__QList_QRhiVertexInputAttribute_,
        is_PySequence_PythonToCpp__QList_QRhiVertexInputAttribute__Convertible);

    // Register converter for type 'QList<QRhiVertexInputBinding>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QRHIVERTEXINPUTBINDING_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QRhiVertexInputBinding__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QRHIVERTEXINPUTBINDING_IDX], "QList<QRhiVertexInputBinding>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QRHIVERTEXINPUTBINDING_IDX],
        PySequence_PythonToCpp__QList_QRhiVertexInputBinding_,
        is_PySequence_PythonToCpp__QList_QRhiVertexInputBinding__Convertible);

    // Register converter for type 'QList<QRhiTextureUploadEntry>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QRHITEXTUREUPLOADENTRY_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QRhiTextureUploadEntry__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QRHITEXTUREUPLOADENTRY_IDX], "QList<QRhiTextureUploadEntry>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QRHITEXTUREUPLOADENTRY_IDX],
        PySequence_PythonToCpp__QList_QRhiTextureUploadEntry_,
        is_PySequence_PythonToCpp__QList_QRhiTextureUploadEntry__Convertible);

    // Register converter for type 'QList<QRhiColorAttachment>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QRHICOLORATTACHMENT_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QRhiColorAttachment__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QRHICOLORATTACHMENT_IDX], "QList<QRhiColorAttachment>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QRHICOLORATTACHMENT_IDX],
        PySequence_PythonToCpp__QList_QRhiColorAttachment_,
        is_PySequence_PythonToCpp__QList_QRhiColorAttachment__Convertible);

    // Register converter for type 'std::array<int,4>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_STD_ARRAY_INT_4_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, std_array_int_4__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_STD_ARRAY_INT_4_IDX], "std::array<int,4>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_STD_ARRAY_INT_4_IDX],
        PySequence_PythonToCpp_std_array_int_4_,
        is_PySequence_PythonToCpp_std_array_int_4__Convertible);

    // Register converter for type 'QList<QPointF>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QPOINTF_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QPointF__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QPOINTF_IDX], "QList<QPointF>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QPOINTF_IDX],
        PySequence_PythonToCpp__QList_QPointF_,
        is_PySequence_PythonToCpp__QList_QPointF__Convertible);
    Shiboken::Conversions::setPythonToCppPointerFunctions(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QPOINTF_IDX],
        PythonToCppQPointFList,
        isQPointFListPythonToCppConvertible);

    // Register converter for type 'QList<quint32>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QUINT32_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_quint32__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QUINT32_IDX], "QList<quint32>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QUINT32_IDX],
        PySequence_PythonToCpp__QList_quint32_,
        is_PySequence_PythonToCpp__QList_quint32__Convertible);

    // Register converter for type 'QList<QFontDatabase::WritingSystem>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QFONTDATABASE_WRITINGSYSTEM_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QFontDatabase_WritingSystem__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QFONTDATABASE_WRITINGSYSTEM_IDX], "QList<QFontDatabase::WritingSystem>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QFONTDATABASE_WRITINGSYSTEM_IDX],
        PySequence_PythonToCpp__QList_QFontDatabase_WritingSystem_,
        is_PySequence_PythonToCpp__QList_QFontDatabase_WritingSystem__Convertible);

    // Register converter for type 'QList<QPoint>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QPOINT_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QPoint__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QPOINT_IDX], "QList<QPoint>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QPOINT_IDX],
        PySequence_PythonToCpp__QList_QPoint_,
        is_PySequence_PythonToCpp__QList_QPoint__Convertible);
    Shiboken::Conversions::setPythonToCppPointerFunctions(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QPOINT_IDX],
        PythonToCppQPointList,
        isQPointListPythonToCppConvertible);

    // Register converter for type 'QList<QPolygonF>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QPOLYGONF_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QPolygonF__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QPOLYGONF_IDX], "QList<QPolygonF>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QPOLYGONF_IDX],
        PySequence_PythonToCpp__QList_QPolygonF_,
        is_PySequence_PythonToCpp__QList_QPolygonF__Convertible);

    // Register converter for type 'QList<QPageRanges::Range>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QPAGERANGES_RANGE_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QPageRanges_Range__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QPAGERANGES_RANGE_IDX], "QList<QPageRanges::Range>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QPAGERANGES_RANGE_IDX],
        PySequence_PythonToCpp__QList_QPageRanges_Range_,
        is_PySequence_PythonToCpp__QList_QPageRanges_Range__Convertible);

    // Register converter for type 'QList<float>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_FLOAT_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_float__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_FLOAT_IDX], "QList<float>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_FLOAT_IDX],
        PySequence_PythonToCpp__QList_float_,
        is_PySequence_PythonToCpp__QList_float__Convertible);

    // Register converter for type 'QList<QSize>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QSIZE_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QSize__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QSIZE_IDX], "QList<QSize>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QSIZE_IDX],
        PySequence_PythonToCpp__QList_QSize_,
        is_PySequence_PythonToCpp__QList_QSize__Convertible);

    // Register converter for type 'std::pair<qreal,QColor>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_STD_PAIR_QREAL_QCOLOR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, std_pair_qreal_QColor__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_STD_PAIR_QREAL_QCOLOR_IDX], "std::pair<qreal,QColor>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_STD_PAIR_QREAL_QCOLOR_IDX],
        PySequence_PythonToCpp_std_pair_qreal_QColor_,
        is_PySequence_PythonToCpp_std_pair_qreal_QColor__Convertible);

    // Register converter for type 'QList<std::pair<qreal,QColor>>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_STD_PAIR_QREAL_QCOLOR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_std_pair_qreal_QColor___CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_STD_PAIR_QREAL_QCOLOR_IDX], "QList<std::pair<qreal,QColor>>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_STD_PAIR_QREAL_QCOLOR_IDX],
        PySequence_PythonToCpp__QList_std_pair_qreal_QColor__,
        is_PySequence_PythonToCpp__QList_std_pair_qreal_QColor___Convertible);

    // Register converter for type 'QList<qsizetype>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QSIZETYPE_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_qsizetype__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QSIZETYPE_IDX], "QList<qsizetype>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QSIZETYPE_IDX],
        PySequence_PythonToCpp__QList_qsizetype_,
        is_PySequence_PythonToCpp__QList_qsizetype__Convertible);

    // Register converter for type 'QList<uint16_t>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_UINT16_T_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_uint16_t__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_UINT16_T_IDX], "QList<uint16_t>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_UINT16_T_IDX],
        PySequence_PythonToCpp__QList_uint16_t_,
        is_PySequence_PythonToCpp__QList_uint16_t__Convertible);

    // Register converter for type 'QList<QAccessibleInterface*>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QACCESSIBLEINTERFACEPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QAccessibleInterfacePTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QACCESSIBLEINTERFACEPTR_IDX], "QList<QAccessibleInterface*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QACCESSIBLEINTERFACEPTR_IDX],
        PySequence_PythonToCpp__QList_QAccessibleInterfacePTR_,
        is_PySequence_PythonToCpp__QList_QAccessibleInterfacePTR__Convertible);

    // Register converter for type 'std::pair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag>>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_STD_PAIR_QACCESSIBLEINTERFACEPTR_QFLAGS_QACCESSIBLE_RELATIONFLAG_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag___CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_STD_PAIR_QACCESSIBLEINTERFACEPTR_QFLAGS_QACCESSIBLE_RELATIONFLAG_IDX], "std::pair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag>>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_STD_PAIR_QACCESSIBLEINTERFACEPTR_QFLAGS_QACCESSIBLE_RELATIONFLAG_IDX],
        PySequence_PythonToCpp_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag__,
        is_PySequence_PythonToCpp_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag___Convertible);

    // Register converter for type 'QList<std::pair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag>>>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_STD_PAIR_QACCESSIBLEINTERFACEPTR_QFLAGS_QACCESSIBLE_RELATIONFLAG_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag____CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_STD_PAIR_QACCESSIBLEINTERFACEPTR_QFLAGS_QACCESSIBLE_RELATIONFLAG_IDX], "QList<std::pair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag>>>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_STD_PAIR_QACCESSIBLEINTERFACEPTR_QFLAGS_QACCESSIBLE_RELATIONFLAG_IDX],
        PySequence_PythonToCpp__QList_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag___,
        is_PySequence_PythonToCpp__QList_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag____Convertible);

    // Register converter for type 'QList<unsigned int>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_UNSIGNEDINT_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_unsignedint__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_UNSIGNEDINT_IDX], "QList<unsigned int>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_UNSIGNEDINT_IDX],
        PySequence_PythonToCpp__QList_unsignedint_,
        is_PySequence_PythonToCpp__QList_unsignedint__Convertible);

    // Register converter for type 'QList<QLine>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QLINE_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QLine__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QLINE_IDX], "QList<QLine>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QLINE_IDX],
        PySequence_PythonToCpp__QList_QLine_,
        is_PySequence_PythonToCpp__QList_QLine__Convertible);

    // Register converter for type 'QList<QLineF>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QLINEF_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QLineF__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QLINEF_IDX], "QList<QLineF>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QLINEF_IDX],
        PySequence_PythonToCpp__QList_QLineF_,
        is_PySequence_PythonToCpp__QList_QLineF__Convertible);

    // Register converter for type 'QList<QRect>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QRECT_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QRect__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QRECT_IDX], "QList<QRect>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QRECT_IDX],
        PySequence_PythonToCpp__QList_QRect_,
        is_PySequence_PythonToCpp__QList_QRect__Convertible);

    // Register converter for type 'QList<QRectF>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QRECTF_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QRectF__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QRECTF_IDX], "QList<QRectF>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QRECTF_IDX],
        PySequence_PythonToCpp__QList_QRectF_,
        is_PySequence_PythonToCpp__QList_QRectF__Convertible);

    // Register converter for type 'QList<QKeySequence>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QKEYSEQUENCE_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QKeySequence__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QKEYSEQUENCE_IDX], "QList<QKeySequence>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QKEYSEQUENCE_IDX],
        PySequence_PythonToCpp__QList_QKeySequence_,
        is_PySequence_PythonToCpp__QList_QKeySequence__Convertible);

    // Register converter for type 'QList<QObject*>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QOBJECTPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QObjectPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QOBJECTPTR_IDX], "QList<QObject*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QOBJECTPTR_IDX],
        PySequence_PythonToCpp__QList_QObjectPTR_,
        is_PySequence_PythonToCpp__QList_QObjectPTR__Convertible);

    // Register converter for type 'QList<QByteArray>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QBYTEARRAY_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QByteArray__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QBYTEARRAY_IDX], "QList<QByteArray>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QBYTEARRAY_IDX],
        PySequence_PythonToCpp__QList_QByteArray_,
        is_PySequence_PythonToCpp__QList_QByteArray__Convertible);

    // Register converter for type 'QList<QUndoStack*>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QUNDOSTACKPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QUndoStackPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QUNDOSTACKPTR_IDX], "QList<QUndoStack*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QUNDOSTACKPTR_IDX],
        PySequence_PythonToCpp__QList_QUndoStackPTR_,
        is_PySequence_PythonToCpp__QList_QUndoStackPTR__Convertible);

    // Register converter for type 'QList<QTextFrame*>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QTEXTFRAMEPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QTextFramePTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QTEXTFRAMEPTR_IDX], "QList<QTextFrame*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QTEXTFRAMEPTR_IDX],
        PySequence_PythonToCpp__QList_QTextFramePTR_,
        is_PySequence_PythonToCpp__QList_QTextFramePTR__Convertible);

    // Register converter for type 'QList<QTextBlock>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QTEXTBLOCK_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QTextBlock__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QTEXTBLOCK_IDX], "QList<QTextBlock>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QTEXTBLOCK_IDX],
        PySequence_PythonToCpp__QList_QTextBlock_,
        is_PySequence_PythonToCpp__QList_QTextBlock__Convertible);

    // Register converter for type 'QList<QTextFormat>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QTEXTFORMAT_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QTextFormat__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QTEXTFORMAT_IDX], "QList<QTextFormat>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QTEXTFORMAT_IDX],
        PySequence_PythonToCpp__QList_QTextFormat_,
        is_PySequence_PythonToCpp__QList_QTextFormat__Convertible);

    // Register converter for type 'QList<QScreen*>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QSCREENPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QScreenPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QSCREENPTR_IDX], "QList<QScreen*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QSCREENPTR_IDX],
        PySequence_PythonToCpp__QList_QScreenPTR_,
        is_PySequence_PythonToCpp__QList_QScreenPTR__Convertible);

    // Register converter for type 'QList<QOpenGLContext*>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QOPENGLCONTEXTPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QOpenGLContextPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QOPENGLCONTEXTPTR_IDX], "QList<QOpenGLContext*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QOPENGLCONTEXTPTR_IDX],
        PySequence_PythonToCpp__QList_QOpenGLContextPTR_,
        is_PySequence_PythonToCpp__QList_QOpenGLContextPTR__Convertible);

    // Register converter for type 'QSet<QByteArray>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QSET_QBYTEARRAY_IDX] = Shiboken::Conversions::createConverter(&PySet_Type, _QSet_QByteArray__CppToPython_PySet);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QSET_QBYTEARRAY_IDX], "QSet<QByteArray>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QSET_QBYTEARRAY_IDX],
        PySequence_PythonToCpp__QSet_QByteArray_,
        is_PySequence_PythonToCpp__QSet_QByteArray__Convertible);

    // Register converter for type 'QList<const QInputDevice*>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_CONSTQINPUTDEVICEPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_constQInputDevicePTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_CONSTQINPUTDEVICEPTR_IDX], "QList<const QInputDevice*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_CONSTQINPUTDEVICEPTR_IDX],
        PySequence_PythonToCpp__QList_constQInputDevicePTR_,
        is_PySequence_PythonToCpp__QList_constQInputDevicePTR__Convertible);

    // Register converter for type 'QList<QAction*>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QACTIONPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QActionPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QACTIONPTR_IDX], "QList<QAction*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QACTIONPTR_IDX],
        PySequence_PythonToCpp__QList_QActionPTR_,
        is_PySequence_PythonToCpp__QList_QActionPTR__Convertible);

    // Register converter for type 'QList<QAbstractTextDocumentLayout::Selection>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QABSTRACTTEXTDOCUMENTLAYOUT_SELECTION_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QAbstractTextDocumentLayout_Selection__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QABSTRACTTEXTDOCUMENTLAYOUT_SELECTION_IDX], "QList<QAbstractTextDocumentLayout::Selection>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QABSTRACTTEXTDOCUMENTLAYOUT_SELECTION_IDX],
        PySequence_PythonToCpp__QList_QAbstractTextDocumentLayout_Selection_,
        is_PySequence_PythonToCpp__QList_QAbstractTextDocumentLayout_Selection__Convertible);

    // Register converter for type 'QList<QInputMethodEvent::Attribute>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QINPUTMETHODEVENT_ATTRIBUTE_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QInputMethodEvent_Attribute__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QINPUTMETHODEVENT_ATTRIBUTE_IDX], "QList<QInputMethodEvent::Attribute>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QINPUTMETHODEVENT_ATTRIBUTE_IDX],
        PySequence_PythonToCpp__QList_QInputMethodEvent_Attribute_,
        is_PySequence_PythonToCpp__QList_QInputMethodEvent_Attribute__Convertible);

    // Register converter for type 'QList<QEventPoint>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QEVENTPOINT_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QEventPoint__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QEVENTPOINT_IDX], "QList<QEventPoint>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QEVENTPOINT_IDX],
        PySequence_PythonToCpp__QList_QEventPoint_,
        is_PySequence_PythonToCpp__QList_QEventPoint__Convertible);

    // Register converter for type 'QList<QWindow*>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QWINDOWPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QWindowPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QWINDOWPTR_IDX], "QList<QWindow*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QWINDOWPTR_IDX],
        PySequence_PythonToCpp__QList_QWindowPTR_,
        is_PySequence_PythonToCpp__QList_QWindowPTR__Convertible);

    // Register converter for type 'QList<QRhiShaderResourceBinding>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QRHISHADERRESOURCEBINDING_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QRhiShaderResourceBinding__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QRHISHADERRESOURCEBINDING_IDX], "QList<QRhiShaderResourceBinding>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QRHISHADERRESOURCEBINDING_IDX],
        PySequence_PythonToCpp__QList_QRhiShaderResourceBinding_,
        is_PySequence_PythonToCpp__QList_QRhiShaderResourceBinding__Convertible);

    // Register converter for type 'QList<QRhiShaderStage>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QRHISHADERSTAGE_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QRhiShaderStage__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QRHISHADERSTAGE_IDX], "QList<QRhiShaderStage>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QRHISHADERSTAGE_IDX],
        PySequence_PythonToCpp__QList_QRhiShaderStage_,
        is_PySequence_PythonToCpp__QList_QRhiShaderStage__Convertible);

    // Register converter for type 'QList<QRhiGraphicsPipeline::TargetBlend>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QRHIGRAPHICSPIPELINE_TARGETBLEND_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QRhiGraphicsPipeline_TargetBlend__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QRHIGRAPHICSPIPELINE_TARGETBLEND_IDX], "QList<QRhiGraphicsPipeline::TargetBlend>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QRHIGRAPHICSPIPELINE_TARGETBLEND_IDX],
        PySequence_PythonToCpp__QList_QRhiGraphicsPipeline_TargetBlend_,
        is_PySequence_PythonToCpp__QList_QRhiGraphicsPipeline_TargetBlend__Convertible);

    // Register converter for type 'std::pair<int,unsigned int>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_STD_PAIR_INT_UNSIGNEDINT_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, std_pair_int_unsignedint__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_STD_PAIR_INT_UNSIGNEDINT_IDX], "std::pair<int,unsigned int>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_STD_PAIR_INT_UNSIGNEDINT_IDX],
        PySequence_PythonToCpp_std_pair_int_unsignedint_,
        is_PySequence_PythonToCpp_std_pair_int_unsignedint__Convertible);

    // Register converter for type 'std::pair<QRhiBuffer*,quint32>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_STD_PAIR_QRHIBUFFERPTR_QUINT32_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, std_pair_QRhiBufferPTR_quint32__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_STD_PAIR_QRHIBUFFERPTR_QUINT32_IDX], "std::pair<QRhiBuffer*,quint32>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_STD_PAIR_QRHIBUFFERPTR_QUINT32_IDX],
        PySequence_PythonToCpp_std_pair_QRhiBufferPTR_quint32_,
        is_PySequence_PythonToCpp_std_pair_QRhiBufferPTR_quint32__Convertible);

    // Register converter for type 'QList<std::pair<QRhiBuffer*,quint32>>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_STD_PAIR_QRHIBUFFERPTR_QUINT32_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_std_pair_QRhiBufferPTR_quint32___CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_STD_PAIR_QRHIBUFFERPTR_QUINT32_IDX], "QList<std::pair<QRhiBuffer*,quint32>>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_STD_PAIR_QRHIBUFFERPTR_QUINT32_IDX],
        PySequence_PythonToCpp__QList_std_pair_QRhiBufferPTR_quint32__,
        is_PySequence_PythonToCpp__QList_std_pair_QRhiBufferPTR_quint32___Convertible);

    // Register converter for type 'std::pair<QRhiBuffer*,unsigned int>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_STD_PAIR_QRHIBUFFERPTR_UNSIGNEDINT_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, std_pair_QRhiBufferPTR_unsignedint__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_STD_PAIR_QRHIBUFFERPTR_UNSIGNEDINT_IDX], "std::pair<QRhiBuffer*,unsigned int>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_STD_PAIR_QRHIBUFFERPTR_UNSIGNEDINT_IDX],
        PySequence_PythonToCpp_std_pair_QRhiBufferPTR_unsignedint_,
        is_PySequence_PythonToCpp_std_pair_QRhiBufferPTR_unsignedint__Convertible);

    // Register converter for type 'QList<QModelIndex>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QMODELINDEX_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QModelIndex__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QMODELINDEX_IDX], "QList<QModelIndex>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QMODELINDEX_IDX],
        PySequence_PythonToCpp__QList_QModelIndex_,
        is_PySequence_PythonToCpp__QList_QModelIndex__Convertible);

    // Register converter for type 'QHash<int,QByteArray>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QHASH_INT_QBYTEARRAY_IDX] = Shiboken::Conversions::createConverter(&PyDict_Type, _QHash_int_QByteArray__CppToPython_PyDict);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QHASH_INT_QBYTEARRAY_IDX], "QHash<int,QByteArray>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QHASH_INT_QBYTEARRAY_IDX],
        PyDict_PythonToCpp__QHash_int_QByteArray_,
        is_PyDict_PythonToCpp__QHash_int_QByteArray__Convertible);

    // Register converter for type 'QList<QVariant>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QVARIANT_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QVariant__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QVARIANT_IDX], "QList<QVariant>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QVARIANT_IDX],
        PySequence_PythonToCpp__QList_QVariant_,
        is_PySequence_PythonToCpp__QList_QVariant__Convertible);

    // Register converter for type 'QList<QString>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QSTRING_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QString__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QSTRING_IDX], "QList<QString>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QLIST_QSTRING_IDX],
        PySequence_PythonToCpp__QList_QString_,
        is_PySequence_PythonToCpp__QList_QString__Convertible);

    // Register converter for type 'QMap<QString,QVariant>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QMAP_QSTRING_QVARIANT_IDX] = Shiboken::Conversions::createConverter(&PyDict_Type, _QMap_QString_QVariant__CppToPython_PyDict);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QMAP_QSTRING_QVARIANT_IDX], "QMap<QString,QVariant>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QTGUI_QMAP_QSTRING_QVARIANT_IDX],
        PyDict_PythonToCpp__QMap_QString_QVariant_,
        is_PyDict_PythonToCpp__QMap_QString_QVariant__Convertible);


    // Opaque container type registration
    PyObject *ob_type{};
    ob_type = reinterpret_cast<PyObject *>(QIntList_TypeF());
    Py_XINCREF(ob_type);
    PyModule_AddObject(module, "QIntList", ob_type);
    ob_type = reinterpret_cast<PyObject *>(QVector2DList_TypeF());
    Py_XINCREF(ob_type);
    PyModule_AddObject(module, "QVector2DList", ob_type);
    ob_type = reinterpret_cast<PyObject *>(QVector3DList_TypeF());
    Py_XINCREF(ob_type);
    PyModule_AddObject(module, "QVector3DList", ob_type);
    ob_type = reinterpret_cast<PyObject *>(QVector4DList_TypeF());
    Py_XINCREF(ob_type);
    PyModule_AddObject(module, "QVector4DList", ob_type);
    ob_type = reinterpret_cast<PyObject *>(QPointFList_TypeF());
    Py_XINCREF(ob_type);
    PyModule_AddObject(module, "QPointFList", ob_type);
    ob_type = reinterpret_cast<PyObject *>(QPointList_TypeF());
    Py_XINCREF(ob_type);
    PyModule_AddObject(module, "QPointList", ob_type);


    // Extended implicit conversions for PySide6.QtCore.QPointF.
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypes[SBK_QPOINTF_IDX],
        QPainterPath_Element_PythonToCpp_PySide6_QtCore_QPointF,
        is_QPainterPath_Element_PythonToCpp_PySide6_QtCore_QPointF_Convertible);

    // Register primitive types converters.
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "GLbitfield");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "GLboolean");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), "GLbyte");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<char>(), "GLchar");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<char>(), "GLcharARB");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<double>(), "GLclampd");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<float>(), "GLclampf");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<double>(), "GLdouble");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "GLenum");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "GLfixed");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<float>(), "GLfloat");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "GLhalf");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "GLhalfARB");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "GLhalfNV");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "GLhandleARB");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "GLint");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "GLint64");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "GLint64EXT");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "GLintptr");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "GLintptrARB");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<short>(), "GLshort");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "GLsizei");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "GLsizeiptr");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "GLsizeiptrARB");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "GLubyte");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "GLuint");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "GLuint64");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "GLuint64EXT");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "GLushort");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "GLvdpauSurfaceNV");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLACQUIREKEYEDMUTEXWIN32EXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLAREPROGRAMSRESIDENTNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLARETEXTURESRESIDENTEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLBINDLIGHTPARAMETEREXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLBINDMATERIALPARAMETEREXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLBINDPARAMETEREXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLBINDTEXGENPARAMETEREXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLBINDTEXTUREUNITPARAMETEREXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCHECKFRAMEBUFFERSTATUSEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCHECKFRAMEBUFFERSTATUSPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCHECKNAMEDFRAMEBUFFERSTATUSEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCHECKNAMEDFRAMEBUFFERSTATUSPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCLIENTWAITSYNCPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCREATEPROGRAMOBJECTARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCREATEPROGRAMPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCREATESHADEROBJECTARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCREATESHADERPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCREATESHADERPROGRAMEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCREATESHADERPROGRAMVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLFINISHASYNCSGIXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGENASYNCMARKERSSGIXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGENFRAGMENTSHADERSATIPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGENPATHSNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGENSYMBOLSEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGENVERTEXSHADERSEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETATTRIBLOCATIONARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETATTRIBLOCATIONPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETCOMMANDHEADERNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETDEBUGMESSAGELOGAMDPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETDEBUGMESSAGELOGARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETDEBUGMESSAGELOGPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETFRAGDATAINDEXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETFRAGDATALOCATIONEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETFRAGDATALOCATIONPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETGRAPHICSRESETSTATUSARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETGRAPHICSRESETSTATUSPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETHANDLEARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "PFNGLGETIMAGEHANDLEARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "PFNGLGETIMAGEHANDLENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETINSTRUMENTSSGIXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<float>(), "PFNGLGETPATHLENGTHNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETPROGRAMRESOURCEINDEXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETPROGRAMRESOURCELOCATIONINDEXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETPROGRAMRESOURCELOCATIONPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "PFNGLGETSTAGEINDEXNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLGETSTRINGIPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETSUBROUTINEINDEXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETSUBROUTINEUNIFORMLOCATIONPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "PFNGLGETTEXTUREHANDLEARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "PFNGLGETTEXTUREHANDLENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "PFNGLGETTEXTURESAMPLERHANDLEARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "PFNGLGETTEXTURESAMPLERHANDLENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETUNIFORMBLOCKINDEXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETUNIFORMBUFFERSIZEEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETUNIFORMLOCATIONARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETUNIFORMLOCATIONPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "PFNGLGETUNIFORMOFFSETEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETVARYINGLOCATIONNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISASYNCMARKERSGIXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISBUFFERARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISBUFFERPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISBUFFERRESIDENTNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISCOMMANDLISTNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISENABLEDINDEXEDEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISENABLEDIPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISFENCEAPPLEPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISFENCENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISFRAMEBUFFEREXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISFRAMEBUFFERPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISIMAGEHANDLERESIDENTARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISIMAGEHANDLERESIDENTNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISMEMORYOBJECTEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISNAMEAMDPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISNAMEDBUFFERRESIDENTNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISNAMEDSTRINGARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISOBJECTBUFFERATIPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISOCCLUSIONQUERYNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISPATHNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISPOINTINFILLPATHNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISPOINTINSTROKEPATHNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISPROGRAMARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISPROGRAMNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISPROGRAMPIPELINEPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISPROGRAMPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISQUERYARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISQUERYPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISRENDERBUFFEREXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISRENDERBUFFERPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISSAMPLERPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISSEMAPHOREEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISSHADERPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISSTATENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISSYNCPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISTEXTUREEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISTEXTUREHANDLERESIDENTARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISTEXTUREHANDLERESIDENTNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISTRANSFORMFEEDBACKNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISTRANSFORMFEEDBACKPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISVARIANTENABLEDEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISVERTEXARRAYAPPLEPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISVERTEXARRAYPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISVERTEXATTRIBENABLEDAPPLEPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLNEWOBJECTBUFFERATIPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLOBJECTPURGEABLEAPPLEPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLOBJECTUNPURGEABLEAPPLEPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLPATHGLYPHINDEXARRAYNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLPATHGLYPHINDEXRANGENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLPATHMEMORYGLYPHINDEXARRAYNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLPOINTALONGPATHNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLPOLLASYNCSGIXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLPOLLINSTRUMENTSSGIXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLQUERYMATRIXXOESPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLQUERYRESOURCENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLRELEASEKEYEDMUTEXWIN32EXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLTESTFENCEAPPLEPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLTESTFENCENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLTESTOBJECTAPPLEPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLUNMAPBUFFERARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLUNMAPBUFFERPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLUNMAPNAMEDBUFFEREXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLUNMAPNAMEDBUFFERPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLVDPAUISSURFACENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "PFNGLVDPAUREGISTEROUTPUTSURFACENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "PFNGLVDPAUREGISTERVIDEOSURFACENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "PFNGLVDPAUREGISTERVIDEOSURFACEWITHPICTURESTRUCTURENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLVIDEOCAPTURENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "QRgb");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__blkcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__blkcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__blksize_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<char>(), "__caddr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__clock_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__clockid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__compar_d_fn_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__compar_fn_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__daddr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__dev_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__fsblkcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__fsblkcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__fsfilcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__fsfilcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__fsword_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__gid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__id_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__ino64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__ino_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<short>(), "__int16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__int32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__int64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), "__int8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<short>(), "__int_least16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__int_least32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__int_least64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), "__int_least8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__intmax_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__intptr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__key_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__loff_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__mode_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__nlink_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__off64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__off_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__pid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__quad_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__rlim64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__rlim_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__sig_atomic_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__socklen_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__ssize_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__suseconds64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__suseconds_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__syscall_slong_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__syscall_ulong_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__time_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "__u_char");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__u_int");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__u_long");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__u_quad_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "__u_short");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__uid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "__uint16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__uint32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__uint64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "__uint8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "__uint_least16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__uint_least32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__uint_least64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "__uint_least8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__uintmax_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__useconds_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "blkcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "blkcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "blksize_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<char>(), "caddr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "comparison_fn_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "daddr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "dev_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "fsblkcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "fsblkcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "fsfilcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "fsfilcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "gid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "id_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "ino64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "ino_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "int_fast16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "int_fast32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "int_fast64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), "int_fast8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<short>(), "int_least16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "int_least32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "int_least64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), "int_least8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "intmax_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "key_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "loff_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "mode_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "nlink_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "off64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "off_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "pid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "ptrdiff_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), "qInternalCallback");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "qopengl_GLintptr");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "qopengl_GLsizeiptr");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "quad_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "register_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "ssize_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "suseconds_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "u_char");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "u_int");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "u_int16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "u_int32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "u_int64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "u_int8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "u_long");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "u_quad_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "u_short");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "uid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uint_fast16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uint_fast32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uint_fast64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "uint_fast8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "uint_least16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "uint_least32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uint_least64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "uint_least8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uintmax_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "useconds_t");

    Shiboken::Module::registerTypes(module, SbkPySide6_QtGuiTypes);
    Shiboken::Module::registerTypeConverters(module, SbkPySide6_QtGuiTypeConverters);

    // Static field initialization
    init_QRhiShaderResourceBindingStaticFields();
    init_QRhiShaderResourceBinding_DataStaticFields();
    init_QRhiStaticFields();
    init_QtGuiQColorConstantsStaticFields();
    init_QtGuiQColorConstants_SvgStaticFields();

    if (Shiboken::Errors::occurred() != nullptr) {
        PyErr_Print();
        Py_FatalError("can't initialize module QtGui");
    }
    PySide::registerCleanupFunction(cleanTypesAttributes);

    FinishSignatureInitialization(module, QtGui_SignatureStrings);

    return module;
}
