// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

#include <sbkpython.h>
#include <shiboken.h>
#include <algorithm>
#include <signature.h>
#include <sbkcontainer.h>
#include <sbkstaticstrings.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysidecleanup.h>
#include <pysideqenum.h>
#include <feature_select.h>
#include <pysidestaticstrings.h>
#include "pyside6_qtwidgets_python.h"

#include <QHash>
#include <QList>
#include <QMap>
#include <QString>
#include <QTextEdit>
#include <QtGui/qaccessible.h>
#include <QtGui/qaction.h>
#include <QtGui/qcolor.h>
#include <QtGui/qkeysequence.h>
#include <QtGui/qscreen.h>
#include <QtGui/qtextformat.h>
#include <QtGui/qwindow.h>
#include <QtWidgets/qabstractbutton.h>
#include <QtWidgets/qdockwidget.h>
#include <QtWidgets/qdrawutil.h>
#include <QtWidgets/qgesture.h>
#include <QtWidgets/qgraphicsitem.h>
#include <QtWidgets/qgraphicstransform.h>
#include <QtWidgets/qgraphicsview.h>
#include <QtWidgets/qlistwidget.h>
#include <QtWidgets/qmdisubwindow.h>
#include <QtWidgets/qscroller.h>
#include <QtWidgets/qtablewidget.h>
#include <QtWidgets/qtreewidget.h>
#include <QtWidgets/qwidget.h>
#include <QtWidgets/qwizard.h>
#include <qabstractitemmodel.h>
#include <qbytearray.h>
#include <qdatetime.h>
#include <qline.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qpoint.h>
#include <qrect.h>
#include <qurl.h>
#include <qvariant.h>
#include <utility>


// Current module's type array.
PyTypeObject **SbkPySide6_QtWidgetsTypes = nullptr;
// Current module's PyObject pointer.
PyObject *SbkPySide6_QtWidgetsModuleObject = nullptr;
// Current module's converter array.
SbkConverter **SbkPySide6_QtWidgetsTypeConverters = nullptr;
void cleanTypesAttributes() {
    static PyObject *attrName = Shiboken::PyName::qtStaticMetaObject();
    for (int i = 0, imax = SBK_QtWidgets_IDX_COUNT; i < imax; i++) {
        PyObject *pyType = reinterpret_cast<PyObject *>(SbkPySide6_QtWidgetsTypes[i]);
        if (pyType && PyObject_HasAttr(pyType, attrName))
            PyObject_SetAttr(pyType, attrName, Py_None);
    }
}
// Global functions ------------------------------------------------------------
static PyObject *SbkQtWidgetsModule_qDrawPlainRect(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.qDrawPlainRect";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[8];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 8));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOOOOOO:qDrawPlainRect", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qDrawPlainRect(QPainter*,int,int,int,int,QColor,int=,const QBrush*=)
    // 1: qDrawPlainRect(QPainter*,QRect,QColor,int=,const QBrush*=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(SbkPySide6_QtGuiTypes[SBK_QPAINTER_IDX], (pyArgs[0])))) {
        if (numArgs >= 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(SbkPySide6_QtCoreTypes[SBK_QRECT_IDX], (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(SbkPySide6_QtGuiTypes[SBK_QCOLOR_IDX], (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 1; // qDrawPlainRect(QPainter*,QRect,QColor,int,const QBrush*)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
                if (numArgs == 4) {
                    overloadId = 1; // qDrawPlainRect(QPainter*,QRect,QColor,int,const QBrush*)
                } else if (numArgs >= 5
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppPointerConversion(SbkPySide6_QtGuiTypes[SBK_QBRUSH_IDX], (pyArgs[4])))) {
                    overloadId = 1; // qDrawPlainRect(QPainter*,QRect,QColor,int,const QBrush*)
                }
            }
        } else if (numArgs >= 6
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))
            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppReferenceConversion(SbkPySide6_QtGuiTypes[SBK_QCOLOR_IDX], (pyArgs[5])))) {
            if (numArgs == 6) {
                overloadId = 0; // qDrawPlainRect(QPainter*,int,int,int,int,QColor,int,const QBrush*)
            } else if (numArgs >= 7
                && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[6])))) {
                if (numArgs == 7) {
                    overloadId = 0; // qDrawPlainRect(QPainter*,int,int,int,int,QColor,int,const QBrush*)
                } else if (numArgs >= 8
                    && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppPointerConversion(SbkPySide6_QtGuiTypes[SBK_QBRUSH_IDX], (pyArgs[7])))) {
                    overloadId = 0; // qDrawPlainRect(QPainter*,int,int,int,int,QColor,int,const QBrush*)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // qDrawPlainRect(QPainter * p, int x, int y, int w, int h, const QColor & arg__6, int lineWidth, const QBrush * fill)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_lineWidth = Shiboken::String::createStaticString("lineWidth");
                if (PyDict_Contains(kwds, key_lineWidth) != 0) {
                    value = PyDict_GetItem(kwds, key_lineWidth);
                    if (value != nullptr && pyArgs[6] != nullptr ) {
                        errInfo.reset(key_lineWidth);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[6] = value;
                        if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[6]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_lineWidth);
                }
                static PyObject *const key_fill = Shiboken::String::createStaticString("fill");
                if (PyDict_Contains(kwds, key_fill) != 0) {
                    value = PyDict_GetItem(kwds, key_fill);
                    if (value != nullptr && pyArgs[7] != nullptr ) {
                        errInfo.reset(key_fill);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[7] = value;
                        if (!(pythonToCpp[7] = Shiboken::Conversions::pythonToCppPointerConversion(SbkPySide6_QtGuiTypes[SBK_QBRUSH_IDX], (pyArgs[7]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_fill);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPainter *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            if (!Shiboken::Object::isValid(pyArgs[5]))
                return {};
            ::QColor cppArg5_local;
            ::QColor *cppArg5 = &cppArg5_local;
            if (pythonToCpp[5].isValue())
                pythonToCpp[5](pyArgs[5], &cppArg5_local);
            else
                pythonToCpp[5](pyArgs[5], &cppArg5);

            int cppArg6 = 1;
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);
            if (!Shiboken::Object::isValid(pyArgs[7]))
                return {};
            ::QBrush *cppArg7 = nullptr;
            if (pythonToCpp[7])
                pythonToCpp[7](pyArgs[7], &cppArg7);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qDrawPlainRect(QPainter*,int,int,int,int,QColor,int,const QBrush*)
                qDrawPlainRect(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, *cppArg5, cppArg6, cppArg7);
            }
            break;
        }
        case 1: // qDrawPlainRect(QPainter * p, const QRect & r, const QColor & arg__3, int lineWidth, const QBrush * fill)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_lineWidth = Shiboken::String::createStaticString("lineWidth");
                if (PyDict_Contains(kwds, key_lineWidth) != 0) {
                    value = PyDict_GetItem(kwds, key_lineWidth);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_lineWidth);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_lineWidth);
                }
                static PyObject *const key_fill = Shiboken::String::createStaticString("fill");
                if (PyDict_Contains(kwds, key_fill) != 0) {
                    value = PyDict_GetItem(kwds, key_fill);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_fill);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppPointerConversion(SbkPySide6_QtGuiTypes[SBK_QBRUSH_IDX], (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_fill);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPainter *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QRect cppArg1_local;
            ::QRect *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QColor cppArg2_local;
            ::QColor *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);

            int cppArg3 = 1;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return {};
            ::QBrush *cppArg4 = nullptr;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qDrawPlainRect(QPainter*,QRect,QColor,int,const QBrush*)
                qDrawPlainRect(cppArg0, *cppArg1, *cppArg2, cppArg3, cppArg4);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *SbkQtWidgetsModule_qDrawShadeLine(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.qDrawShadeLine";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[9];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 4, 9));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOOOOOOO:qDrawShadeLine", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7]), &(pyArgs[8])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qDrawShadeLine(QPainter*,int,int,int,int,QPalette,bool=,int=,int=)
    // 1: qDrawShadeLine(QPainter*,QPoint,QPoint,QPalette,bool=,int=,int=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(SbkPySide6_QtGuiTypes[SBK_QPAINTER_IDX], (pyArgs[0])))) {
        if (numArgs >= 4
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(SbkPySide6_QtCoreTypes[SBK_QPOINT_IDX], (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(SbkPySide6_QtCoreTypes[SBK_QPOINT_IDX], (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppReferenceConversion(SbkPySide6_QtGuiTypes[SBK_QPALETTE_IDX], (pyArgs[3])))) {
            if (numArgs == 4) {
                overloadId = 1; // qDrawShadeLine(QPainter*,QPoint,QPoint,QPalette,bool,int,int)
            } else if (numArgs >= 5
                && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[4])))) {
                if (numArgs == 5) {
                    overloadId = 1; // qDrawShadeLine(QPainter*,QPoint,QPoint,QPalette,bool,int,int)
                } else if (numArgs >= 6
                    && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5])))) {
                    if (numArgs == 6) {
                        overloadId = 1; // qDrawShadeLine(QPainter*,QPoint,QPoint,QPalette,bool,int,int)
                    } else if (numArgs >= 7
                        && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[6])))) {
                        overloadId = 1; // qDrawShadeLine(QPainter*,QPoint,QPoint,QPalette,bool,int,int)
                    }
                }
            }
        } else if (numArgs >= 6
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))
            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppReferenceConversion(SbkPySide6_QtGuiTypes[SBK_QPALETTE_IDX], (pyArgs[5])))) {
            if (numArgs == 6) {
                overloadId = 0; // qDrawShadeLine(QPainter*,int,int,int,int,QPalette,bool,int,int)
            } else if (numArgs >= 7
                && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[6])))) {
                if (numArgs == 7) {
                    overloadId = 0; // qDrawShadeLine(QPainter*,int,int,int,int,QPalette,bool,int,int)
                } else if (numArgs >= 8
                    && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[7])))) {
                    if (numArgs == 8) {
                        overloadId = 0; // qDrawShadeLine(QPainter*,int,int,int,int,QPalette,bool,int,int)
                    } else if (numArgs >= 9
                        && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[8])))) {
                        overloadId = 0; // qDrawShadeLine(QPainter*,int,int,int,int,QPalette,bool,int,int)
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // qDrawShadeLine(QPainter * p, int x1, int y1, int x2, int y2, const QPalette & pal, bool sunken, int lineWidth, int midLineWidth)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_sunken = Shiboken::String::createStaticString("sunken");
                if (PyDict_Contains(kwds, key_sunken) != 0) {
                    value = PyDict_GetItem(kwds, key_sunken);
                    if (value != nullptr && pyArgs[6] != nullptr ) {
                        errInfo.reset(key_sunken);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[6] = value;
                        if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[6]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_sunken);
                }
                static PyObject *const key_lineWidth = Shiboken::String::createStaticString("lineWidth");
                if (PyDict_Contains(kwds, key_lineWidth) != 0) {
                    value = PyDict_GetItem(kwds, key_lineWidth);
                    if (value != nullptr && pyArgs[7] != nullptr ) {
                        errInfo.reset(key_lineWidth);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[7] = value;
                        if (!(pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[7]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_lineWidth);
                }
                static PyObject *const key_midLineWidth = Shiboken::String::createStaticString("midLineWidth");
                if (PyDict_Contains(kwds, key_midLineWidth) != 0) {
                    value = PyDict_GetItem(kwds, key_midLineWidth);
                    if (value != nullptr && pyArgs[8] != nullptr ) {
                        errInfo.reset(key_midLineWidth);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[8] = value;
                        if (!(pythonToCpp[8] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[8]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_midLineWidth);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPainter *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            if (!Shiboken::Object::isValid(pyArgs[5]))
                return {};
            ::QPalette cppArg5_local;
            ::QPalette *cppArg5 = &cppArg5_local;
            if (pythonToCpp[5].isValue())
                pythonToCpp[5](pyArgs[5], &cppArg5_local);
            else
                pythonToCpp[5](pyArgs[5], &cppArg5);

            bool cppArg6 = true;
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);
            int cppArg7 = 1;
            if (pythonToCpp[7])
                pythonToCpp[7](pyArgs[7], &cppArg7);
            int cppArg8 = 0;
            if (pythonToCpp[8])
                pythonToCpp[8](pyArgs[8], &cppArg8);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qDrawShadeLine(QPainter*,int,int,int,int,QPalette,bool,int,int)
                qDrawShadeLine(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, *cppArg5, cppArg6, cppArg7, cppArg8);
            }
            break;
        }
        case 1: // qDrawShadeLine(QPainter * p, const QPoint & p1, const QPoint & p2, const QPalette & pal, bool sunken, int lineWidth, int midLineWidth)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_sunken = Shiboken::String::createStaticString("sunken");
                if (PyDict_Contains(kwds, key_sunken) != 0) {
                    value = PyDict_GetItem(kwds, key_sunken);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_sunken);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_sunken);
                }
                static PyObject *const key_lineWidth = Shiboken::String::createStaticString("lineWidth");
                if (PyDict_Contains(kwds, key_lineWidth) != 0) {
                    value = PyDict_GetItem(kwds, key_lineWidth);
                    if (value != nullptr && pyArgs[5] != nullptr ) {
                        errInfo.reset(key_lineWidth);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[5] = value;
                        if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_lineWidth);
                }
                static PyObject *const key_midLineWidth = Shiboken::String::createStaticString("midLineWidth");
                if (PyDict_Contains(kwds, key_midLineWidth) != 0) {
                    value = PyDict_GetItem(kwds, key_midLineWidth);
                    if (value != nullptr && pyArgs[6] != nullptr ) {
                        errInfo.reset(key_midLineWidth);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[6] = value;
                        if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[6]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_midLineWidth);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPainter *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QPoint cppArg1_local;
            ::QPoint *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QPoint cppArg2_local;
            ::QPoint *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QPalette cppArg3_local;
            ::QPalette *cppArg3 = &cppArg3_local;
            if (pythonToCpp[3].isValue())
                pythonToCpp[3](pyArgs[3], &cppArg3_local);
            else
                pythonToCpp[3](pyArgs[3], &cppArg3);

            bool cppArg4 = true;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);
            int cppArg5 = 1;
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);
            int cppArg6 = 0;
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qDrawShadeLine(QPainter*,QPoint,QPoint,QPalette,bool,int,int)
                qDrawShadeLine(cppArg0, *cppArg1, *cppArg2, *cppArg3, cppArg4, cppArg5, cppArg6);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *SbkQtWidgetsModule_qDrawShadePanel(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.qDrawShadePanel";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[9];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 9));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOOOOOOO:qDrawShadePanel", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7]), &(pyArgs[8])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qDrawShadePanel(QPainter*,int,int,int,int,QPalette,bool=,int=,const QBrush*=)
    // 1: qDrawShadePanel(QPainter*,QRect,QPalette,bool=,int=,const QBrush*=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(SbkPySide6_QtGuiTypes[SBK_QPAINTER_IDX], (pyArgs[0])))) {
        if (numArgs >= 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(SbkPySide6_QtCoreTypes[SBK_QRECT_IDX], (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(SbkPySide6_QtGuiTypes[SBK_QPALETTE_IDX], (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 1; // qDrawShadePanel(QPainter*,QRect,QPalette,bool,int,const QBrush*)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[3])))) {
                if (numArgs == 4) {
                    overloadId = 1; // qDrawShadePanel(QPainter*,QRect,QPalette,bool,int,const QBrush*)
                } else if (numArgs >= 5
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))) {
                    if (numArgs == 5) {
                        overloadId = 1; // qDrawShadePanel(QPainter*,QRect,QPalette,bool,int,const QBrush*)
                    } else if (numArgs >= 6
                        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppPointerConversion(SbkPySide6_QtGuiTypes[SBK_QBRUSH_IDX], (pyArgs[5])))) {
                        overloadId = 1; // qDrawShadePanel(QPainter*,QRect,QPalette,bool,int,const QBrush*)
                    }
                }
            }
        } else if (numArgs >= 6
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))
            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppReferenceConversion(SbkPySide6_QtGuiTypes[SBK_QPALETTE_IDX], (pyArgs[5])))) {
            if (numArgs == 6) {
                overloadId = 0; // qDrawShadePanel(QPainter*,int,int,int,int,QPalette,bool,int,const QBrush*)
            } else if (numArgs >= 7
                && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[6])))) {
                if (numArgs == 7) {
                    overloadId = 0; // qDrawShadePanel(QPainter*,int,int,int,int,QPalette,bool,int,const QBrush*)
                } else if (numArgs >= 8
                    && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[7])))) {
                    if (numArgs == 8) {
                        overloadId = 0; // qDrawShadePanel(QPainter*,int,int,int,int,QPalette,bool,int,const QBrush*)
                    } else if (numArgs >= 9
                        && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppPointerConversion(SbkPySide6_QtGuiTypes[SBK_QBRUSH_IDX], (pyArgs[8])))) {
                        overloadId = 0; // qDrawShadePanel(QPainter*,int,int,int,int,QPalette,bool,int,const QBrush*)
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // qDrawShadePanel(QPainter * p, int x, int y, int w, int h, const QPalette & pal, bool sunken, int lineWidth, const QBrush * fill)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_sunken = Shiboken::String::createStaticString("sunken");
                if (PyDict_Contains(kwds, key_sunken) != 0) {
                    value = PyDict_GetItem(kwds, key_sunken);
                    if (value != nullptr && pyArgs[6] != nullptr ) {
                        errInfo.reset(key_sunken);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[6] = value;
                        if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[6]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_sunken);
                }
                static PyObject *const key_lineWidth = Shiboken::String::createStaticString("lineWidth");
                if (PyDict_Contains(kwds, key_lineWidth) != 0) {
                    value = PyDict_GetItem(kwds, key_lineWidth);
                    if (value != nullptr && pyArgs[7] != nullptr ) {
                        errInfo.reset(key_lineWidth);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[7] = value;
                        if (!(pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[7]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_lineWidth);
                }
                static PyObject *const key_fill = Shiboken::String::createStaticString("fill");
                if (PyDict_Contains(kwds, key_fill) != 0) {
                    value = PyDict_GetItem(kwds, key_fill);
                    if (value != nullptr && pyArgs[8] != nullptr ) {
                        errInfo.reset(key_fill);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[8] = value;
                        if (!(pythonToCpp[8] = Shiboken::Conversions::pythonToCppPointerConversion(SbkPySide6_QtGuiTypes[SBK_QBRUSH_IDX], (pyArgs[8]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_fill);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPainter *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            if (!Shiboken::Object::isValid(pyArgs[5]))
                return {};
            ::QPalette cppArg5_local;
            ::QPalette *cppArg5 = &cppArg5_local;
            if (pythonToCpp[5].isValue())
                pythonToCpp[5](pyArgs[5], &cppArg5_local);
            else
                pythonToCpp[5](pyArgs[5], &cppArg5);

            bool cppArg6 = false;
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);
            int cppArg7 = 1;
            if (pythonToCpp[7])
                pythonToCpp[7](pyArgs[7], &cppArg7);
            if (!Shiboken::Object::isValid(pyArgs[8]))
                return {};
            ::QBrush *cppArg8 = nullptr;
            if (pythonToCpp[8])
                pythonToCpp[8](pyArgs[8], &cppArg8);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qDrawShadePanel(QPainter*,int,int,int,int,QPalette,bool,int,const QBrush*)
                qDrawShadePanel(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, *cppArg5, cppArg6, cppArg7, cppArg8);
            }
            break;
        }
        case 1: // qDrawShadePanel(QPainter * p, const QRect & r, const QPalette & pal, bool sunken, int lineWidth, const QBrush * fill)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_sunken = Shiboken::String::createStaticString("sunken");
                if (PyDict_Contains(kwds, key_sunken) != 0) {
                    value = PyDict_GetItem(kwds, key_sunken);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_sunken);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_sunken);
                }
                static PyObject *const key_lineWidth = Shiboken::String::createStaticString("lineWidth");
                if (PyDict_Contains(kwds, key_lineWidth) != 0) {
                    value = PyDict_GetItem(kwds, key_lineWidth);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_lineWidth);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_lineWidth);
                }
                static PyObject *const key_fill = Shiboken::String::createStaticString("fill");
                if (PyDict_Contains(kwds, key_fill) != 0) {
                    value = PyDict_GetItem(kwds, key_fill);
                    if (value != nullptr && pyArgs[5] != nullptr ) {
                        errInfo.reset(key_fill);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[5] = value;
                        if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppPointerConversion(SbkPySide6_QtGuiTypes[SBK_QBRUSH_IDX], (pyArgs[5]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_fill);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPainter *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QRect cppArg1_local;
            ::QRect *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QPalette cppArg2_local;
            ::QPalette *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);

            bool cppArg3 = false;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4 = 1;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);
            if (!Shiboken::Object::isValid(pyArgs[5]))
                return {};
            ::QBrush *cppArg5 = nullptr;
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qDrawShadePanel(QPainter*,QRect,QPalette,bool,int,const QBrush*)
                qDrawShadePanel(cppArg0, *cppArg1, *cppArg2, cppArg3, cppArg4, cppArg5);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *SbkQtWidgetsModule_qDrawShadeRect(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.qDrawShadeRect";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[10];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 10));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOOOOOOOO:qDrawShadeRect", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7]), &(pyArgs[8]), &(pyArgs[9])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qDrawShadeRect(QPainter*,int,int,int,int,QPalette,bool=,int=,int=,const QBrush*=)
    // 1: qDrawShadeRect(QPainter*,QRect,QPalette,bool=,int=,int=,const QBrush*=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(SbkPySide6_QtGuiTypes[SBK_QPAINTER_IDX], (pyArgs[0])))) {
        if (numArgs >= 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(SbkPySide6_QtCoreTypes[SBK_QRECT_IDX], (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(SbkPySide6_QtGuiTypes[SBK_QPALETTE_IDX], (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 1; // qDrawShadeRect(QPainter*,QRect,QPalette,bool,int,int,const QBrush*)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[3])))) {
                if (numArgs == 4) {
                    overloadId = 1; // qDrawShadeRect(QPainter*,QRect,QPalette,bool,int,int,const QBrush*)
                } else if (numArgs >= 5
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))) {
                    if (numArgs == 5) {
                        overloadId = 1; // qDrawShadeRect(QPainter*,QRect,QPalette,bool,int,int,const QBrush*)
                    } else if (numArgs >= 6
                        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5])))) {
                        if (numArgs == 6) {
                            overloadId = 1; // qDrawShadeRect(QPainter*,QRect,QPalette,bool,int,int,const QBrush*)
                        } else if (numArgs >= 7
                            && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppPointerConversion(SbkPySide6_QtGuiTypes[SBK_QBRUSH_IDX], (pyArgs[6])))) {
                            overloadId = 1; // qDrawShadeRect(QPainter*,QRect,QPalette,bool,int,int,const QBrush*)
                        }
                    }
                }
            }
        } else if (numArgs >= 6
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))
            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppReferenceConversion(SbkPySide6_QtGuiTypes[SBK_QPALETTE_IDX], (pyArgs[5])))) {
            if (numArgs == 6) {
                overloadId = 0; // qDrawShadeRect(QPainter*,int,int,int,int,QPalette,bool,int,int,const QBrush*)
            } else if (numArgs >= 7
                && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[6])))) {
                if (numArgs == 7) {
                    overloadId = 0; // qDrawShadeRect(QPainter*,int,int,int,int,QPalette,bool,int,int,const QBrush*)
                } else if (numArgs >= 8
                    && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[7])))) {
                    if (numArgs == 8) {
                        overloadId = 0; // qDrawShadeRect(QPainter*,int,int,int,int,QPalette,bool,int,int,const QBrush*)
                    } else if (numArgs >= 9
                        && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[8])))) {
                        if (numArgs == 9) {
                            overloadId = 0; // qDrawShadeRect(QPainter*,int,int,int,int,QPalette,bool,int,int,const QBrush*)
                        } else if (numArgs >= 10
                            && (pythonToCpp[9] = Shiboken::Conversions::pythonToCppPointerConversion(SbkPySide6_QtGuiTypes[SBK_QBRUSH_IDX], (pyArgs[9])))) {
                            overloadId = 0; // qDrawShadeRect(QPainter*,int,int,int,int,QPalette,bool,int,int,const QBrush*)
                        }
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // qDrawShadeRect(QPainter * p, int x, int y, int w, int h, const QPalette & pal, bool sunken, int lineWidth, int midLineWidth, const QBrush * fill)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_sunken = Shiboken::String::createStaticString("sunken");
                if (PyDict_Contains(kwds, key_sunken) != 0) {
                    value = PyDict_GetItem(kwds, key_sunken);
                    if (value != nullptr && pyArgs[6] != nullptr ) {
                        errInfo.reset(key_sunken);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[6] = value;
                        if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[6]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_sunken);
                }
                static PyObject *const key_lineWidth = Shiboken::String::createStaticString("lineWidth");
                if (PyDict_Contains(kwds, key_lineWidth) != 0) {
                    value = PyDict_GetItem(kwds, key_lineWidth);
                    if (value != nullptr && pyArgs[7] != nullptr ) {
                        errInfo.reset(key_lineWidth);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[7] = value;
                        if (!(pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[7]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_lineWidth);
                }
                static PyObject *const key_midLineWidth = Shiboken::String::createStaticString("midLineWidth");
                if (PyDict_Contains(kwds, key_midLineWidth) != 0) {
                    value = PyDict_GetItem(kwds, key_midLineWidth);
                    if (value != nullptr && pyArgs[8] != nullptr ) {
                        errInfo.reset(key_midLineWidth);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[8] = value;
                        if (!(pythonToCpp[8] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[8]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_midLineWidth);
                }
                static PyObject *const key_fill = Shiboken::String::createStaticString("fill");
                if (PyDict_Contains(kwds, key_fill) != 0) {
                    value = PyDict_GetItem(kwds, key_fill);
                    if (value != nullptr && pyArgs[9] != nullptr ) {
                        errInfo.reset(key_fill);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[9] = value;
                        if (!(pythonToCpp[9] = Shiboken::Conversions::pythonToCppPointerConversion(SbkPySide6_QtGuiTypes[SBK_QBRUSH_IDX], (pyArgs[9]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_fill);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPainter *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            if (!Shiboken::Object::isValid(pyArgs[5]))
                return {};
            ::QPalette cppArg5_local;
            ::QPalette *cppArg5 = &cppArg5_local;
            if (pythonToCpp[5].isValue())
                pythonToCpp[5](pyArgs[5], &cppArg5_local);
            else
                pythonToCpp[5](pyArgs[5], &cppArg5);

            bool cppArg6 = false;
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);
            int cppArg7 = 1;
            if (pythonToCpp[7])
                pythonToCpp[7](pyArgs[7], &cppArg7);
            int cppArg8 = 0;
            if (pythonToCpp[8])
                pythonToCpp[8](pyArgs[8], &cppArg8);
            if (!Shiboken::Object::isValid(pyArgs[9]))
                return {};
            ::QBrush *cppArg9 = nullptr;
            if (pythonToCpp[9])
                pythonToCpp[9](pyArgs[9], &cppArg9);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qDrawShadeRect(QPainter*,int,int,int,int,QPalette,bool,int,int,const QBrush*)
                qDrawShadeRect(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, *cppArg5, cppArg6, cppArg7, cppArg8, cppArg9);
            }
            break;
        }
        case 1: // qDrawShadeRect(QPainter * p, const QRect & r, const QPalette & pal, bool sunken, int lineWidth, int midLineWidth, const QBrush * fill)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_sunken = Shiboken::String::createStaticString("sunken");
                if (PyDict_Contains(kwds, key_sunken) != 0) {
                    value = PyDict_GetItem(kwds, key_sunken);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_sunken);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_sunken);
                }
                static PyObject *const key_lineWidth = Shiboken::String::createStaticString("lineWidth");
                if (PyDict_Contains(kwds, key_lineWidth) != 0) {
                    value = PyDict_GetItem(kwds, key_lineWidth);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_lineWidth);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_lineWidth);
                }
                static PyObject *const key_midLineWidth = Shiboken::String::createStaticString("midLineWidth");
                if (PyDict_Contains(kwds, key_midLineWidth) != 0) {
                    value = PyDict_GetItem(kwds, key_midLineWidth);
                    if (value != nullptr && pyArgs[5] != nullptr ) {
                        errInfo.reset(key_midLineWidth);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[5] = value;
                        if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_midLineWidth);
                }
                static PyObject *const key_fill = Shiboken::String::createStaticString("fill");
                if (PyDict_Contains(kwds, key_fill) != 0) {
                    value = PyDict_GetItem(kwds, key_fill);
                    if (value != nullptr && pyArgs[6] != nullptr ) {
                        errInfo.reset(key_fill);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[6] = value;
                        if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppPointerConversion(SbkPySide6_QtGuiTypes[SBK_QBRUSH_IDX], (pyArgs[6]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_fill);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPainter *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QRect cppArg1_local;
            ::QRect *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QPalette cppArg2_local;
            ::QPalette *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);

            bool cppArg3 = false;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4 = 1;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);
            int cppArg5 = 0;
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);
            if (!Shiboken::Object::isValid(pyArgs[6]))
                return {};
            ::QBrush *cppArg6 = nullptr;
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qDrawShadeRect(QPainter*,QRect,QPalette,bool,int,int,const QBrush*)
                qDrawShadeRect(cppArg0, *cppArg1, *cppArg2, cppArg3, cppArg4, cppArg5, cppArg6);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *SbkQtWidgetsModule_qDrawWinButton(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.qDrawWinButton";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[8];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 8));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOOOOOO:qDrawWinButton", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qDrawWinButton(QPainter*,int,int,int,int,QPalette,bool=,const QBrush*=)
    // 1: qDrawWinButton(QPainter*,QRect,QPalette,bool=,const QBrush*=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(SbkPySide6_QtGuiTypes[SBK_QPAINTER_IDX], (pyArgs[0])))) {
        if (numArgs >= 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(SbkPySide6_QtCoreTypes[SBK_QRECT_IDX], (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(SbkPySide6_QtGuiTypes[SBK_QPALETTE_IDX], (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 1; // qDrawWinButton(QPainter*,QRect,QPalette,bool,const QBrush*)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[3])))) {
                if (numArgs == 4) {
                    overloadId = 1; // qDrawWinButton(QPainter*,QRect,QPalette,bool,const QBrush*)
                } else if (numArgs >= 5
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppPointerConversion(SbkPySide6_QtGuiTypes[SBK_QBRUSH_IDX], (pyArgs[4])))) {
                    overloadId = 1; // qDrawWinButton(QPainter*,QRect,QPalette,bool,const QBrush*)
                }
            }
        } else if (numArgs >= 6
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))
            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppReferenceConversion(SbkPySide6_QtGuiTypes[SBK_QPALETTE_IDX], (pyArgs[5])))) {
            if (numArgs == 6) {
                overloadId = 0; // qDrawWinButton(QPainter*,int,int,int,int,QPalette,bool,const QBrush*)
            } else if (numArgs >= 7
                && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[6])))) {
                if (numArgs == 7) {
                    overloadId = 0; // qDrawWinButton(QPainter*,int,int,int,int,QPalette,bool,const QBrush*)
                } else if (numArgs >= 8
                    && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppPointerConversion(SbkPySide6_QtGuiTypes[SBK_QBRUSH_IDX], (pyArgs[7])))) {
                    overloadId = 0; // qDrawWinButton(QPainter*,int,int,int,int,QPalette,bool,const QBrush*)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // qDrawWinButton(QPainter * p, int x, int y, int w, int h, const QPalette & pal, bool sunken, const QBrush * fill)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_sunken = Shiboken::String::createStaticString("sunken");
                if (PyDict_Contains(kwds, key_sunken) != 0) {
                    value = PyDict_GetItem(kwds, key_sunken);
                    if (value != nullptr && pyArgs[6] != nullptr ) {
                        errInfo.reset(key_sunken);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[6] = value;
                        if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[6]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_sunken);
                }
                static PyObject *const key_fill = Shiboken::String::createStaticString("fill");
                if (PyDict_Contains(kwds, key_fill) != 0) {
                    value = PyDict_GetItem(kwds, key_fill);
                    if (value != nullptr && pyArgs[7] != nullptr ) {
                        errInfo.reset(key_fill);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[7] = value;
                        if (!(pythonToCpp[7] = Shiboken::Conversions::pythonToCppPointerConversion(SbkPySide6_QtGuiTypes[SBK_QBRUSH_IDX], (pyArgs[7]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_fill);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPainter *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            if (!Shiboken::Object::isValid(pyArgs[5]))
                return {};
            ::QPalette cppArg5_local;
            ::QPalette *cppArg5 = &cppArg5_local;
            if (pythonToCpp[5].isValue())
                pythonToCpp[5](pyArgs[5], &cppArg5_local);
            else
                pythonToCpp[5](pyArgs[5], &cppArg5);

            bool cppArg6 = false;
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);
            if (!Shiboken::Object::isValid(pyArgs[7]))
                return {};
            ::QBrush *cppArg7 = nullptr;
            if (pythonToCpp[7])
                pythonToCpp[7](pyArgs[7], &cppArg7);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qDrawWinButton(QPainter*,int,int,int,int,QPalette,bool,const QBrush*)
                qDrawWinButton(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, *cppArg5, cppArg6, cppArg7);
            }
            break;
        }
        case 1: // qDrawWinButton(QPainter * p, const QRect & r, const QPalette & pal, bool sunken, const QBrush * fill)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_sunken = Shiboken::String::createStaticString("sunken");
                if (PyDict_Contains(kwds, key_sunken) != 0) {
                    value = PyDict_GetItem(kwds, key_sunken);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_sunken);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_sunken);
                }
                static PyObject *const key_fill = Shiboken::String::createStaticString("fill");
                if (PyDict_Contains(kwds, key_fill) != 0) {
                    value = PyDict_GetItem(kwds, key_fill);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_fill);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppPointerConversion(SbkPySide6_QtGuiTypes[SBK_QBRUSH_IDX], (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_fill);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPainter *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QRect cppArg1_local;
            ::QRect *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QPalette cppArg2_local;
            ::QPalette *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);

            bool cppArg3 = false;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return {};
            ::QBrush *cppArg4 = nullptr;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qDrawWinButton(QPainter*,QRect,QPalette,bool,const QBrush*)
                qDrawWinButton(cppArg0, *cppArg1, *cppArg2, cppArg3, cppArg4);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *SbkQtWidgetsModule_qDrawWinPanel(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.qDrawWinPanel";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[8];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 8));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOOOOOO:qDrawWinPanel", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qDrawWinPanel(QPainter*,int,int,int,int,QPalette,bool=,const QBrush*=)
    // 1: qDrawWinPanel(QPainter*,QRect,QPalette,bool=,const QBrush*=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(SbkPySide6_QtGuiTypes[SBK_QPAINTER_IDX], (pyArgs[0])))) {
        if (numArgs >= 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(SbkPySide6_QtCoreTypes[SBK_QRECT_IDX], (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(SbkPySide6_QtGuiTypes[SBK_QPALETTE_IDX], (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 1; // qDrawWinPanel(QPainter*,QRect,QPalette,bool,const QBrush*)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[3])))) {
                if (numArgs == 4) {
                    overloadId = 1; // qDrawWinPanel(QPainter*,QRect,QPalette,bool,const QBrush*)
                } else if (numArgs >= 5
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppPointerConversion(SbkPySide6_QtGuiTypes[SBK_QBRUSH_IDX], (pyArgs[4])))) {
                    overloadId = 1; // qDrawWinPanel(QPainter*,QRect,QPalette,bool,const QBrush*)
                }
            }
        } else if (numArgs >= 6
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))
            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppReferenceConversion(SbkPySide6_QtGuiTypes[SBK_QPALETTE_IDX], (pyArgs[5])))) {
            if (numArgs == 6) {
                overloadId = 0; // qDrawWinPanel(QPainter*,int,int,int,int,QPalette,bool,const QBrush*)
            } else if (numArgs >= 7
                && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[6])))) {
                if (numArgs == 7) {
                    overloadId = 0; // qDrawWinPanel(QPainter*,int,int,int,int,QPalette,bool,const QBrush*)
                } else if (numArgs >= 8
                    && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppPointerConversion(SbkPySide6_QtGuiTypes[SBK_QBRUSH_IDX], (pyArgs[7])))) {
                    overloadId = 0; // qDrawWinPanel(QPainter*,int,int,int,int,QPalette,bool,const QBrush*)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // qDrawWinPanel(QPainter * p, int x, int y, int w, int h, const QPalette & pal, bool sunken, const QBrush * fill)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_sunken = Shiboken::String::createStaticString("sunken");
                if (PyDict_Contains(kwds, key_sunken) != 0) {
                    value = PyDict_GetItem(kwds, key_sunken);
                    if (value != nullptr && pyArgs[6] != nullptr ) {
                        errInfo.reset(key_sunken);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[6] = value;
                        if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[6]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_sunken);
                }
                static PyObject *const key_fill = Shiboken::String::createStaticString("fill");
                if (PyDict_Contains(kwds, key_fill) != 0) {
                    value = PyDict_GetItem(kwds, key_fill);
                    if (value != nullptr && pyArgs[7] != nullptr ) {
                        errInfo.reset(key_fill);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[7] = value;
                        if (!(pythonToCpp[7] = Shiboken::Conversions::pythonToCppPointerConversion(SbkPySide6_QtGuiTypes[SBK_QBRUSH_IDX], (pyArgs[7]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_fill);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPainter *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            if (!Shiboken::Object::isValid(pyArgs[5]))
                return {};
            ::QPalette cppArg5_local;
            ::QPalette *cppArg5 = &cppArg5_local;
            if (pythonToCpp[5].isValue())
                pythonToCpp[5](pyArgs[5], &cppArg5_local);
            else
                pythonToCpp[5](pyArgs[5], &cppArg5);

            bool cppArg6 = false;
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);
            if (!Shiboken::Object::isValid(pyArgs[7]))
                return {};
            ::QBrush *cppArg7 = nullptr;
            if (pythonToCpp[7])
                pythonToCpp[7](pyArgs[7], &cppArg7);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qDrawWinPanel(QPainter*,int,int,int,int,QPalette,bool,const QBrush*)
                qDrawWinPanel(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, *cppArg5, cppArg6, cppArg7);
            }
            break;
        }
        case 1: // qDrawWinPanel(QPainter * p, const QRect & r, const QPalette & pal, bool sunken, const QBrush * fill)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_sunken = Shiboken::String::createStaticString("sunken");
                if (PyDict_Contains(kwds, key_sunken) != 0) {
                    value = PyDict_GetItem(kwds, key_sunken);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_sunken);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_sunken);
                }
                static PyObject *const key_fill = Shiboken::String::createStaticString("fill");
                if (PyDict_Contains(kwds, key_fill) != 0) {
                    value = PyDict_GetItem(kwds, key_fill);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_fill);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppPointerConversion(SbkPySide6_QtGuiTypes[SBK_QBRUSH_IDX], (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_fill);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPainter *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QRect cppArg1_local;
            ::QRect *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QPalette cppArg2_local;
            ::QPalette *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);

            bool cppArg3 = false;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return {};
            ::QBrush *cppArg4 = nullptr;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qDrawWinPanel(QPainter*,QRect,QPalette,bool,const QBrush*)
                qDrawWinPanel(cppArg0, *cppArg1, *cppArg2, cppArg3, cppArg4);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static PyMethodDef QtWidgets_methods[] = {
    {"qDrawPlainRect", reinterpret_cast<PyCFunction>(SbkQtWidgetsModule_qDrawPlainRect), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"qDrawShadeLine", reinterpret_cast<PyCFunction>(SbkQtWidgetsModule_qDrawShadeLine), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"qDrawShadePanel", reinterpret_cast<PyCFunction>(SbkQtWidgetsModule_qDrawShadePanel), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"qDrawShadeRect", reinterpret_cast<PyCFunction>(SbkQtWidgetsModule_qDrawShadeRect), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"qDrawWinButton", reinterpret_cast<PyCFunction>(SbkQtWidgetsModule_qDrawWinButton), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"qDrawWinPanel", reinterpret_cast<PyCFunction>(SbkQtWidgetsModule_qDrawWinPanel), METH_VARARGS|METH_KEYWORDS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Classes initialization functions ------------------------------------------------------------
void init_QWhatsThis(PyObject *module);
void init_QTreeWidgetItemIterator(PyObject *module);
void init_QTreeWidgetItem(PyObject *module);
void init_QTableWidgetSelectionRange(PyObject *module);
void init_QTableWidgetItem(PyObject *module);
void init_QStyleHintReturn(PyObject *module);
void init_QStyleHintReturnVariant(PyObject *module);
void init_QStyleFactory(PyObject *module);
void init_QSizePolicy(PyObject *module);
void init_QScrollerProperties(PyObject *module);
void init_QListWidgetItem(PyObject *module);
void init_QLayoutItem(PyObject *module);
void init_QSpacerItem(PyObject *module);
void init_QItemEditorFactory(PyObject *module);
void init_QItemEditorCreatorBase(PyObject *module);
void init_QGestureRecognizer(PyObject *module);
void init_QColormap(PyObject *module);
void init_QStyleHintReturnMask(PyObject *module);
void init_QAccessibleWidget(PyObject *module);
void init_QFileIconProvider(PyObject *module);
void init_QTileRules(PyObject *module);
void init_QGraphicsLayoutItem(PyObject *module);
void init_QGraphicsLayout(PyObject *module);
void init_QGraphicsLinearLayout(PyObject *module);
void init_QGraphicsGridLayout(PyObject *module);
void init_QGraphicsAnchorLayout(PyObject *module);
void init_QGraphicsItem(PyObject *module);
void init_QGraphicsPixmapItem(PyObject *module);
void init_QGraphicsLineItem(PyObject *module);
void init_QGraphicsItemGroup(PyObject *module);
void init_QAbstractGraphicsShapeItem(PyObject *module);
void init_QGraphicsSimpleTextItem(PyObject *module);
void init_QGraphicsRectItem(PyObject *module);
void init_QGraphicsPolygonItem(PyObject *module);
void init_QGraphicsPathItem(PyObject *module);
void init_QGraphicsEllipseItem(PyObject *module);
void init_QToolTip(PyObject *module);
void init_QStylePainter(PyObject *module);
void init_QWidget(PyObject *module);
void init_QWizardPage(PyObject *module);
void init_QWidgetItem(PyObject *module);
void init_QToolBar(PyObject *module);
void init_QTabWidget(PyObject *module);
void init_QTabBar(PyObject *module);
void init_QStatusBar(PyObject *module);
void init_QSplitterHandle(PyObject *module);
void init_QSplashScreen(PyObject *module);
void init_QSizeGrip(PyObject *module);
void init_QRubberBand(PyObject *module);
void init_QProgressBar(PyObject *module);
void init_QMenuBar(PyObject *module);
void init_QMenu(PyObject *module);
void init_QMdiSubWindow(PyObject *module);
void init_QMainWindow(PyObject *module);
void init_QLineEdit(PyObject *module);
void init_QKeySequenceEdit(PyObject *module);
void init_QGroupBox(PyObject *module);
void init_QFrame(PyObject *module);
void init_QToolBox(PyObject *module);
void init_QStackedWidget(PyObject *module);
void init_QSplitter(PyObject *module);
void init_QLabel(PyObject *module);
void init_QLCDNumber(PyObject *module);
void init_QAbstractScrollArea(PyObject *module);
void init_QTextEdit(PyObject *module);
void init_QTextEdit_ExtraSelection(PyObject *enclosingClass);
void init_QTextBrowser(PyObject *module);
void init_QScrollArea(PyObject *module);
void init_QPlainTextEdit(PyObject *module);
void init_QMdiArea(PyObject *module);
void init_QGraphicsView(PyObject *module);
void init_QAbstractItemView(PyObject *module);
void init_QTreeView(PyObject *module);
void init_QTreeWidget(PyObject *module);
void init_QTableView(PyObject *module);
void init_QTableWidget(PyObject *module);
void init_QListView(PyObject *module);
void init_QUndoView(PyObject *module);
void init_QListWidget(PyObject *module);
void init_QHeaderView(PyObject *module);
void init_QColumnView(PyObject *module);
void init_QFocusFrame(PyObject *module);
void init_QDockWidget(PyObject *module);
void init_QDialogButtonBox(PyObject *module);
void init_QDialog(PyObject *module);
void init_QWizard(PyObject *module);
void init_QProgressDialog(PyObject *module);
void init_QMessageBox(PyObject *module);
void init_QInputDialog(PyObject *module);
void init_QFontDialog(PyObject *module);
void init_QErrorMessage(PyObject *module);
void init_QColorDialog(PyObject *module);
void init_QComboBox(PyObject *module);
void init_QFontComboBox(PyObject *module);
void init_QCalendarWidget(PyObject *module);
void init_QAbstractSpinBox(PyObject *module);
void init_QSpinBox(PyObject *module);
void init_QDoubleSpinBox(PyObject *module);
void init_QDateTimeEdit(PyObject *module);
void init_QTimeEdit(PyObject *module);
void init_QDateEdit(PyObject *module);
void init_QAbstractSlider(PyObject *module);
void init_QSlider(PyObject *module);
void init_QScrollBar(PyObject *module);
void init_QDial(PyObject *module);
void init_QAbstractButton(PyObject *module);
void init_QToolButton(PyObject *module);
void init_QRadioButton(PyObject *module);
void init_QPushButton(PyObject *module);
void init_QCommandLinkButton(PyObject *module);
void init_QCheckBox(PyObject *module);
void init_QSystemTrayIcon(PyObject *module);
void init_QStyleOption(PyObject *module);
void init_QStyleOptionViewItem(PyObject *module);
void init_QStyleOptionToolBox(PyObject *module);
void init_QStyleOptionToolBar(PyObject *module);
void init_QStyleOptionTabWidgetFrame(PyObject *module);
void init_QStyleOptionTabBarBase(PyObject *module);
void init_QStyleOptionTab(PyObject *module);
void init_QStyleOptionRubberBand(PyObject *module);
void init_QStyleOptionProgressBar(PyObject *module);
void init_QStyleOptionMenuItem(PyObject *module);
void init_QStyleOptionHeader(PyObject *module);
void init_QStyleOptionHeaderV2(PyObject *module);
void init_QStyleOptionGraphicsItem(PyObject *module);
void init_QStyleOptionFrame(PyObject *module);
void init_QStyleOptionFocusRect(PyObject *module);
void init_QStyleOptionDockWidget(PyObject *module);
void init_QStyleOptionComplex(PyObject *module);
void init_QStyleOptionToolButton(PyObject *module);
void init_QStyleOptionTitleBar(PyObject *module);
void init_QStyleOptionSpinBox(PyObject *module);
void init_QStyleOptionSlider(PyObject *module);
void init_QStyleOptionSizeGrip(PyObject *module);
void init_QStyleOptionGroupBox(PyObject *module);
void init_QStyleOptionComboBox(PyObject *module);
void init_QStyleOptionButton(PyObject *module);
void init_QStyle(PyObject *module);
void init_QCommonStyle(PyObject *module);
void init_QProxyStyle(PyObject *module);
void init_QScroller(PyObject *module);
void init_QLayout(PyObject *module);
void init_QStackedLayout(PyObject *module);
void init_QGridLayout(PyObject *module);
void init_QFormLayout(PyObject *module);
void init_QFormLayout_TakeRowResult(PyObject *enclosingClass);
void init_QBoxLayout(PyObject *module);
void init_QVBoxLayout(PyObject *module);
void init_QHBoxLayout(PyObject *module);
void init_QGraphicsTransform(PyObject *module);
void init_QGraphicsScale(PyObject *module);
void init_QGraphicsRotation(PyObject *module);
void init_QGraphicsScene(PyObject *module);
void init_QGraphicsObject(PyObject *module);
void init_QGraphicsWidget(PyObject *module);
void init_QGraphicsProxyWidget(PyObject *module);
void init_QGraphicsTextItem(PyObject *module);
void init_QGraphicsItemAnimation(PyObject *module);
void init_QGraphicsEffect(PyObject *module);
void init_QGraphicsOpacityEffect(PyObject *module);
void init_QGraphicsDropShadowEffect(PyObject *module);
void init_QGraphicsColorizeEffect(PyObject *module);
void init_QGraphicsBlurEffect(PyObject *module);
void init_QGraphicsAnchor(PyObject *module);
void init_QGesture(PyObject *module);
void init_QTapGesture(PyObject *module);
void init_QTapAndHoldGesture(PyObject *module);
void init_QSwipeGesture(PyObject *module);
void init_QPinchGesture(PyObject *module);
void init_QPanGesture(PyObject *module);
void init_QDataWidgetMapper(PyObject *module);
void init_QCompleter(PyObject *module);
void init_QButtonGroup(PyObject *module);
void init_QAbstractItemDelegate(PyObject *module);
void init_QStyledItemDelegate(PyObject *module);
void init_QItemDelegate(PyObject *module);
void init_QWidgetAction(PyObject *module);
void init_QPlainTextDocumentLayout(PyObject *module);
void init_QGraphicsSceneEvent(PyObject *module);
void init_QGraphicsSceneWheelEvent(PyObject *module);
void init_QGraphicsSceneResizeEvent(PyObject *module);
void init_QGraphicsSceneMoveEvent(PyObject *module);
void init_QGraphicsSceneMouseEvent(PyObject *module);
void init_QGraphicsSceneHoverEvent(PyObject *module);
void init_QGraphicsSceneHelpEvent(PyObject *module);
void init_QGraphicsSceneDragDropEvent(PyObject *module);
void init_QGraphicsSceneContextMenuEvent(PyObject *module);
void init_QGestureEvent(PyObject *module);
void init_QApplication(PyObject *module);
void init_QFileDialog(PyObject *module);
void init_QFileSystemModel(PyObject *module);

// Required modules' type and converter arrays.
PyTypeObject **SbkPySide6_QtGuiTypes;
SbkConverter **SbkPySide6_QtGuiTypeConverters;
PyTypeObject **SbkPySide6_QtCoreTypes;
SbkConverter **SbkPySide6_QtCoreTypeConverters;

// Module initialization ------------------------------------------------------------
// Container Type converters.

// C++ to Python conversion for container type 'QList<int>'.
static PyObject *_QList_int__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<int> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_int_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<int> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        int cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_int__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyIn))
        return PySequence_PythonToCpp__QList_int_;
    return {};
}


// Binding for QList<int>

template <>
struct ShibokenContainerValueConverter<int>
{
    static bool checkValue(PyObject *pyArg)
    {
        return PyLong_Check(pyArg);
    }

    static PyObject *convertValueToPython(int cppArg)
    {
        return Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppArg);
    }

    static std::optional<int> convertValueToCpp(PyObject *pyArg)
    {
        Shiboken::Conversions::PythonToCppConversion pythonToCpp;
        if (!(PyLong_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg))))) {
            Shiboken::Errors::setWrongContainerType();
            return {};
        }
        int cppArg;
        pythonToCpp(pyArg, &cppArg);
        return cppArg;
    }
};

static PyMethodDef QIntList_methods[] = {
    {"push_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::push_back), METH_O, "push_back"},
    {"append", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::push_back), METH_O, "append"},
    {"clear", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::clear), METH_NOARGS, "clear"},
    {"pop_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::pop_back), METH_NOARGS, "pop_back"},
    {"removeLast", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::pop_back), METH_NOARGS, "removeLast"},
    {"push_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::push_front), METH_O, "push_front"},
    {"prepend", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::push_front), METH_O, "prepend"},
    {"pop_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::pop_front), METH_NOARGS, "pop_front"},
    {"removeFirst", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::pop_front), METH_O, "removeFirst"},
    {"reserve", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::reserve), METH_O, "reserve"},
    {"capacity", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::capacity), METH_NOARGS, "capacity"},
    {"data", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::data), METH_NOARGS, "data"},
    {"constData", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::constData), METH_NOARGS, "constData"},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyType_Slot QIntList_slots[] = {
    {Py_tp_init, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::tpInit)},
    {Py_tp_new, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::tpNew)},
    {Py_tp_free, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::tpFree)},
    {Py_tp_dealloc, reinterpret_cast<void *>(Sbk_object_dealloc)},
    {Py_tp_methods, reinterpret_cast<void *>(QIntList_methods)},
    {Py_sq_ass_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::sqSetItem)},
    {Py_sq_length, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::sqLen)},
    {Py_sq_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::sqGetItem)},
    {0, nullptr}
};

static PyType_Spec QIntList_spec = {
    "2:PySide6.QtWidgets.QIntList",
    sizeof(ShibokenContainer),
    0,
    Py_TPFLAGS_DEFAULT,
    QIntList_slots
};

static inline PyTypeObject *createQIntListType()
{
    auto *result = reinterpret_cast<PyTypeObject *>(SbkType_FromSpec(&QIntList_spec));
    Py_INCREF(Py_True);
    Shiboken::AutoDecRef tpDict(PepType_GetDict(result));
    PyDict_SetItem(tpDict.object(), Shiboken::PyMagicName::opaque_container(), Py_True);
    return result;
}

static PyTypeObject *QIntList_TypeF()
{
    static PyTypeObject *type = createQIntListType();
    return type;
}

extern "C" PyObject *createQIntList(QList<int>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QIntList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<int>>();
    d->m_list = ct;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" PyObject *createConstQIntList(const QList<int>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QIntList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<int>>();
    d->m_list = const_cast<QList<int> *>(ct);
    d->m_const = true;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" int QIntList_Check(PyObject *pyArg)
{
    return pyArg != nullptr && pyArg != Py_None && pyArg->ob_type == QIntList_TypeF();
}

extern "C" void PythonToCppQIntList(PyObject *pyArg, void *cppOut)
{
    auto *d = ShibokenSequenceContainerPrivate<QList<int>>::get(pyArg);
    *reinterpret_cast<QList<int>**>(cppOut) = d->m_list;
}

extern "C" PythonToCppFunc isQIntListPythonToCppConvertible(PyObject *pyArg)
{
    if (QIntList_Check(pyArg))
        return PythonToCppQIntList;
    return {};
}

// C++ to Python conversion for container type 'QList<QTreeWidgetItem*>'.
static PyObject *_QList_QTreeWidgetItemPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QTreeWidgetItem*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(SbkPySide6_QtWidgetsTypes[SBK_QTREEWIDGETITEM_IDX], cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QTreeWidgetItemPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QTreeWidgetItem*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QTreeWidgetItem* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_QtWidgetsTypes[SBK_QTREEWIDGETITEM_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QTreeWidgetItemPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(SbkPySide6_QtWidgetsTypes[SBK_QTREEWIDGETITEM_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QTreeWidgetItemPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QColor>'.
static PyObject *_QList_QColor__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QColor> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypes[SBK_QCOLOR_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QColor_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QColor> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QColor cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtGuiTypes[SBK_QCOLOR_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QColor__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtGuiTypes[SBK_QCOLOR_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QColor_;
    return {};
}

// C++ to Python conversion for container type 'std::pair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag>>'.
static PyObject *std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag___CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::std::pair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag>> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - START
    PyObject *pyOut = PyTuple_New(2);
    PyTuple_SET_ITEM(pyOut, 0, Shiboken::Conversions::pointerToPython(SbkPySide6_QtGuiTypes[SBK_QACCESSIBLEINTERFACE_IDX], cppInRef.first));
    PyTuple_SET_ITEM(pyOut, 1, Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QFLAGS_QACCESSIBLE_RELATIONFLAG_IDX]))->converter, &cppInRef.second));
    return pyOut;
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - END

}
static void PySequence_PythonToCpp_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag__(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::std::pair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag>> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - START
    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_QtGuiTypes[SBK_QACCESSIBLEINTERFACE_IDX], PySequence_Fast_GET_ITEM(pyIn, 0), &(cppOutRef.first));
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QFLAGS_QACCESSIBLE_RELATIONFLAG_IDX]))->converter, PySequence_Fast_GET_ITEM(pyIn, 1), &(cppOutRef.second));
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag___Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertiblePairTypes(PepType_SOTP(reinterpret_cast<PyTypeObject *>(SbkPySide6_QtGuiTypes[SBK_QACCESSIBLEINTERFACE_IDX]))->converter, true, PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtGuiTypes[SBK_QFLAGS_QACCESSIBLE_RELATIONFLAG_IDX]))->converter, false, pyIn))
        return PySequence_PythonToCpp_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag__;
    return {};
}

// C++ to Python conversion for container type 'QList<std::pair< QAccessibleInterface*,QFlags<QAccessible::RelationFlag>>>'.
static PyObject *_QList_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag____CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<std::pair< QAccessibleInterface*,QFlags<QAccessible::RelationFlag>>> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_STD_PAIR_QACCESSIBLEINTERFACEPTR_QFLAGS_QACCESSIBLE_RELATIONFLAG_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag___(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<std::pair< QAccessibleInterface*,QFlags<QAccessible::RelationFlag>>> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::std::pair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag>> cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_STD_PAIR_QACCESSIBLEINTERFACEPTR_QFLAGS_QACCESSIBLE_RELATIONFLAG_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag____Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_STD_PAIR_QACCESSIBLEINTERFACEPTR_QFLAGS_QACCESSIBLE_RELATIONFLAG_IDX], pyIn))
        return PySequence_PythonToCpp__QList_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag___;
    return {};
}

// C++ to Python conversion for container type 'QList<QGraphicsItem*>'.
static PyObject *_QList_QGraphicsItemPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QGraphicsItem*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(SbkPySide6_QtWidgetsTypes[SBK_QGRAPHICSITEM_IDX], cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QGraphicsItemPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QGraphicsItem*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QGraphicsItem* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_QtWidgetsTypes[SBK_QGRAPHICSITEM_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QGraphicsItemPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(SbkPySide6_QtWidgetsTypes[SBK_QGRAPHICSITEM_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QGraphicsItemPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QGraphicsTransform*>'.
static PyObject *_QList_QGraphicsTransformPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QGraphicsTransform*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(SbkPySide6_QtWidgetsTypes[SBK_QGRAPHICSTRANSFORM_IDX], cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QGraphicsTransformPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QGraphicsTransform*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QGraphicsTransform* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_QtWidgetsTypes[SBK_QGRAPHICSTRANSFORM_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QGraphicsTransformPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(SbkPySide6_QtWidgetsTypes[SBK_QGRAPHICSTRANSFORM_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QGraphicsTransformPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QLine>'.
static PyObject *_QList_QLine__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QLine> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypes[SBK_QLINE_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QLine_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QLine> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QLine cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypes[SBK_QLINE_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QLine__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypes[SBK_QLINE_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QLine_;
    return {};
}

// C++ to Python conversion for container type 'QList<QLineF>'.
static PyObject *_QList_QLineF__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QLineF> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypes[SBK_QLINEF_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QLineF_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QLineF> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QLineF cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypes[SBK_QLINEF_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QLineF__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypes[SBK_QLINEF_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QLineF_;
    return {};
}

// C++ to Python conversion for container type 'QList<QPoint>'.
static PyObject *_QList_QPoint__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QPoint> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypes[SBK_QPOINT_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QPoint_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QPoint> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QPoint cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypes[SBK_QPOINT_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QPoint__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypes[SBK_QPOINT_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QPoint_;
    return {};
}


// Binding for QList<QPoint>

template <>
struct ShibokenContainerValueConverter<QPoint>
{
    static bool checkValue(PyObject *pyArg)
    {
        return SbkObject_TypeCheck(SbkPySide6_QtCoreTypes[SBK_QPOINT_IDX], pyArg);
    }

    static PyObject *convertValueToPython(const QPoint &cppArg)
    {
        return Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypes[SBK_QPOINT_IDX], &cppArg);
    }

    static std::optional<QPoint> convertValueToCpp(PyObject *pyArg)
    {
        Shiboken::Conversions::PythonToCppConversion pythonToCpp;
        if (!((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(SbkPySide6_QtCoreTypes[SBK_QPOINT_IDX], (pyArg))))) {
            Shiboken::Errors::setWrongContainerType();
            return {};
        }
        ::QPoint cppArg;
        pythonToCpp(pyArg, &cppArg);
        return cppArg;
    }
};

static PyMethodDef QPointList_methods[] = {
    {"push_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::push_back), METH_O, "push_back"},
    {"append", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::push_back), METH_O, "append"},
    {"clear", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::clear), METH_NOARGS, "clear"},
    {"pop_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::pop_back), METH_NOARGS, "pop_back"},
    {"removeLast", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::pop_back), METH_NOARGS, "removeLast"},
    {"push_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::push_front), METH_O, "push_front"},
    {"prepend", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::push_front), METH_O, "prepend"},
    {"pop_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::pop_front), METH_NOARGS, "pop_front"},
    {"removeFirst", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::pop_front), METH_O, "removeFirst"},
    {"reserve", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::reserve), METH_O, "reserve"},
    {"capacity", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::capacity), METH_NOARGS, "capacity"},
    {"data", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::data), METH_NOARGS, "data"},
    {"constData", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::constData), METH_NOARGS, "constData"},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyType_Slot QPointList_slots[] = {
    {Py_tp_init, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPoint>>::tpInit)},
    {Py_tp_new, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPoint>>::tpNew)},
    {Py_tp_free, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPoint>>::tpFree)},
    {Py_tp_dealloc, reinterpret_cast<void *>(Sbk_object_dealloc)},
    {Py_tp_methods, reinterpret_cast<void *>(QPointList_methods)},
    {Py_sq_ass_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPoint>>::sqSetItem)},
    {Py_sq_length, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPoint>>::sqLen)},
    {Py_sq_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPoint>>::sqGetItem)},
    {0, nullptr}
};

static PyType_Spec QPointList_spec = {
    "2:PySide6.QtWidgets.QPointList",
    sizeof(ShibokenContainer),
    0,
    Py_TPFLAGS_DEFAULT,
    QPointList_slots
};

static inline PyTypeObject *createQPointListType()
{
    auto *result = reinterpret_cast<PyTypeObject *>(SbkType_FromSpec(&QPointList_spec));
    Py_INCREF(Py_True);
    Shiboken::AutoDecRef tpDict(PepType_GetDict(result));
    PyDict_SetItem(tpDict.object(), Shiboken::PyMagicName::opaque_container(), Py_True);
    return result;
}

static PyTypeObject *QPointList_TypeF()
{
    static PyTypeObject *type = createQPointListType();
    return type;
}

extern "C" PyObject *createQPointList(QList<QPoint>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QPointList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<QPoint>>();
    d->m_list = ct;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" PyObject *createConstQPointList(const QList<QPoint>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QPointList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<QPoint>>();
    d->m_list = const_cast<QList<QPoint> *>(ct);
    d->m_const = true;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" int QPointList_Check(PyObject *pyArg)
{
    return pyArg != nullptr && pyArg != Py_None && pyArg->ob_type == QPointList_TypeF();
}

extern "C" void PythonToCppQPointList(PyObject *pyArg, void *cppOut)
{
    auto *d = ShibokenSequenceContainerPrivate<QList<QPoint>>::get(pyArg);
    *reinterpret_cast<QList<QPoint>**>(cppOut) = d->m_list;
}

extern "C" PythonToCppFunc isQPointListPythonToCppConvertible(PyObject *pyArg)
{
    if (QPointList_Check(pyArg))
        return PythonToCppQPointList;
    return {};
}

// C++ to Python conversion for container type 'QList<QPointF>'.
static PyObject *_QList_QPointF__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QPointF> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypes[SBK_QPOINTF_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QPointF_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QPointF> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QPointF cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypes[SBK_QPOINTF_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QPointF__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypes[SBK_QPOINTF_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QPointF_;
    return {};
}


// Binding for QList<QPointF>

template <>
struct ShibokenContainerValueConverter<QPointF>
{
    static bool checkValue(PyObject *pyArg)
    {
        return SbkObject_TypeCheck(SbkPySide6_QtCoreTypes[SBK_QPOINTF_IDX], pyArg);
    }

    static PyObject *convertValueToPython(const QPointF &cppArg)
    {
        return Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypes[SBK_QPOINTF_IDX], &cppArg);
    }

    static std::optional<QPointF> convertValueToCpp(PyObject *pyArg)
    {
        Shiboken::Conversions::PythonToCppConversion pythonToCpp;
        if (!((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(SbkPySide6_QtCoreTypes[SBK_QPOINTF_IDX], (pyArg))))) {
            Shiboken::Errors::setWrongContainerType();
            return {};
        }
        ::QPointF cppArg;
        pythonToCpp(pyArg, &cppArg);
        return cppArg;
    }
};

static PyMethodDef QPointFList_methods[] = {
    {"push_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::push_back), METH_O, "push_back"},
    {"append", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::push_back), METH_O, "append"},
    {"clear", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::clear), METH_NOARGS, "clear"},
    {"pop_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::pop_back), METH_NOARGS, "pop_back"},
    {"removeLast", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::pop_back), METH_NOARGS, "removeLast"},
    {"push_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::push_front), METH_O, "push_front"},
    {"prepend", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::push_front), METH_O, "prepend"},
    {"pop_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::pop_front), METH_NOARGS, "pop_front"},
    {"removeFirst", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::pop_front), METH_O, "removeFirst"},
    {"reserve", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::reserve), METH_O, "reserve"},
    {"capacity", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::capacity), METH_NOARGS, "capacity"},
    {"data", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::data), METH_NOARGS, "data"},
    {"constData", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::constData), METH_NOARGS, "constData"},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyType_Slot QPointFList_slots[] = {
    {Py_tp_init, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPointF>>::tpInit)},
    {Py_tp_new, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPointF>>::tpNew)},
    {Py_tp_free, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPointF>>::tpFree)},
    {Py_tp_dealloc, reinterpret_cast<void *>(Sbk_object_dealloc)},
    {Py_tp_methods, reinterpret_cast<void *>(QPointFList_methods)},
    {Py_sq_ass_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPointF>>::sqSetItem)},
    {Py_sq_length, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPointF>>::sqLen)},
    {Py_sq_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPointF>>::sqGetItem)},
    {0, nullptr}
};

static PyType_Spec QPointFList_spec = {
    "2:PySide6.QtWidgets.QPointFList",
    sizeof(ShibokenContainer),
    0,
    Py_TPFLAGS_DEFAULT,
    QPointFList_slots
};

static inline PyTypeObject *createQPointFListType()
{
    auto *result = reinterpret_cast<PyTypeObject *>(SbkType_FromSpec(&QPointFList_spec));
    Py_INCREF(Py_True);
    Shiboken::AutoDecRef tpDict(PepType_GetDict(result));
    PyDict_SetItem(tpDict.object(), Shiboken::PyMagicName::opaque_container(), Py_True);
    return result;
}

static PyTypeObject *QPointFList_TypeF()
{
    static PyTypeObject *type = createQPointFListType();
    return type;
}

extern "C" PyObject *createQPointFList(QList<QPointF>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QPointFList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<QPointF>>();
    d->m_list = ct;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" PyObject *createConstQPointFList(const QList<QPointF>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QPointFList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<QPointF>>();
    d->m_list = const_cast<QList<QPointF> *>(ct);
    d->m_const = true;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" int QPointFList_Check(PyObject *pyArg)
{
    return pyArg != nullptr && pyArg != Py_None && pyArg->ob_type == QPointFList_TypeF();
}

extern "C" void PythonToCppQPointFList(PyObject *pyArg, void *cppOut)
{
    auto *d = ShibokenSequenceContainerPrivate<QList<QPointF>>::get(pyArg);
    *reinterpret_cast<QList<QPointF>**>(cppOut) = d->m_list;
}

extern "C" PythonToCppFunc isQPointFListPythonToCppConvertible(PyObject *pyArg)
{
    if (QPointFList_Check(pyArg))
        return PythonToCppQPointFList;
    return {};
}

// C++ to Python conversion for container type 'QList<QRect>'.
static PyObject *_QList_QRect__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QRect> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypes[SBK_QRECT_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QRect_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QRect> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QRect cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypes[SBK_QRECT_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QRect__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypes[SBK_QRECT_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QRect_;
    return {};
}

// C++ to Python conversion for container type 'QList<QRectF>'.
static PyObject *_QList_QRectF__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QRectF> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypes[SBK_QRECTF_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QRectF_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QRectF> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QRectF cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypes[SBK_QRECTF_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QRectF__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypes[SBK_QRECTF_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QRectF_;
    return {};
}

// C++ to Python conversion for container type 'QList<QAction*>'.
static PyObject *_QList_QActionPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QAction*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(SbkPySide6_QtGuiTypes[SBK_QACTION_IDX], cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QActionPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QAction*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QAction* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_QtGuiTypes[SBK_QACTION_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QActionPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(SbkPySide6_QtGuiTypes[SBK_QACTION_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QActionPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QObject*>'.
static PyObject *_QList_QObjectPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QObject*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(SbkPySide6_QtCoreTypes[SBK_QOBJECT_IDX], cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QObjectPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QObject*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QObject* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_QtCoreTypes[SBK_QOBJECT_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QObjectPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(SbkPySide6_QtCoreTypes[SBK_QOBJECT_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QObjectPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QByteArray>'.
static PyObject *_QList_QByteArray__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QByteArray> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypes[SBK_QBYTEARRAY_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QByteArray_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QByteArray> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QByteArray cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypes[SBK_QBYTEARRAY_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QByteArray__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypes[SBK_QBYTEARRAY_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QByteArray_;
    return {};
}

// C++ to Python conversion for container type 'QList<QDockWidget*>'.
static PyObject *_QList_QDockWidgetPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QDockWidget*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(SbkPySide6_QtWidgetsTypes[SBK_QDOCKWIDGET_IDX], cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QDockWidgetPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QDockWidget*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QDockWidget* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_QtWidgetsTypes[SBK_QDOCKWIDGET_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QDockWidgetPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(SbkPySide6_QtWidgetsTypes[SBK_QDOCKWIDGET_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QDockWidgetPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QKeyCombination>'.
static PyObject *_QList_QKeyCombination__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QKeyCombination> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypes[SBK_QKEYCOMBINATION_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QKeyCombination_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QKeyCombination> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QKeyCombination cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypes[SBK_QKEYCOMBINATION_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QKeyCombination__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypes[SBK_QKEYCOMBINATION_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QKeyCombination_;
    return {};
}

// C++ to Python conversion for container type 'QList<QWidget*>'.
static PyObject *_QList_QWidgetPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QWidget*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(SbkPySide6_QtWidgetsTypes[SBK_QWIDGET_IDX], cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QWidgetPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QWidget*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QWidget* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_QtWidgetsTypes[SBK_QWIDGET_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QWidgetPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(SbkPySide6_QtWidgetsTypes[SBK_QWIDGET_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QWidgetPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QTextEdit::ExtraSelection>'.
static PyObject *_QList_QTextEdit_ExtraSelection__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QTextEdit::ExtraSelection> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtWidgetsTypes[SBK_QTEXTEDIT_EXTRASELECTION_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QTextEdit_ExtraSelection_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QTextEdit::ExtraSelection> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QTextEdit::ExtraSelection cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtWidgetsTypes[SBK_QTEXTEDIT_EXTRASELECTION_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QTextEdit_ExtraSelection__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtWidgetsTypes[SBK_QTEXTEDIT_EXTRASELECTION_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QTextEdit_ExtraSelection_;
    return {};
}

// C++ to Python conversion for container type 'QList<QMdiSubWindow*>'.
static PyObject *_QList_QMdiSubWindowPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QMdiSubWindow*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(SbkPySide6_QtWidgetsTypes[SBK_QMDISUBWINDOW_IDX], cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QMdiSubWindowPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QMdiSubWindow*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QMdiSubWindow* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_QtWidgetsTypes[SBK_QMDISUBWINDOW_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QMdiSubWindowPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(SbkPySide6_QtWidgetsTypes[SBK_QMDISUBWINDOW_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QMdiSubWindowPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QModelIndex>'.
static PyObject *_QList_QModelIndex__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QModelIndex> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypes[SBK_QMODELINDEX_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QModelIndex_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QModelIndex> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QModelIndex cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypes[SBK_QMODELINDEX_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QModelIndex__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypes[SBK_QMODELINDEX_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QModelIndex_;
    return {};
}

// C++ to Python conversion for container type 'QList<QTableWidgetItem*>'.
static PyObject *_QList_QTableWidgetItemPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QTableWidgetItem*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(SbkPySide6_QtWidgetsTypes[SBK_QTABLEWIDGETITEM_IDX], cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QTableWidgetItemPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QTableWidgetItem*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QTableWidgetItem* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_QtWidgetsTypes[SBK_QTABLEWIDGETITEM_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QTableWidgetItemPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(SbkPySide6_QtWidgetsTypes[SBK_QTABLEWIDGETITEM_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QTableWidgetItemPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QTableWidgetSelectionRange>'.
static PyObject *_QList_QTableWidgetSelectionRange__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QTableWidgetSelectionRange> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtWidgetsTypes[SBK_QTABLEWIDGETSELECTIONRANGE_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QTableWidgetSelectionRange_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QTableWidgetSelectionRange> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QTableWidgetSelectionRange cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtWidgetsTypes[SBK_QTABLEWIDGETSELECTIONRANGE_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QTableWidgetSelectionRange__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtWidgetsTypes[SBK_QTABLEWIDGETSELECTIONRANGE_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QTableWidgetSelectionRange_;
    return {};
}

// C++ to Python conversion for container type 'QList<QListWidgetItem*>'.
static PyObject *_QList_QListWidgetItemPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QListWidgetItem*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(SbkPySide6_QtWidgetsTypes[SBK_QLISTWIDGETITEM_IDX], cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QListWidgetItemPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QListWidgetItem*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QListWidgetItem* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_QtWidgetsTypes[SBK_QLISTWIDGETITEM_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QListWidgetItemPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(SbkPySide6_QtWidgetsTypes[SBK_QLISTWIDGETITEM_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QListWidgetItemPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QAbstractButton*>'.
static PyObject *_QList_QAbstractButtonPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QAbstractButton*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(SbkPySide6_QtWidgetsTypes[SBK_QABSTRACTBUTTON_IDX], cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QAbstractButtonPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QAbstractButton*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QAbstractButton* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_QtWidgetsTypes[SBK_QABSTRACTBUTTON_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QAbstractButtonPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(SbkPySide6_QtWidgetsTypes[SBK_QABSTRACTBUTTON_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QAbstractButtonPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QWizard::WizardButton>'.
static PyObject *_QList_QWizard_WizardButton__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QWizard::WizardButton> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtWidgetsTypes[SBK_QWIZARD_WIZARDBUTTON_IDX]))->converter, &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QWizard_WizardButton_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QWizard::WizardButton> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QWizard::WizardButton cppItem{QWizard::BackButton};
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtWidgetsTypes[SBK_QWIZARD_WIZARDBUTTON_IDX]))->converter, pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QWizard_WizardButton__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(PepType_SETP(reinterpret_cast<SbkEnumType *>(SbkPySide6_QtWidgetsTypes[SBK_QWIZARD_WIZARDBUTTON_IDX]))->converter, pyIn))
        return PySequence_PythonToCpp__QList_QWizard_WizardButton_;
    return {};
}

// C++ to Python conversion for container type 'QMap<QDate,QTextCharFormat>'.
static PyObject *_QMap_QDate_QTextCharFormat__CppToPython_PyDict(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QMap<QDate,QTextCharFormat> *>(cppIn);
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - START
    PyObject *pyOut = PyDict_New();
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it) {
        const auto &key = it.key();
        const auto &value = it.value();
        PyObject *pyKey = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypes[SBK_QDATE_IDX], &key);
        PyObject *pyValue = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypes[SBK_QTEXTCHARFORMAT_IDX], &value);
        PyDict_SetItem(pyOut, pyKey, pyValue);
        Py_DECREF(pyKey);
        Py_DECREF(pyValue);
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - END

}
static void PyDict_PythonToCpp__QMap_QDate_QTextCharFormat_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QMap<QDate,QTextCharFormat> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - START
    PyObject *key;
    PyObject *value;
    cppOutRef.clear();
    Py_ssize_t pos = 0;
    while (PyDict_Next(pyIn, &pos, &key, &value)) {
        ::QDate cppKey;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypes[SBK_QDATE_IDX], key, &(cppKey));
        ::QTextCharFormat cppValue;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtGuiTypes[SBK_QTEXTCHARFORMAT_IDX], value, &(cppValue));
        cppOutRef.insert(cppKey, cppValue);
    }
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - END

}
static PythonToCppFunc is_PyDict_PythonToCpp__QMap_QDate_QTextCharFormat__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleDictTypes(PepType_SOTP(reinterpret_cast<PyTypeObject *>(SbkPySide6_QtCoreTypes[SBK_QDATE_IDX]))->converter, false, PepType_SOTP(reinterpret_cast<PyTypeObject *>(SbkPySide6_QtGuiTypes[SBK_QTEXTCHARFORMAT_IDX]))->converter, false, pyIn))
        return PyDict_PythonToCpp__QMap_QDate_QTextCharFormat_;
    return {};
}

// C++ to Python conversion for container type 'QList<QScroller*>'.
static PyObject *_QList_QScrollerPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QScroller*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(SbkPySide6_QtWidgetsTypes[SBK_QSCROLLER_IDX], cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QScrollerPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QScroller*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QScroller* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_QtWidgetsTypes[SBK_QSCROLLER_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QScrollerPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(SbkPySide6_QtWidgetsTypes[SBK_QSCROLLER_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QScrollerPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<qreal>'.
static PyObject *_QList_qreal__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<qreal> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_qreal_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<qreal> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        qreal cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_qreal__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), pyIn))
        return PySequence_PythonToCpp__QList_qreal_;
    return {};
}

// C++ to Python conversion for container type 'QList<QGraphicsView*>'.
static PyObject *_QList_QGraphicsViewPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QGraphicsView*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(SbkPySide6_QtWidgetsTypes[SBK_QGRAPHICSVIEW_IDX], cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QGraphicsViewPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QGraphicsView*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QGraphicsView* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_QtWidgetsTypes[SBK_QGRAPHICSVIEW_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QGraphicsViewPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(SbkPySide6_QtWidgetsTypes[SBK_QGRAPHICSVIEW_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QGraphicsViewPTR_;
    return {};
}

// C++ to Python conversion for container type 'std::pair<qreal,QPointF>'.
static PyObject *std_pair_qreal_QPointF__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::std::pair<qreal,QPointF> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - START
    PyObject *pyOut = PyTuple_New(2);
    PyTuple_SET_ITEM(pyOut, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppInRef.first));
    PyTuple_SET_ITEM(pyOut, 1, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypes[SBK_QPOINTF_IDX], &cppInRef.second));
    return pyOut;
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - END

}
static void PySequence_PythonToCpp_std_pair_qreal_QPointF_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::std::pair<qreal,QPointF> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - START
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), PySequence_Fast_GET_ITEM(pyIn, 0), &(cppOutRef.first));
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypes[SBK_QPOINTF_IDX], PySequence_Fast_GET_ITEM(pyIn, 1), &(cppOutRef.second));
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_std_pair_qreal_QPointF__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertiblePairTypes(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), false, PepType_SOTP(reinterpret_cast<PyTypeObject *>(SbkPySide6_QtCoreTypes[SBK_QPOINTF_IDX]))->converter, false, pyIn))
        return PySequence_PythonToCpp_std_pair_qreal_QPointF_;
    return {};
}

// C++ to Python conversion for container type 'QList<std::pair< qreal,QPointF>>'.
static PyObject *_QList_std_pair_qreal_QPointF___CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<std::pair< qreal,QPointF>> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_STD_PAIR_QREAL_QPOINTF_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_std_pair_qreal_QPointF__(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<std::pair< qreal,QPointF>> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::std::pair<qreal,QPointF> cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_STD_PAIR_QREAL_QPOINTF_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_std_pair_qreal_QPointF___Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_STD_PAIR_QREAL_QPOINTF_IDX], pyIn))
        return PySequence_PythonToCpp__QList_std_pair_qreal_QPointF__;
    return {};
}

// C++ to Python conversion for container type 'std::pair<qreal,qreal>'.
static PyObject *std_pair_qreal_qreal__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::std::pair<qreal,qreal> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - START
    PyObject *pyOut = PyTuple_New(2);
    PyTuple_SET_ITEM(pyOut, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppInRef.first));
    PyTuple_SET_ITEM(pyOut, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppInRef.second));
    return pyOut;
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - END

}
static void PySequence_PythonToCpp_std_pair_qreal_qreal_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::std::pair<qreal,qreal> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - START
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), PySequence_Fast_GET_ITEM(pyIn, 0), &(cppOutRef.first));
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), PySequence_Fast_GET_ITEM(pyIn, 1), &(cppOutRef.second));
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_std_pair_qreal_qreal__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertiblePairTypes(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), false, Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), false, pyIn))
        return PySequence_PythonToCpp_std_pair_qreal_qreal_;
    return {};
}

// C++ to Python conversion for container type 'QList<std::pair< qreal,qreal>>'.
static PyObject *_QList_std_pair_qreal_qreal___CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<std::pair< qreal,qreal>> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_STD_PAIR_QREAL_QREAL_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_std_pair_qreal_qreal__(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<std::pair< qreal,qreal>> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::std::pair<qreal,qreal> cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_STD_PAIR_QREAL_QREAL_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_std_pair_qreal_qreal___Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_STD_PAIR_QREAL_QREAL_IDX], pyIn))
        return PySequence_PythonToCpp__QList_std_pair_qreal_qreal__;
    return {};
}

// C++ to Python conversion for container type 'QList<QKeySequence>'.
static PyObject *_QList_QKeySequence__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QKeySequence> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypes[SBK_QKEYSEQUENCE_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QKeySequence_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QKeySequence> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QKeySequence cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtGuiTypes[SBK_QKEYSEQUENCE_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QKeySequence__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtGuiTypes[SBK_QKEYSEQUENCE_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QKeySequence_;
    return {};
}

// C++ to Python conversion for container type 'QList<QGesture*>'.
static PyObject *_QList_QGesturePTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QGesture*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(SbkPySide6_QtWidgetsTypes[SBK_QGESTURE_IDX], cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QGesturePTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QGesture*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QGesture* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_QtWidgetsTypes[SBK_QGESTURE_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QGesturePTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(SbkPySide6_QtWidgetsTypes[SBK_QGESTURE_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QGesturePTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QWindow*>'.
static PyObject *_QList_QWindowPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QWindow*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(SbkPySide6_QtGuiTypes[SBK_QWINDOW_IDX], cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QWindowPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QWindow*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QWindow* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_QtGuiTypes[SBK_QWINDOW_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QWindowPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(SbkPySide6_QtGuiTypes[SBK_QWINDOW_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QWindowPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QScreen*>'.
static PyObject *_QList_QScreenPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QScreen*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(SbkPySide6_QtGuiTypes[SBK_QSCREEN_IDX], cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QScreenPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QScreen*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QScreen* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_QtGuiTypes[SBK_QSCREEN_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QScreenPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(SbkPySide6_QtGuiTypes[SBK_QSCREEN_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QScreenPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QUrl>'.
static PyObject *_QList_QUrl__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QUrl> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypes[SBK_QURL_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QUrl_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QUrl> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QUrl cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypes[SBK_QURL_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QUrl__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypes[SBK_QURL_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QUrl_;
    return {};
}

// C++ to Python conversion for container type 'QMap<int,QVariant>'.
static PyObject *_QMap_int_QVariant__CppToPython_PyDict(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QMap<int,QVariant> *>(cppIn);
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - START
    PyObject *pyOut = PyDict_New();
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it) {
        const auto &key = it.key();
        const auto &value = it.value();
        PyObject *pyKey = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &key);
        PyObject *pyValue = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVARIANT_IDX], &value);
        PyDict_SetItem(pyOut, pyKey, pyValue);
        Py_DECREF(pyKey);
        Py_DECREF(pyValue);
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - END

}
static void PyDict_PythonToCpp__QMap_int_QVariant_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QMap<int,QVariant> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - START
    PyObject *key;
    PyObject *value;
    cppOutRef.clear();
    Py_ssize_t pos = 0;
    while (PyDict_Next(pyIn, &pos, &key, &value)) {
        int cppKey;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<int>(), key, &(cppKey));
        ::QVariant cppValue;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QVARIANT_IDX], value, &(cppValue));
        cppOutRef.insert(cppKey, cppValue);
    }
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - END

}
static PythonToCppFunc is_PyDict_PythonToCpp__QMap_int_QVariant__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleDictTypes(Shiboken::Conversions::PrimitiveTypeConverter<int>(), false, SbkPySide6_QtCoreTypeConverters[SBK_QVARIANT_IDX], false, pyIn))
        return PyDict_PythonToCpp__QMap_int_QVariant_;
    return {};
}

// C++ to Python conversion for container type 'QHash<int,QByteArray>'.
static PyObject *_QHash_int_QByteArray__CppToPython_PyDict(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QHash<int,QByteArray> *>(cppIn);
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - START
    PyObject *pyOut = PyDict_New();
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it) {
        const auto &key = it.key();
        const auto &value = it.value();
        PyObject *pyKey = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &key);
        PyObject *pyValue = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypes[SBK_QBYTEARRAY_IDX], &value);
        PyDict_SetItem(pyOut, pyKey, pyValue);
        Py_DECREF(pyKey);
        Py_DECREF(pyValue);
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - END

}
static void PyDict_PythonToCpp__QHash_int_QByteArray_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QHash<int,QByteArray> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - START
    PyObject *key;
    PyObject *value;
    cppOutRef.clear();
    Py_ssize_t pos = 0;
    while (PyDict_Next(pyIn, &pos, &key, &value)) {
        int cppKey;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<int>(), key, &(cppKey));
        ::QByteArray cppValue;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypes[SBK_QBYTEARRAY_IDX], value, &(cppValue));
        cppOutRef.insert(cppKey, cppValue);
    }
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - END

}
static PythonToCppFunc is_PyDict_PythonToCpp__QHash_int_QByteArray__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleDictTypes(Shiboken::Conversions::PrimitiveTypeConverter<int>(), false, PepType_SOTP(reinterpret_cast<PyTypeObject *>(SbkPySide6_QtCoreTypes[SBK_QBYTEARRAY_IDX]))->converter, false, pyIn))
        return PyDict_PythonToCpp__QHash_int_QByteArray_;
    return {};
}

// C++ to Python conversion for container type 'QList<QVariant>'.
static PyObject *_QList_QVariant__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QVariant> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVARIANT_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QVariant_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QVariant> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QVariant cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QVARIANT_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QVariant__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypeConverters[SBK_QVARIANT_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QVariant_;
    return {};
}

// C++ to Python conversion for container type 'QList<QString>'.
static PyObject *_QList_QString__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QString> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QSTRING_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QString_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QString> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QString cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QSTRING_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QString__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypeConverters[SBK_QSTRING_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QString_;
    return {};
}

// C++ to Python conversion for container type 'QMap<QString,QVariant>'.
static PyObject *_QMap_QString_QVariant__CppToPython_PyDict(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QMap<QString,QVariant> *>(cppIn);
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - START
    PyObject *pyOut = PyDict_New();
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it) {
        const auto &key = it.key();
        const auto &value = it.value();
        PyObject *pyKey = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QSTRING_IDX], &key);
        PyObject *pyValue = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVARIANT_IDX], &value);
        PyDict_SetItem(pyOut, pyKey, pyValue);
        Py_DECREF(pyKey);
        Py_DECREF(pyValue);
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - END

}
static void PyDict_PythonToCpp__QMap_QString_QVariant_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QMap<QString,QVariant> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - START
    PyObject *key;
    PyObject *value;
    cppOutRef.clear();
    Py_ssize_t pos = 0;
    while (PyDict_Next(pyIn, &pos, &key, &value)) {
        ::QString cppKey;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QSTRING_IDX], key, &(cppKey));
        ::QVariant cppValue;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QVARIANT_IDX], value, &(cppValue));
        cppOutRef.insert(cppKey, cppValue);
    }
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - END

}
static PythonToCppFunc is_PyDict_PythonToCpp__QMap_QString_QVariant__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleDictTypes(SbkPySide6_QtCoreTypeConverters[SBK_QSTRING_IDX], false, SbkPySide6_QtCoreTypeConverters[SBK_QVARIANT_IDX], false, pyIn))
        return PyDict_PythonToCpp__QMap_QString_QVariant_;
    return {};
}


static struct PyModuleDef moduledef = {
    /* m_base     */ PyModuleDef_HEAD_INIT,
    /* m_name     */ "QtWidgets",
    /* m_doc      */ nullptr,
    /* m_size     */ -1,
    /* m_methods  */ QtWidgets_methods,
    /* m_reload   */ nullptr,
    /* m_traverse */ nullptr,
    /* m_clear    */ nullptr,
    /* m_free     */ nullptr
};

// The signatures string for the global functions.
// Multiple signatures have their index "n:" in front.
static const char *QtWidgets_SignatureStrings[] = {
    "1:PySide6.QtWidgets.qDrawPlainRect(p:PySide6.QtGui.QPainter,x:int,y:int,w:int,h:int,arg__6:typing.Union[PySide6.QtGui.QColor, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int],lineWidth:int=1,fill:typing.Union[PySide6.QtGui.QBrush, PySide6.QtCore.Qt.BrushStyle, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor, PySide6.QtGui.QGradient, PySide6.QtGui.QImage, PySide6.QtGui.QPixmap]=nullptr)",
    "0:PySide6.QtWidgets.qDrawPlainRect(p:PySide6.QtGui.QPainter,r:PySide6.QtCore.QRect,arg__3:typing.Union[PySide6.QtGui.QColor, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int],lineWidth:int=1,fill:typing.Union[PySide6.QtGui.QBrush, PySide6.QtCore.Qt.BrushStyle, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor, PySide6.QtGui.QGradient, PySide6.QtGui.QImage, PySide6.QtGui.QPixmap]=nullptr)",
    "1:PySide6.QtWidgets.qDrawShadeLine(p:PySide6.QtGui.QPainter,x1:int,y1:int,x2:int,y2:int,pal:typing.Union[PySide6.QtGui.QPalette, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor],sunken:bool=true,lineWidth:int=1,midLineWidth:int=0)",
    "0:PySide6.QtWidgets.qDrawShadeLine(p:PySide6.QtGui.QPainter,p1:PySide6.QtCore.QPoint,p2:PySide6.QtCore.QPoint,pal:typing.Union[PySide6.QtGui.QPalette, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor],sunken:bool=true,lineWidth:int=1,midLineWidth:int=0)",
    "1:PySide6.QtWidgets.qDrawShadePanel(p:PySide6.QtGui.QPainter,x:int,y:int,w:int,h:int,pal:typing.Union[PySide6.QtGui.QPalette, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor],sunken:bool=false,lineWidth:int=1,fill:typing.Union[PySide6.QtGui.QBrush, PySide6.QtCore.Qt.BrushStyle, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor, PySide6.QtGui.QGradient, PySide6.QtGui.QImage, PySide6.QtGui.QPixmap]=nullptr)",
    "0:PySide6.QtWidgets.qDrawShadePanel(p:PySide6.QtGui.QPainter,r:PySide6.QtCore.QRect,pal:typing.Union[PySide6.QtGui.QPalette, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor],sunken:bool=false,lineWidth:int=1,fill:typing.Union[PySide6.QtGui.QBrush, PySide6.QtCore.Qt.BrushStyle, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor, PySide6.QtGui.QGradient, PySide6.QtGui.QImage, PySide6.QtGui.QPixmap]=nullptr)",
    "1:PySide6.QtWidgets.qDrawShadeRect(p:PySide6.QtGui.QPainter,x:int,y:int,w:int,h:int,pal:typing.Union[PySide6.QtGui.QPalette, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor],sunken:bool=false,lineWidth:int=1,midLineWidth:int=0,fill:typing.Union[PySide6.QtGui.QBrush, PySide6.QtCore.Qt.BrushStyle, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor, PySide6.QtGui.QGradient, PySide6.QtGui.QImage, PySide6.QtGui.QPixmap]=nullptr)",
    "0:PySide6.QtWidgets.qDrawShadeRect(p:PySide6.QtGui.QPainter,r:PySide6.QtCore.QRect,pal:typing.Union[PySide6.QtGui.QPalette, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor],sunken:bool=false,lineWidth:int=1,midLineWidth:int=0,fill:typing.Union[PySide6.QtGui.QBrush, PySide6.QtCore.Qt.BrushStyle, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor, PySide6.QtGui.QGradient, PySide6.QtGui.QImage, PySide6.QtGui.QPixmap]=nullptr)",
    "1:PySide6.QtWidgets.qDrawWinButton(p:PySide6.QtGui.QPainter,x:int,y:int,w:int,h:int,pal:typing.Union[PySide6.QtGui.QPalette, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor],sunken:bool=false,fill:typing.Union[PySide6.QtGui.QBrush, PySide6.QtCore.Qt.BrushStyle, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor, PySide6.QtGui.QGradient, PySide6.QtGui.QImage, PySide6.QtGui.QPixmap]=nullptr)",
    "0:PySide6.QtWidgets.qDrawWinButton(p:PySide6.QtGui.QPainter,r:PySide6.QtCore.QRect,pal:typing.Union[PySide6.QtGui.QPalette, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor],sunken:bool=false,fill:typing.Union[PySide6.QtGui.QBrush, PySide6.QtCore.Qt.BrushStyle, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor, PySide6.QtGui.QGradient, PySide6.QtGui.QImage, PySide6.QtGui.QPixmap]=nullptr)",
    "1:PySide6.QtWidgets.qDrawWinPanel(p:PySide6.QtGui.QPainter,x:int,y:int,w:int,h:int,pal:typing.Union[PySide6.QtGui.QPalette, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor],sunken:bool=false,fill:typing.Union[PySide6.QtGui.QBrush, PySide6.QtCore.Qt.BrushStyle, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor, PySide6.QtGui.QGradient, PySide6.QtGui.QImage, PySide6.QtGui.QPixmap]=nullptr)",
    "0:PySide6.QtWidgets.qDrawWinPanel(p:PySide6.QtGui.QPainter,r:PySide6.QtCore.QRect,pal:typing.Union[PySide6.QtGui.QPalette, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor],sunken:bool=false,fill:typing.Union[PySide6.QtGui.QBrush, PySide6.QtCore.Qt.BrushStyle, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor, PySide6.QtGui.QGradient, PySide6.QtGui.QImage, PySide6.QtGui.QPixmap]=nullptr)",
    nullptr}; // Sentinel

extern "C" LIBSHIBOKEN_EXPORT PyObject *PyInit_QtWidgets()
{
    if (SbkPySide6_QtWidgetsModuleObject != nullptr)
        return SbkPySide6_QtWidgetsModuleObject;
    {
        Shiboken::AutoDecRef requiredModule(Shiboken::Module::import("PySide6.QtGui"));
        if (requiredModule.isNull())
            return nullptr;
        SbkPySide6_QtGuiTypes = Shiboken::Module::getTypes(requiredModule);
        SbkPySide6_QtGuiTypeConverters = Shiboken::Module::getTypeConverters(requiredModule);
    }

    {
        Shiboken::AutoDecRef requiredModule(Shiboken::Module::import("PySide6.QtCore"));
        if (requiredModule.isNull())
            return nullptr;
        SbkPySide6_QtCoreTypes = Shiboken::Module::getTypes(requiredModule);
        SbkPySide6_QtCoreTypeConverters = Shiboken::Module::getTypeConverters(requiredModule);
    }

    // Create an array of wrapper types for the current module.
    static PyTypeObject *cppApi[SBK_QtWidgets_IDX_COUNT];
    SbkPySide6_QtWidgetsTypes = cppApi;

    // Create an array of primitive type converters for the current module.
    static SbkConverter *sbkConverters[SBK_QtWidgets_CONVERTERS_IDX_COUNT];
    SbkPySide6_QtWidgetsTypeConverters = sbkConverters;

    PyObject *module = Shiboken::Module::create("QtWidgets", &moduledef);

    // Make module available from global scope
    SbkPySide6_QtWidgetsModuleObject = module;

    // Initialize classes in the type system
    init_QWhatsThis(module);
    init_QTreeWidgetItemIterator(module);
    init_QTreeWidgetItem(module);
    init_QTableWidgetSelectionRange(module);
    init_QTableWidgetItem(module);
    init_QStyleHintReturn(module);
    init_QStyleHintReturnVariant(module);
    init_QStyleFactory(module);
    init_QSizePolicy(module);
    init_QScrollerProperties(module);
    init_QListWidgetItem(module);
    init_QLayoutItem(module);
    init_QSpacerItem(module);
    init_QItemEditorFactory(module);
    init_QItemEditorCreatorBase(module);
    init_QGestureRecognizer(module);
    init_QColormap(module);
    init_QStyleHintReturnMask(module);
    init_QAccessibleWidget(module);
    init_QFileIconProvider(module);
    init_QTileRules(module);
    init_QGraphicsLayoutItem(module);
    init_QGraphicsLayout(module);
    init_QGraphicsLinearLayout(module);
    init_QGraphicsGridLayout(module);
    init_QGraphicsAnchorLayout(module);
    init_QGraphicsItem(module);
    init_QGraphicsPixmapItem(module);
    init_QGraphicsLineItem(module);
    init_QGraphicsItemGroup(module);
    init_QAbstractGraphicsShapeItem(module);
    init_QGraphicsSimpleTextItem(module);
    init_QGraphicsRectItem(module);
    init_QGraphicsPolygonItem(module);
    init_QGraphicsPathItem(module);
    init_QGraphicsEllipseItem(module);
    init_QToolTip(module);
    init_QStylePainter(module);
    init_QWidget(module);
    init_QWizardPage(module);
    init_QWidgetItem(module);
    init_QToolBar(module);
    init_QTabWidget(module);
    init_QTabBar(module);
    init_QStatusBar(module);
    init_QSplitterHandle(module);
    init_QSplashScreen(module);
    init_QSizeGrip(module);
    init_QRubberBand(module);
    init_QProgressBar(module);
    init_QMenuBar(module);
    init_QMenu(module);
    init_QMdiSubWindow(module);
    init_QMainWindow(module);
    init_QLineEdit(module);
    init_QKeySequenceEdit(module);
    init_QGroupBox(module);
    init_QFrame(module);
    init_QToolBox(module);
    init_QStackedWidget(module);
    init_QSplitter(module);
    init_QLabel(module);
    init_QLCDNumber(module);
    init_QAbstractScrollArea(module);
    init_QTextEdit(module);
    init_QTextEdit_ExtraSelection(reinterpret_cast<PyObject *>(SbkPySide6_QtWidgetsTypes[SBK_QTEXTEDIT_IDX]));
    init_QTextBrowser(module);
    init_QScrollArea(module);
    init_QPlainTextEdit(module);
    init_QMdiArea(module);
    init_QGraphicsView(module);
    init_QAbstractItemView(module);
    init_QTreeView(module);
    init_QTreeWidget(module);
    init_QTableView(module);
    init_QTableWidget(module);
    init_QListView(module);
    init_QUndoView(module);
    init_QListWidget(module);
    init_QHeaderView(module);
    init_QColumnView(module);
    init_QFocusFrame(module);
    init_QDockWidget(module);
    init_QDialogButtonBox(module);
    init_QDialog(module);
    init_QWizard(module);
    init_QProgressDialog(module);
    init_QMessageBox(module);
    init_QInputDialog(module);
    init_QFontDialog(module);
    init_QErrorMessage(module);
    init_QColorDialog(module);
    init_QComboBox(module);
    init_QFontComboBox(module);
    init_QCalendarWidget(module);
    init_QAbstractSpinBox(module);
    init_QSpinBox(module);
    init_QDoubleSpinBox(module);
    init_QDateTimeEdit(module);
    init_QTimeEdit(module);
    init_QDateEdit(module);
    init_QAbstractSlider(module);
    init_QSlider(module);
    init_QScrollBar(module);
    init_QDial(module);
    init_QAbstractButton(module);
    init_QToolButton(module);
    init_QRadioButton(module);
    init_QPushButton(module);
    init_QCommandLinkButton(module);
    init_QCheckBox(module);
    init_QSystemTrayIcon(module);
    init_QStyleOption(module);
    init_QStyleOptionViewItem(module);
    init_QStyleOptionToolBox(module);
    init_QStyleOptionToolBar(module);
    init_QStyleOptionTabWidgetFrame(module);
    init_QStyleOptionTabBarBase(module);
    init_QStyleOptionTab(module);
    init_QStyleOptionRubberBand(module);
    init_QStyleOptionProgressBar(module);
    init_QStyleOptionMenuItem(module);
    init_QStyleOptionHeader(module);
    init_QStyleOptionHeaderV2(module);
    init_QStyleOptionGraphicsItem(module);
    init_QStyleOptionFrame(module);
    init_QStyleOptionFocusRect(module);
    init_QStyleOptionDockWidget(module);
    init_QStyleOptionComplex(module);
    init_QStyleOptionToolButton(module);
    init_QStyleOptionTitleBar(module);
    init_QStyleOptionSpinBox(module);
    init_QStyleOptionSlider(module);
    init_QStyleOptionSizeGrip(module);
    init_QStyleOptionGroupBox(module);
    init_QStyleOptionComboBox(module);
    init_QStyleOptionButton(module);
    init_QStyle(module);
    init_QCommonStyle(module);
    init_QProxyStyle(module);
    init_QScroller(module);
    init_QLayout(module);
    init_QStackedLayout(module);
    init_QGridLayout(module);
    init_QFormLayout(module);
    init_QFormLayout_TakeRowResult(reinterpret_cast<PyObject *>(SbkPySide6_QtWidgetsTypes[SBK_QFORMLAYOUT_IDX]));
    init_QBoxLayout(module);
    init_QVBoxLayout(module);
    init_QHBoxLayout(module);
    init_QGraphicsTransform(module);
    init_QGraphicsScale(module);
    init_QGraphicsRotation(module);
    init_QGraphicsScene(module);
    init_QGraphicsObject(module);
    init_QGraphicsWidget(module);
    init_QGraphicsProxyWidget(module);
    init_QGraphicsTextItem(module);
    init_QGraphicsItemAnimation(module);
    init_QGraphicsEffect(module);
    init_QGraphicsOpacityEffect(module);
    init_QGraphicsDropShadowEffect(module);
    init_QGraphicsColorizeEffect(module);
    init_QGraphicsBlurEffect(module);
    init_QGraphicsAnchor(module);
    init_QGesture(module);
    init_QTapGesture(module);
    init_QTapAndHoldGesture(module);
    init_QSwipeGesture(module);
    init_QPinchGesture(module);
    init_QPanGesture(module);
    init_QDataWidgetMapper(module);
    init_QCompleter(module);
    init_QButtonGroup(module);
    init_QAbstractItemDelegate(module);
    init_QStyledItemDelegate(module);
    init_QItemDelegate(module);
    init_QWidgetAction(module);
    init_QPlainTextDocumentLayout(module);
    init_QGraphicsSceneEvent(module);
    init_QGraphicsSceneWheelEvent(module);
    init_QGraphicsSceneResizeEvent(module);
    init_QGraphicsSceneMoveEvent(module);
    init_QGraphicsSceneMouseEvent(module);
    init_QGraphicsSceneHoverEvent(module);
    init_QGraphicsSceneHelpEvent(module);
    init_QGraphicsSceneDragDropEvent(module);
    init_QGraphicsSceneContextMenuEvent(module);
    init_QGestureEvent(module);
    init_QApplication(module);
    init_QFileDialog(module);
    init_QFileSystemModel(module);

    // Register converter for type 'QList<int>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_INT_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_int__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_INT_IDX], "QList<int>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_INT_IDX],
        PySequence_PythonToCpp__QList_int_,
        is_PySequence_PythonToCpp__QList_int__Convertible);
    Shiboken::Conversions::setPythonToCppPointerFunctions(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_INT_IDX],
        PythonToCppQIntList,
        isQIntListPythonToCppConvertible);

    // Register converter for type 'QList<QTreeWidgetItem*>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QTREEWIDGETITEMPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QTreeWidgetItemPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QTREEWIDGETITEMPTR_IDX], "QList<QTreeWidgetItem*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QTREEWIDGETITEMPTR_IDX],
        PySequence_PythonToCpp__QList_QTreeWidgetItemPTR_,
        is_PySequence_PythonToCpp__QList_QTreeWidgetItemPTR__Convertible);

    // Register converter for type 'QList<QColor>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QCOLOR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QColor__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QCOLOR_IDX], "QList<QColor>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QCOLOR_IDX],
        PySequence_PythonToCpp__QList_QColor_,
        is_PySequence_PythonToCpp__QList_QColor__Convertible);

    // Register converter for type 'std::pair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag>>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_STD_PAIR_QACCESSIBLEINTERFACEPTR_QFLAGS_QACCESSIBLE_RELATIONFLAG_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag___CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_STD_PAIR_QACCESSIBLEINTERFACEPTR_QFLAGS_QACCESSIBLE_RELATIONFLAG_IDX], "std::pair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag>>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_STD_PAIR_QACCESSIBLEINTERFACEPTR_QFLAGS_QACCESSIBLE_RELATIONFLAG_IDX],
        PySequence_PythonToCpp_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag__,
        is_PySequence_PythonToCpp_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag___Convertible);

    // Register converter for type 'QList<std::pair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag>>>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_STD_PAIR_QACCESSIBLEINTERFACEPTR_QFLAGS_QACCESSIBLE_RELATIONFLAG_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag____CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_STD_PAIR_QACCESSIBLEINTERFACEPTR_QFLAGS_QACCESSIBLE_RELATIONFLAG_IDX], "QList<std::pair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag>>>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_STD_PAIR_QACCESSIBLEINTERFACEPTR_QFLAGS_QACCESSIBLE_RELATIONFLAG_IDX],
        PySequence_PythonToCpp__QList_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag___,
        is_PySequence_PythonToCpp__QList_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag____Convertible);

    // Register converter for type 'QList<QGraphicsItem*>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QGRAPHICSITEMPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QGraphicsItemPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QGRAPHICSITEMPTR_IDX], "QList<QGraphicsItem*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QGRAPHICSITEMPTR_IDX],
        PySequence_PythonToCpp__QList_QGraphicsItemPTR_,
        is_PySequence_PythonToCpp__QList_QGraphicsItemPTR__Convertible);

    // Register converter for type 'QList<QGraphicsTransform*>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QGRAPHICSTRANSFORMPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QGraphicsTransformPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QGRAPHICSTRANSFORMPTR_IDX], "QList<QGraphicsTransform*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QGRAPHICSTRANSFORMPTR_IDX],
        PySequence_PythonToCpp__QList_QGraphicsTransformPTR_,
        is_PySequence_PythonToCpp__QList_QGraphicsTransformPTR__Convertible);

    // Register converter for type 'QList<QLine>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QLINE_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QLine__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QLINE_IDX], "QList<QLine>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QLINE_IDX],
        PySequence_PythonToCpp__QList_QLine_,
        is_PySequence_PythonToCpp__QList_QLine__Convertible);

    // Register converter for type 'QList<QLineF>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QLINEF_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QLineF__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QLINEF_IDX], "QList<QLineF>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QLINEF_IDX],
        PySequence_PythonToCpp__QList_QLineF_,
        is_PySequence_PythonToCpp__QList_QLineF__Convertible);

    // Register converter for type 'QList<QPoint>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QPOINT_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QPoint__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QPOINT_IDX], "QList<QPoint>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QPOINT_IDX],
        PySequence_PythonToCpp__QList_QPoint_,
        is_PySequence_PythonToCpp__QList_QPoint__Convertible);
    Shiboken::Conversions::setPythonToCppPointerFunctions(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QPOINT_IDX],
        PythonToCppQPointList,
        isQPointListPythonToCppConvertible);

    // Register converter for type 'QList<QPointF>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QPOINTF_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QPointF__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QPOINTF_IDX], "QList<QPointF>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QPOINTF_IDX],
        PySequence_PythonToCpp__QList_QPointF_,
        is_PySequence_PythonToCpp__QList_QPointF__Convertible);
    Shiboken::Conversions::setPythonToCppPointerFunctions(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QPOINTF_IDX],
        PythonToCppQPointFList,
        isQPointFListPythonToCppConvertible);

    // Register converter for type 'QList<QRect>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QRECT_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QRect__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QRECT_IDX], "QList<QRect>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QRECT_IDX],
        PySequence_PythonToCpp__QList_QRect_,
        is_PySequence_PythonToCpp__QList_QRect__Convertible);

    // Register converter for type 'QList<QRectF>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QRECTF_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QRectF__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QRECTF_IDX], "QList<QRectF>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QRECTF_IDX],
        PySequence_PythonToCpp__QList_QRectF_,
        is_PySequence_PythonToCpp__QList_QRectF__Convertible);

    // Register converter for type 'QList<QAction*>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QACTIONPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QActionPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QACTIONPTR_IDX], "QList<QAction*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QACTIONPTR_IDX],
        PySequence_PythonToCpp__QList_QActionPTR_,
        is_PySequence_PythonToCpp__QList_QActionPTR__Convertible);

    // Register converter for type 'QList<QObject*>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QOBJECTPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QObjectPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QOBJECTPTR_IDX], "QList<QObject*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QOBJECTPTR_IDX],
        PySequence_PythonToCpp__QList_QObjectPTR_,
        is_PySequence_PythonToCpp__QList_QObjectPTR__Convertible);

    // Register converter for type 'QList<QByteArray>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QBYTEARRAY_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QByteArray__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QBYTEARRAY_IDX], "QList<QByteArray>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QBYTEARRAY_IDX],
        PySequence_PythonToCpp__QList_QByteArray_,
        is_PySequence_PythonToCpp__QList_QByteArray__Convertible);

    // Register converter for type 'QList<QDockWidget*>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QDOCKWIDGETPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QDockWidgetPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QDOCKWIDGETPTR_IDX], "QList<QDockWidget*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QDOCKWIDGETPTR_IDX],
        PySequence_PythonToCpp__QList_QDockWidgetPTR_,
        is_PySequence_PythonToCpp__QList_QDockWidgetPTR__Convertible);

    // Register converter for type 'QList<QKeyCombination>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QKEYCOMBINATION_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QKeyCombination__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QKEYCOMBINATION_IDX], "QList<QKeyCombination>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QKEYCOMBINATION_IDX],
        PySequence_PythonToCpp__QList_QKeyCombination_,
        is_PySequence_PythonToCpp__QList_QKeyCombination__Convertible);

    // Register converter for type 'QList<QWidget*>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QWIDGETPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QWidgetPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QWIDGETPTR_IDX], "QList<QWidget*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QWIDGETPTR_IDX],
        PySequence_PythonToCpp__QList_QWidgetPTR_,
        is_PySequence_PythonToCpp__QList_QWidgetPTR__Convertible);

    // Register converter for type 'QList<QTextEdit::ExtraSelection>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QTEXTEDIT_EXTRASELECTION_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QTextEdit_ExtraSelection__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QTEXTEDIT_EXTRASELECTION_IDX], "QList<QTextEdit::ExtraSelection>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QTEXTEDIT_EXTRASELECTION_IDX],
        PySequence_PythonToCpp__QList_QTextEdit_ExtraSelection_,
        is_PySequence_PythonToCpp__QList_QTextEdit_ExtraSelection__Convertible);

    // Register converter for type 'QList<QMdiSubWindow*>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QMDISUBWINDOWPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QMdiSubWindowPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QMDISUBWINDOWPTR_IDX], "QList<QMdiSubWindow*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QMDISUBWINDOWPTR_IDX],
        PySequence_PythonToCpp__QList_QMdiSubWindowPTR_,
        is_PySequence_PythonToCpp__QList_QMdiSubWindowPTR__Convertible);

    // Register converter for type 'QList<QModelIndex>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QMODELINDEX_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QModelIndex__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QMODELINDEX_IDX], "QList<QModelIndex>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QMODELINDEX_IDX],
        PySequence_PythonToCpp__QList_QModelIndex_,
        is_PySequence_PythonToCpp__QList_QModelIndex__Convertible);

    // Register converter for type 'QList<QTableWidgetItem*>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QTABLEWIDGETITEMPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QTableWidgetItemPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QTABLEWIDGETITEMPTR_IDX], "QList<QTableWidgetItem*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QTABLEWIDGETITEMPTR_IDX],
        PySequence_PythonToCpp__QList_QTableWidgetItemPTR_,
        is_PySequence_PythonToCpp__QList_QTableWidgetItemPTR__Convertible);

    // Register converter for type 'QList<QTableWidgetSelectionRange>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QTABLEWIDGETSELECTIONRANGE_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QTableWidgetSelectionRange__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QTABLEWIDGETSELECTIONRANGE_IDX], "QList<QTableWidgetSelectionRange>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QTABLEWIDGETSELECTIONRANGE_IDX],
        PySequence_PythonToCpp__QList_QTableWidgetSelectionRange_,
        is_PySequence_PythonToCpp__QList_QTableWidgetSelectionRange__Convertible);

    // Register converter for type 'QList<QListWidgetItem*>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QLISTWIDGETITEMPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QListWidgetItemPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QLISTWIDGETITEMPTR_IDX], "QList<QListWidgetItem*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QLISTWIDGETITEMPTR_IDX],
        PySequence_PythonToCpp__QList_QListWidgetItemPTR_,
        is_PySequence_PythonToCpp__QList_QListWidgetItemPTR__Convertible);

    // Register converter for type 'QList<QAbstractButton*>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QABSTRACTBUTTONPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QAbstractButtonPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QABSTRACTBUTTONPTR_IDX], "QList<QAbstractButton*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QABSTRACTBUTTONPTR_IDX],
        PySequence_PythonToCpp__QList_QAbstractButtonPTR_,
        is_PySequence_PythonToCpp__QList_QAbstractButtonPTR__Convertible);

    // Register converter for type 'QList<QWizard::WizardButton>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QWIZARD_WIZARDBUTTON_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QWizard_WizardButton__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QWIZARD_WIZARDBUTTON_IDX], "QList<QWizard::WizardButton>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QWIZARD_WIZARDBUTTON_IDX],
        PySequence_PythonToCpp__QList_QWizard_WizardButton_,
        is_PySequence_PythonToCpp__QList_QWizard_WizardButton__Convertible);

    // Register converter for type 'QMap<QDate,QTextCharFormat>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QMAP_QDATE_QTEXTCHARFORMAT_IDX] = Shiboken::Conversions::createConverter(&PyDict_Type, _QMap_QDate_QTextCharFormat__CppToPython_PyDict);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QMAP_QDATE_QTEXTCHARFORMAT_IDX], "QMap<QDate,QTextCharFormat>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QMAP_QDATE_QTEXTCHARFORMAT_IDX],
        PyDict_PythonToCpp__QMap_QDate_QTextCharFormat_,
        is_PyDict_PythonToCpp__QMap_QDate_QTextCharFormat__Convertible);

    // Register converter for type 'QList<QScroller*>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QSCROLLERPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QScrollerPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QSCROLLERPTR_IDX], "QList<QScroller*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QSCROLLERPTR_IDX],
        PySequence_PythonToCpp__QList_QScrollerPTR_,
        is_PySequence_PythonToCpp__QList_QScrollerPTR__Convertible);

    // Register converter for type 'QList<qreal>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QREAL_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_qreal__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QREAL_IDX], "QList<qreal>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QREAL_IDX],
        PySequence_PythonToCpp__QList_qreal_,
        is_PySequence_PythonToCpp__QList_qreal__Convertible);

    // Register converter for type 'QList<QGraphicsView*>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QGRAPHICSVIEWPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QGraphicsViewPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QGRAPHICSVIEWPTR_IDX], "QList<QGraphicsView*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QGRAPHICSVIEWPTR_IDX],
        PySequence_PythonToCpp__QList_QGraphicsViewPTR_,
        is_PySequence_PythonToCpp__QList_QGraphicsViewPTR__Convertible);

    // Register converter for type 'std::pair<qreal,QPointF>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_STD_PAIR_QREAL_QPOINTF_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, std_pair_qreal_QPointF__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_STD_PAIR_QREAL_QPOINTF_IDX], "std::pair<qreal,QPointF>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_STD_PAIR_QREAL_QPOINTF_IDX],
        PySequence_PythonToCpp_std_pair_qreal_QPointF_,
        is_PySequence_PythonToCpp_std_pair_qreal_QPointF__Convertible);

    // Register converter for type 'QList<std::pair<qreal,QPointF>>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_STD_PAIR_QREAL_QPOINTF_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_std_pair_qreal_QPointF___CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_STD_PAIR_QREAL_QPOINTF_IDX], "QList<std::pair<qreal,QPointF>>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_STD_PAIR_QREAL_QPOINTF_IDX],
        PySequence_PythonToCpp__QList_std_pair_qreal_QPointF__,
        is_PySequence_PythonToCpp__QList_std_pair_qreal_QPointF___Convertible);

    // Register converter for type 'std::pair<qreal,qreal>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_STD_PAIR_QREAL_QREAL_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, std_pair_qreal_qreal__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_STD_PAIR_QREAL_QREAL_IDX], "std::pair<qreal,qreal>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_STD_PAIR_QREAL_QREAL_IDX],
        PySequence_PythonToCpp_std_pair_qreal_qreal_,
        is_PySequence_PythonToCpp_std_pair_qreal_qreal__Convertible);

    // Register converter for type 'QList<std::pair<qreal,qreal>>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_STD_PAIR_QREAL_QREAL_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_std_pair_qreal_qreal___CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_STD_PAIR_QREAL_QREAL_IDX], "QList<std::pair<qreal,qreal>>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_STD_PAIR_QREAL_QREAL_IDX],
        PySequence_PythonToCpp__QList_std_pair_qreal_qreal__,
        is_PySequence_PythonToCpp__QList_std_pair_qreal_qreal___Convertible);

    // Register converter for type 'QList<QKeySequence>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QKEYSEQUENCE_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QKeySequence__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QKEYSEQUENCE_IDX], "QList<QKeySequence>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QKEYSEQUENCE_IDX],
        PySequence_PythonToCpp__QList_QKeySequence_,
        is_PySequence_PythonToCpp__QList_QKeySequence__Convertible);

    // Register converter for type 'QList<QGesture*>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QGESTUREPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QGesturePTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QGESTUREPTR_IDX], "QList<QGesture*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QGESTUREPTR_IDX],
        PySequence_PythonToCpp__QList_QGesturePTR_,
        is_PySequence_PythonToCpp__QList_QGesturePTR__Convertible);

    // Register converter for type 'QList<QWindow*>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QWINDOWPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QWindowPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QWINDOWPTR_IDX], "QList<QWindow*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QWINDOWPTR_IDX],
        PySequence_PythonToCpp__QList_QWindowPTR_,
        is_PySequence_PythonToCpp__QList_QWindowPTR__Convertible);

    // Register converter for type 'QList<QScreen*>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QSCREENPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QScreenPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QSCREENPTR_IDX], "QList<QScreen*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QSCREENPTR_IDX],
        PySequence_PythonToCpp__QList_QScreenPTR_,
        is_PySequence_PythonToCpp__QList_QScreenPTR__Convertible);

    // Register converter for type 'QList<QUrl>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QURL_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QUrl__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QURL_IDX], "QList<QUrl>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QURL_IDX],
        PySequence_PythonToCpp__QList_QUrl_,
        is_PySequence_PythonToCpp__QList_QUrl__Convertible);

    // Register converter for type 'QMap<int,QVariant>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QMAP_INT_QVARIANT_IDX] = Shiboken::Conversions::createConverter(&PyDict_Type, _QMap_int_QVariant__CppToPython_PyDict);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QMAP_INT_QVARIANT_IDX], "QMap<int,QVariant>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QMAP_INT_QVARIANT_IDX],
        PyDict_PythonToCpp__QMap_int_QVariant_,
        is_PyDict_PythonToCpp__QMap_int_QVariant__Convertible);

    // Register converter for type 'QHash<int,QByteArray>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QHASH_INT_QBYTEARRAY_IDX] = Shiboken::Conversions::createConverter(&PyDict_Type, _QHash_int_QByteArray__CppToPython_PyDict);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QHASH_INT_QBYTEARRAY_IDX], "QHash<int,QByteArray>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QHASH_INT_QBYTEARRAY_IDX],
        PyDict_PythonToCpp__QHash_int_QByteArray_,
        is_PyDict_PythonToCpp__QHash_int_QByteArray__Convertible);

    // Register converter for type 'QList<QVariant>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QVARIANT_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QVariant__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QVARIANT_IDX], "QList<QVariant>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QVARIANT_IDX],
        PySequence_PythonToCpp__QList_QVariant_,
        is_PySequence_PythonToCpp__QList_QVariant__Convertible);

    // Register converter for type 'QList<QString>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QSTRING_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QString__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QSTRING_IDX], "QList<QString>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QLIST_QSTRING_IDX],
        PySequence_PythonToCpp__QList_QString_,
        is_PySequence_PythonToCpp__QList_QString__Convertible);

    // Register converter for type 'QMap<QString,QVariant>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QMAP_QSTRING_QVARIANT_IDX] = Shiboken::Conversions::createConverter(&PyDict_Type, _QMap_QString_QVariant__CppToPython_PyDict);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QMAP_QSTRING_QVARIANT_IDX], "QMap<QString,QVariant>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QTWIDGETS_QMAP_QSTRING_QVARIANT_IDX],
        PyDict_PythonToCpp__QMap_QString_QVariant_,
        is_PyDict_PythonToCpp__QMap_QString_QVariant__Convertible);


    // Opaque container type registration
    PyObject *ob_type{};
    ob_type = reinterpret_cast<PyObject *>(QIntList_TypeF());
    Py_XINCREF(ob_type);
    PyModule_AddObject(module, "QIntList", ob_type);
    ob_type = reinterpret_cast<PyObject *>(QPointList_TypeF());
    Py_XINCREF(ob_type);
    PyModule_AddObject(module, "QPointList", ob_type);
    ob_type = reinterpret_cast<PyObject *>(QPointFList_TypeF());
    Py_XINCREF(ob_type);
    PyModule_AddObject(module, "QPointFList", ob_type);

    // Register primitive types converters.
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "GLbitfield");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "GLboolean");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), "GLbyte");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<char>(), "GLchar");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<char>(), "GLcharARB");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<double>(), "GLclampd");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<float>(), "GLclampf");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<double>(), "GLdouble");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "GLenum");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "GLfixed");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<float>(), "GLfloat");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "GLhalf");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "GLhalfARB");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "GLhalfNV");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "GLhandleARB");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "GLint");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "GLint64");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "GLint64EXT");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "GLintptr");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "GLintptrARB");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<short>(), "GLshort");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "GLsizei");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "GLsizeiptr");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "GLsizeiptrARB");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "GLubyte");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "GLuint");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "GLuint64");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "GLuint64EXT");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "GLushort");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "GLvdpauSurfaceNV");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLACQUIREKEYEDMUTEXWIN32EXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLAREPROGRAMSRESIDENTNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLARETEXTURESRESIDENTEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLBINDLIGHTPARAMETEREXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLBINDMATERIALPARAMETEREXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLBINDPARAMETEREXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLBINDTEXGENPARAMETEREXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLBINDTEXTUREUNITPARAMETEREXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCHECKFRAMEBUFFERSTATUSEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCHECKFRAMEBUFFERSTATUSPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCHECKNAMEDFRAMEBUFFERSTATUSEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCHECKNAMEDFRAMEBUFFERSTATUSPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCLIENTWAITSYNCPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCREATEPROGRAMOBJECTARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCREATEPROGRAMPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCREATESHADEROBJECTARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCREATESHADERPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCREATESHADERPROGRAMEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCREATESHADERPROGRAMVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLFINISHASYNCSGIXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGENASYNCMARKERSSGIXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGENFRAGMENTSHADERSATIPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGENPATHSNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGENSYMBOLSEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGENVERTEXSHADERSEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETATTRIBLOCATIONARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETATTRIBLOCATIONPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETCOMMANDHEADERNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETDEBUGMESSAGELOGAMDPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETDEBUGMESSAGELOGARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETDEBUGMESSAGELOGPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETFRAGDATAINDEXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETFRAGDATALOCATIONEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETFRAGDATALOCATIONPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETGRAPHICSRESETSTATUSARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETGRAPHICSRESETSTATUSPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETHANDLEARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "PFNGLGETIMAGEHANDLEARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "PFNGLGETIMAGEHANDLENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETINSTRUMENTSSGIXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<float>(), "PFNGLGETPATHLENGTHNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETPROGRAMRESOURCEINDEXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETPROGRAMRESOURCELOCATIONINDEXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETPROGRAMRESOURCELOCATIONPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "PFNGLGETSTAGEINDEXNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLGETSTRINGIPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETSUBROUTINEINDEXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETSUBROUTINEUNIFORMLOCATIONPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "PFNGLGETTEXTUREHANDLEARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "PFNGLGETTEXTUREHANDLENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "PFNGLGETTEXTURESAMPLERHANDLEARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "PFNGLGETTEXTURESAMPLERHANDLENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETUNIFORMBLOCKINDEXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETUNIFORMBUFFERSIZEEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETUNIFORMLOCATIONARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETUNIFORMLOCATIONPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "PFNGLGETUNIFORMOFFSETEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETVARYINGLOCATIONNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISASYNCMARKERSGIXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISBUFFERARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISBUFFERPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISBUFFERRESIDENTNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISCOMMANDLISTNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISENABLEDINDEXEDEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISENABLEDIPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISFENCEAPPLEPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISFENCENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISFRAMEBUFFEREXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISFRAMEBUFFERPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISIMAGEHANDLERESIDENTARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISIMAGEHANDLERESIDENTNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISMEMORYOBJECTEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISNAMEAMDPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISNAMEDBUFFERRESIDENTNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISNAMEDSTRINGARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISOBJECTBUFFERATIPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISOCCLUSIONQUERYNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISPATHNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISPOINTINFILLPATHNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISPOINTINSTROKEPATHNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISPROGRAMARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISPROGRAMNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISPROGRAMPIPELINEPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISPROGRAMPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISQUERYARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISQUERYPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISRENDERBUFFEREXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISRENDERBUFFERPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISSAMPLERPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISSEMAPHOREEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISSHADERPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISSTATENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISSYNCPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISTEXTUREEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISTEXTUREHANDLERESIDENTARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISTEXTUREHANDLERESIDENTNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISTRANSFORMFEEDBACKNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISTRANSFORMFEEDBACKPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISVARIANTENABLEDEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISVERTEXARRAYAPPLEPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISVERTEXARRAYPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISVERTEXATTRIBENABLEDAPPLEPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLNEWOBJECTBUFFERATIPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLOBJECTPURGEABLEAPPLEPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLOBJECTUNPURGEABLEAPPLEPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLPATHGLYPHINDEXARRAYNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLPATHGLYPHINDEXRANGENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLPATHMEMORYGLYPHINDEXARRAYNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLPOINTALONGPATHNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLPOLLASYNCSGIXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLPOLLINSTRUMENTSSGIXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLQUERYMATRIXXOESPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLQUERYRESOURCENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLRELEASEKEYEDMUTEXWIN32EXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLTESTFENCEAPPLEPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLTESTFENCENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLTESTOBJECTAPPLEPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLUNMAPBUFFERARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLUNMAPBUFFERPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLUNMAPNAMEDBUFFEREXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLUNMAPNAMEDBUFFERPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLVDPAUISSURFACENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "PFNGLVDPAUREGISTEROUTPUTSURFACENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "PFNGLVDPAUREGISTERVIDEOSURFACENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "PFNGLVDPAUREGISTERVIDEOSURFACEWITHPICTURESTRUCTURENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLVIDEOCAPTURENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "QRgb");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__blkcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__blkcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__blksize_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<char>(), "__caddr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__clock_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__clockid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__compar_d_fn_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__compar_fn_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__daddr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__dev_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__fsblkcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__fsblkcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__fsfilcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__fsfilcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__fsword_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__gid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__id_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__ino64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__ino_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<short>(), "__int16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__int32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__int64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), "__int8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<short>(), "__int_least16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__int_least32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__int_least64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), "__int_least8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__intmax_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__intptr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__key_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__loff_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__mode_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__nlink_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__off64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__off_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__pid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__quad_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__rlim64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__rlim_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__sig_atomic_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__socklen_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__ssize_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__suseconds64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__suseconds_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__syscall_slong_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__syscall_ulong_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__time_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "__u_char");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__u_int");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__u_long");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__u_quad_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "__u_short");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__uid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "__uint16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__uint32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__uint64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "__uint8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "__uint_least16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__uint_least32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__uint_least64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "__uint_least8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__uintmax_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__useconds_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "blkcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "blkcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "blksize_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<char>(), "caddr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "comparison_fn_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "daddr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "dev_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "fsblkcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "fsblkcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "fsfilcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "fsfilcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "gid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "id_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "ino64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "ino_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "int_fast16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "int_fast32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "int_fast64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), "int_fast8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<short>(), "int_least16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "int_least32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "int_least64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), "int_least8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "intmax_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "key_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "loff_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "mode_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "nlink_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "off64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "off_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "pid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "ptrdiff_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), "qInternalCallback");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "qopengl_GLintptr");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "qopengl_GLsizeiptr");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "quad_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "register_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "ssize_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "suseconds_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "u_char");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "u_int");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "u_int16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "u_int32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "u_int64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "u_int8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "u_long");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "u_quad_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "u_short");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "uid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uint_fast16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uint_fast32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uint_fast64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "uint_fast8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "uint_least16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "uint_least32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uint_least64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "uint_least8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uintmax_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "useconds_t");

    Shiboken::Module::registerTypes(module, SbkPySide6_QtWidgetsTypes);
    Shiboken::Module::registerTypeConverters(module, SbkPySide6_QtWidgetsTypeConverters);

    if (Shiboken::Errors::occurred() != nullptr) {
        PyErr_Print();
        Py_FatalError("can't initialize module QtWidgets");
    }
    PySide::registerCleanupFunction(cleanTypesAttributes);

    FinishSignatureInitialization(module, QtWidgets_SignatureStrings);

    return module;
}
